@@ -60,6 +60,9 @@ void UI_setVProcessToggleStatus( uint8_t status )
 //**************************************************
 void UI_refreshCustomMenu(void) {}
 
+void UI_applySettings(void)
+{}
+
 int    UI_getCurrentPreview(void)
 {
   return 0; 
@@ -171,4 +174,6 @@ bool UI_setDisplayName(char const*)
 {
         return true;
 }
+void UI_setNeedsResizingFlag(bool resize)
+{}
 // EOF
