@@ -1,6 +1,6 @@
 /***************************************************************************
   DIA_prefs.cpp
-  (C) 2007 Mean Fixounet@free.fr 
+  (C) 2007/2016 Mean Fixounet@free.fr
 ***************************************************************************/
 
 /***************************************************************************
@@ -22,12 +22,15 @@
 
 
 #include "DIA_factory.h"
+#ifdef USE_VDPAU
+#include "ADM_coreVdpau/ADM_coreVdpau.h"
+#endif
 #ifdef USE_SDL
 #include "ADM_render/GUI_sdlRender.h"
 #endif
 
 extern void 		AVDM_audioPref( void );
-extern const char* getNativeRendererDesc();
+extern const char* getNativeRendererDesc(int type);
 
 
 
@@ -44,8 +47,6 @@ uint32_t olddevice,newdevice;
 bool     use_odml=0;
 uint32_t autosplit=0;
 uint32_t render;
-bool     useTray=0;
-
 
 bool     useSwap=0;
 
@@ -58,14 +59,19 @@ bool     mpeg_no_limit=0;
 uint32_t msglevel=2;
 
 uint32_t mixer=0;
-
+bool     doAutoUpdate=false;
+bool     loadDefault=false;
 char     *alsaDevice=NULL;
 
 bool     balternate_mp3_tag=true;
+bool     lastReadDirAsTarget=false;
+bool     altKeyboardShortcuts=false;
+bool     swapUpDown=false;
 
 uint32_t pp_type=3;
 uint32_t pp_value=5;
 
+bool     bdxva2=false;
 bool     bvdpau=false;
 bool     bxvba=false;
 bool     blibva=false;
@@ -91,21 +97,22 @@ std::string currentSdlDriver=getSdlDriverName();
 
         prefs->get(FEATURES_CAP_REFRESH_ENABLED,&refreshCapEnabled);
         prefs->get(FEATURES_CAP_REFRESH_VALUE,&refreshCapValue);
-        
-        
+
+
         // Default pp
          if(!prefs->get(DEFAULT_POSTPROC_TYPE,&pp_type)) pp_type=3;
          if(!prefs->get(DEFAULT_POSTPROC_VALUE,&pp_value)) pp_value=3;
 #define DOME(x,y) y=!!(pp_type & x)
-    
+
     DOME(1,hzd);
     DOME(2,vzd);
     DOME(4,dring);
-     
+
 // Cpu caps
-#define CPU_CAPS(x)    	if(CpuCaps::myCpuMask & ADM_CPUCAP_##x) caps##x=1; else caps##x=0;
-    
-    	if(CpuCaps::myCpuMask==ADM_CPUCAP_ALL) capsAll=1; else capsAll=0;
+#define CPU_CAPS(x)    	if(cpuMask & ADM_CPUCAP_##x) caps##x=1; else caps##x=0;
+
+        uint32_t cpuMask=CpuCaps::getMask();
+    	if(cpuMask==ADM_CPUCAP_ALL) capsAll=1; else capsAll=0;
     	CPU_CAPS(MMX);
     	CPU_CAPS(MMXEXT);
     	CPU_CAPS(3DNOW);
@@ -128,12 +135,15 @@ std::string currentSdlDriver=getSdlDriverName();
                         defaultPortAvisynth=9999;
     	}
     	ADM_info("Avisynth port: %d\n",defaultPortAvisynth);
-    
+
         // Alsa
 #ifdef ALSA_SUPPORT
         if( prefs->get(DEVICE_AUDIO_ALSA_DEVICE, &alsaDevice) != RC_OK )
                 alsaDevice = ADM_strdup("plughw:0,0");
 #endif
+        // dxva2
+        
+        prefs->get(FEATURES_DXVA2,&bdxva2);                
         // vdpau
         prefs->get(FEATURES_VDPAU,&bvdpau);
         // xvba
@@ -142,18 +152,28 @@ std::string currentSdlDriver=getSdlDriverName();
         prefs->get(FEATURES_LIBVA,&blibva);
         // Alternate mp3 tag (haali)
         prefs->get(FEATURES_ALTERNATE_MP3_TAG,&balternate_mp3_tag);
-        
+
         // Video renderer
         if(prefs->get(VIDEODEVICE,&render)!=RC_OK)
-        {       
+        {
                 render=(uint32_t)RENDER_GTK;
         }
-        // SysTray
-        if(!prefs->get(FEATURES_USE_SYSTRAY,&useTray)) 
-                useTray=0;
         // Accept mpeg for DVD when fq!=48 kHz
         if(!prefs->get(FEATURES_MPEG_NO_LIMIT,&mpeg_no_limit)) mpeg_no_limit=0;
 
+        prefs->get(UPDATE_ENABLED,&doAutoUpdate);
+
+        prefs->get(RESET_ENCODER_ON_VIDEO_LOAD,&loadDefault);
+
+        // Make users happy who prefer the output dir to be the same as the input dir
+        prefs->get(FEATURES_USE_LAST_READ_DIR_AS_TARGET,&lastReadDirAsTarget);
+
+        // PgUp and PgDown are cumbersome to reach on some laptops, offer alternative kbd shortcuts
+        prefs->get(KEYBOARD_SHORTCUTS_USE_ALTERNATE_KBD_SHORTCUTS,&altKeyboardShortcuts);
+
+        // Optionally reverse UP and DOWN keys for navigation
+        prefs->get(KEYBOARD_SHORTCUTS_SWAP_UP_DOWN_KEYS,&swapUpDown);
+
         // Multithreads
         prefs->get(FEATURES_THREADING_LAVC, &lavcThreads);
 
@@ -168,10 +188,10 @@ std::string currentSdlDriver=getSdlDriverName();
         if(!prefs->get(PRIORITY_PLAYBACK, &playbackPriority))
         playbackPriority=0;
 
-        // VCD/SVCD split point		
+        // VCD/SVCD split point
         if(!prefs->get(MPEGSPLIT_AUTOSPLIT, &autosplit))
-                autosplit=690;		
-                        
+                autosplit=690;
+
         // Open DML (Gmv)
         if(!prefs->get(FEATURES_USE_ODML, &use_odml))
           use_odml=0;
@@ -188,106 +208,99 @@ std::string currentSdlDriver=getSdlDriverName();
         prefs->get(MESSAGE_LEVEL,&msglevel);
         // Downmix default
         if(prefs->get(DEFAULT_DOWNMIXING,&downmix)!=RC_OK)
-        {       
+        {
             downmix=0;
         }
         olddevice=newdevice=AVDM_getCurrentDevice();
         // Audio device
         /************************ Build diaelems ****************************************/
+        diaElemToggle useDxva2(&bdxva2,QT_TRANSLATE_NOOP("adm","Decode video using DXVA2 (windows)"));
         diaElemToggle useVdpau(&bvdpau,QT_TRANSLATE_NOOP("adm","Decode video using VDPAU (NVIDIA)"));
         diaElemToggle useXvba(&bxvba,QT_TRANSLATE_NOOP("adm","Decode video using XVBA (AMD)"));
         diaElemToggle useLibVA(&blibva,QT_TRANSLATE_NOOP("adm","Decode video using LIBVA (INTEL)"));
         diaElemToggle useOpenGl(&hasOpenGl,QT_TRANSLATE_NOOP("adm","Enable openGl support"));
-        
+
         bool foo=0;
         diaElemToggle hwAccelText(&foo,QT_TRANSLATE_NOOP("adm","If you use Hw decoding, it is better to use the matching display driver"));
-        
 
-#ifndef USE_VDPAU
-        // Crash useVdpau.enable(0);
-#endif
-#ifndef USE_LIBVA
-        // Crash useLibVA.enable(0);
-#endif
-#ifndef USE_XVBA
-        // Crash useXvba.enable(0);
-#endif
 
-        
-#ifndef USE_OPENGL
-        // Crash         //useOpenGl.enable(0);
-#endif
-        
-        diaElemToggle useSysTray(&useTray,QT_TRANSLATE_NOOP("adm","_Use systray while encoding"));
         diaElemToggle allowAnyMpeg(&mpeg_no_limit,QT_TRANSLATE_NOOP("adm","_Accept non-standard audio frequency for DVD"));
         diaElemToggle openDml(&use_odml,QT_TRANSLATE_NOOP("adm","Create _OpenDML files"));
+        diaElemToggle resetEncoder(&loadDefault,QT_TRANSLATE_NOOP("adm","_Revert to saved default output settings on video load"));
+        diaElemToggle enableAltShortcuts(&altKeyboardShortcuts,QT_TRANSLATE_NOOP("adm","_Enable alternative keyboard shortcuts"));
+        diaElemToggle swapUpDownKeys(&swapUpDown,QT_TRANSLATE_NOOP("adm","Re_verse UP and DOWN arrow keys for navigation"));
+        diaElemToggle checkForUpdate(&doAutoUpdate,QT_TRANSLATE_NOOP("adm","_Check for new release"));
 
-        
 
         diaElemFrame frameSimd(QT_TRANSLATE_NOOP("adm","SIMD"));
 
-		diaElemToggle capsToggleAll(&capsAll,QT_TRANSLATE_NOOP("adm","Enable all SIMD"));
+        diaElemToggle capsToggleAll(&capsAll,QT_TRANSLATE_NOOP("adm","Enable all SIMD"));
         diaElemToggle capsToggleMMX(&capsMMX, QT_TRANSLATE_NOOP("adm","Enable MMX"));
-		diaElemToggle capsToggleMMXEXT(&capsMMXEXT, QT_TRANSLATE_NOOP("adm","Enable MMXEXT"));
-		diaElemToggle capsToggle3DNOW(&caps3DNOW, QT_TRANSLATE_NOOP("adm","Enable 3DNOW"));
-		diaElemToggle capsToggle3DNOWEXT(&caps3DNOWEXT, QT_TRANSLATE_NOOP("adm","Enable 3DNOWEXT"));
-		diaElemToggle capsToggleSSE(&capsSSE, QT_TRANSLATE_NOOP("adm","Enable SSE"));
-		diaElemToggle capsToggleSSE2(&capsSSE2, QT_TRANSLATE_NOOP("adm","Enable SSE2"));
-		diaElemToggle capsToggleSSE3(&capsSSE3, QT_TRANSLATE_NOOP("adm","Enable SSE3"));
-		diaElemToggle capsToggleSSSE3(&capsSSSE3, QT_TRANSLATE_NOOP("adm","Enable SSSE3"));
+        diaElemToggle capsToggleMMXEXT(&capsMMXEXT, QT_TRANSLATE_NOOP("adm","Enable MMXEXT"));
+        diaElemToggle capsToggle3DNOW(&caps3DNOW, QT_TRANSLATE_NOOP("adm","Enable 3DNOW"));
+        diaElemToggle capsToggle3DNOWEXT(&caps3DNOWEXT, QT_TRANSLATE_NOOP("adm","Enable 3DNOWEXT"));
+        diaElemToggle capsToggleSSE(&capsSSE, QT_TRANSLATE_NOOP("adm","Enable SSE"));
+        diaElemToggle capsToggleSSE2(&capsSSE2, QT_TRANSLATE_NOOP("adm","Enable SSE2"));
+        diaElemToggle capsToggleSSE3(&capsSSE3, QT_TRANSLATE_NOOP("adm","Enable SSE3"));
+        diaElemToggle capsToggleSSSE3(&capsSSSE3, QT_TRANSLATE_NOOP("adm","Enable SSSE3"));
 
-		capsToggleAll.link(0, &capsToggleMMX);
-		capsToggleAll.link(0, &capsToggleMMXEXT);
-		capsToggleAll.link(0, &capsToggle3DNOW);
-		capsToggleAll.link(0, &capsToggle3DNOWEXT);
-		capsToggleAll.link(0, &capsToggleSSE);
-		capsToggleAll.link(0, &capsToggleSSE2);
-		capsToggleAll.link(0, &capsToggleSSE3);
-		capsToggleAll.link(0, &capsToggleSSSE3);
+        capsToggleAll.link(0, &capsToggleMMX);
+        capsToggleAll.link(0, &capsToggleMMXEXT);
+        capsToggleAll.link(0, &capsToggle3DNOW);
+        capsToggleAll.link(0, &capsToggle3DNOWEXT);
+        capsToggleAll.link(0, &capsToggleSSE);
+        capsToggleAll.link(0, &capsToggleSSE2);
+        capsToggleAll.link(0, &capsToggleSSE3);
+        capsToggleAll.link(0, &capsToggleSSSE3);
 
-		frameSimd.swallow(&capsToggleAll);
-		frameSimd.swallow(&capsToggleMMX);
-		frameSimd.swallow(&capsToggleMMXEXT);
-		frameSimd.swallow(&capsToggle3DNOW);
-		frameSimd.swallow(&capsToggle3DNOWEXT);
-		frameSimd.swallow(&capsToggleSSE);
-		frameSimd.swallow(&capsToggleSSE2);
-		frameSimd.swallow(&capsToggleSSE3);
-		frameSimd.swallow(&capsToggleSSSE3);
+        frameSimd.swallow(&capsToggleAll);
+        frameSimd.swallow(&capsToggleMMX);
+        frameSimd.swallow(&capsToggleMMXEXT);
+        frameSimd.swallow(&capsToggle3DNOW);
+        frameSimd.swallow(&capsToggle3DNOWEXT);
+        frameSimd.swallow(&capsToggleSSE);
+        frameSimd.swallow(&capsToggleSSE2);
+        frameSimd.swallow(&capsToggleSSE3);
+        frameSimd.swallow(&capsToggleSSSE3);
 
-		diaElemThreadCount lavcThreadCount(&lavcThreads, QT_TRANSLATE_NOOP("adm","_lavc threads:"));
+        diaElemThreadCount lavcThreadCount(&lavcThreads, QT_TRANSLATE_NOOP("adm","_lavc threads:"));
 
-		diaElemFrame frameThread(QT_TRANSLATE_NOOP("adm","Multi-threading"));
-		frameThread.swallow(&lavcThreadCount);
+        diaElemFrame frameThread(QT_TRANSLATE_NOOP("adm","Multi-threading"));
+        frameThread.swallow(&lavcThreadCount);
 
-		diaMenuEntry priorityEntries[] = {
-                             {0,       QT_TRANSLATE_NOOP("adm","High"),NULL}
-                             ,{1,      QT_TRANSLATE_NOOP("adm","Above normal"),NULL}
-                             ,{2,      QT_TRANSLATE_NOOP("adm","Normal"),NULL}
-							 ,{3,      QT_TRANSLATE_NOOP("adm","Below normal"),NULL}
-							 ,{4,      QT_TRANSLATE_NOOP("adm","Low"),NULL}
-        };
-		diaElemMenu menuEncodePriority(&encodePriority,QT_TRANSLATE_NOOP("adm","_Encoding priority:"), sizeof(priorityEntries)/sizeof(diaMenuEntry), priorityEntries,"");
-		diaElemMenu menuIndexPriority(&indexPriority,QT_TRANSLATE_NOOP("adm","_Indexing/unpacking priority:"), sizeof(priorityEntries)/sizeof(diaMenuEntry), priorityEntries,"");
-		diaElemMenu menuPlaybackPriority(&playbackPriority,QT_TRANSLATE_NOOP("adm","_Playback priority:"), sizeof(priorityEntries)/sizeof(diaMenuEntry), priorityEntries,"");
+        diaMenuEntry priorityEntries[] = {
+                     {0,       QT_TRANSLATE_NOOP("adm","High"),NULL}
+                     ,{1,      QT_TRANSLATE_NOOP("adm","Above normal"),NULL}
+                     ,{2,      QT_TRANSLATE_NOOP("adm","Normal"),NULL}
+                    ,{3,      QT_TRANSLATE_NOOP("adm","Below normal"),NULL}
+                    ,{4,      QT_TRANSLATE_NOOP("adm","Low"),NULL}
+};
+        diaElemMenu menuEncodePriority(&encodePriority,QT_TRANSLATE_NOOP("adm","_Encoding priority:"), sizeof(priorityEntries)/sizeof(diaMenuEntry), priorityEntries,"");
+        diaElemMenu menuIndexPriority(&indexPriority,QT_TRANSLATE_NOOP("adm","_Indexing/unpacking priority:"), sizeof(priorityEntries)/sizeof(diaMenuEntry), priorityEntries,"");
+        diaElemMenu menuPlaybackPriority(&playbackPriority,QT_TRANSLATE_NOOP("adm","_Playback priority:"), sizeof(priorityEntries)/sizeof(diaMenuEntry), priorityEntries,"");
 
-		diaElemFrame framePriority(QT_TRANSLATE_NOOP("adm","Prioritisation"));
-		framePriority.swallow(&menuEncodePriority);
-		framePriority.swallow(&menuIndexPriority);
-		framePriority.swallow(&menuPlaybackPriority);
+        diaElemFrame framePriority(QT_TRANSLATE_NOOP("adm","Prioritisation"));
+        framePriority.swallow(&menuEncodePriority);
+        framePriority.swallow(&menuIndexPriority);
+        framePriority.swallow(&menuPlaybackPriority);
 
         diaElemUInteger autoSplit(&autosplit,QT_TRANSLATE_NOOP("adm","_Split MPEG files every (MB):"),10,4096);
-        
+
         diaElemToggle   togTagMp3(&balternate_mp3_tag,QT_TRANSLATE_NOOP("adm","_Use alternative tag for MP3 in .mp4"));
-        
+
+        diaElemToggle useLastReadAsTarget(&lastReadDirAsTarget,QT_TRANSLATE_NOOP("adm","_Default to the directory of the last read file for saving"));
+
         diaMenuEntry videoMode[]={
-                             {RENDER_GTK, getNativeRendererDesc(), NULL}
+                             {RENDER_GTK, getNativeRendererDesc(0), NULL}
 #ifdef USE_XV
                              ,{RENDER_XV,   QT_TRANSLATE_NOOP("adm","XVideo (best)"),NULL}
 #endif
 #ifdef USE_VDPAU
                              ,{RENDER_VDPAU,   QT_TRANSLATE_NOOP("adm","VDPAU (best)"),NULL}
 #endif
+#ifdef USE_DXVA2
+                             ,{RENDER_DXVA2,   QT_TRANSLATE_NOOP("adm","DXVA2 (best)"),NULL}
+#endif
 #ifdef USE_XVBA
                              //,{RENDER_XVBA,   QT_TRANSLATE_NOOP("adm","XVBA (best)"),NULL}
 #endif
@@ -299,11 +312,11 @@ std::string currentSdlDriver=getSdlDriverName();
                              ,{RENDER_LIBVA,   QT_TRANSLATE_NOOP("adm","LIBVA (best)"),NULL}
 #endif
 
-                             
+
 #ifdef USE_SDL
 							 ,{RENDER_SDL,      QT_TRANSLATE_NOOP("adm","SDL (good)"),NULL}
 #endif
-        };        
+        };
         diaElemMenu menuVideoMode(&render,QT_TRANSLATE_NOOP("adm","Video _display:"), sizeof(videoMode)/sizeof(diaMenuEntry),videoMode,"");
 #ifdef USE_SDL
         const std::vector<sdlDriverInfo> &listOfSdl=getListOfSdlDrivers();
@@ -327,48 +340,48 @@ std::string currentSdlDriver=getSdlDriverName();
             sdlMenu=new diaElemMenuDynamic(&sdlMenuIndex, QT_TRANSLATE_NOOP("adm","Sdl driver"),nbSDL,  sdlMenuEntries);
         }else
         {
-            sdlMenu=new diaElemMenuDynamic(&sdlMenuIndex, QT_TRANSLATE_NOOP("adm","Sdl driver"),0,  NULL);   
+            sdlMenu=new diaElemMenuDynamic(&sdlMenuIndex, QT_TRANSLATE_NOOP("adm","Sdl driver"),0,  NULL);
         }
-#endif        
-        
-        
+#endif
+
+
         diaMenuEntry msgEntries[]={
                              {0,       QT_TRANSLATE_NOOP("adm","No alerts"),NULL}
                              ,{1,      QT_TRANSLATE_NOOP("adm","Display only error alerts"),NULL}
                              ,{2,      QT_TRANSLATE_NOOP("adm","Display all alerts"),NULL}
         };
         diaElemMenu menuMessage(&msglevel,QT_TRANSLATE_NOOP("adm","_Message level:"), sizeof(msgEntries)/sizeof(diaMenuEntry),msgEntries,"");
-        
-        
+
+
 #if defined(ALSA_SUPPORT) || defined (OSS_SUPPORT)
         diaMenuEntry volumeEntries[]={
                              {0,       QT_TRANSLATE_NOOP("adm","PCM"),NULL}
                              ,{1,      QT_TRANSLATE_NOOP("adm","Master"),NULL}};
         diaElemMenu menuVolume(&useMaster,QT_TRANSLATE_NOOP("adm","_Volume control:"), sizeof(volumeEntries)/sizeof(diaMenuEntry),volumeEntries,"");
 #endif
-        
-        
+
+
          diaMenuEntry mixerEntries[]={
                              {0,       QT_TRANSLATE_NOOP("adm","No downmixing"),NULL}
                              ,{1,       QT_TRANSLATE_NOOP("adm","Stereo"),NULL}
                              ,{2,      QT_TRANSLATE_NOOP("adm","Pro Logic"),NULL}
-                              ,{3,      QT_TRANSLATE_NOOP("adm","Pro Logic II"),NULL}
+                             ,{3,      QT_TRANSLATE_NOOP("adm","Pro Logic II"),NULL}
          };
         diaElemMenu menuMixer(&downmix,QT_TRANSLATE_NOOP("adm","_Local playback downmixing:"), sizeof(mixerEntries)/sizeof(diaMenuEntry),mixerEntries,"");
 //*********** AV_
-		
+
 //***AV
         uint32_t nbAudioDevice=ADM_av_getNbDevices();
         diaMenuEntryDynamic **audioDeviceItems=new diaMenuEntryDynamic *[nbAudioDevice+1];
         audioDeviceItems[0]=new diaMenuEntryDynamic(0,"Dummy","Dummy");
         for(int i=0;i<nbAudioDevice;i++)
         {
-            const char *name;
+            std::string name;
             uint32_t major,minor,patch;
-            ADM_av_getDeviceInfo(i, &name, &major,&minor,&patch);
-            audioDeviceItems[i+1]=new diaMenuEntryDynamic(i+1,name,name);
+            ADM_av_getDeviceInfo(i, name, &major,&minor,&patch);
+            audioDeviceItems[i+1]=new diaMenuEntryDynamic(i+1,name.c_str(),name.c_str());
         }
-        diaElemMenuDynamic menuAudio(&newdevice,QT_TRANSLATE_NOOP("adm","_AudioDevice"), nbAudioDevice+1, 
+        diaElemMenuDynamic menuAudio(&newdevice,QT_TRANSLATE_NOOP("adm","_AudioDevice"), nbAudioDevice+1,
                     audioDeviceItems,NULL);
         // default Post proc
      diaElemToggle     fhzd(&hzd,QT_TRANSLATE_NOOP("adm","_Horizontal deblocking"));
@@ -376,7 +389,7 @@ std::string currentSdlDriver=getSdlDriverName();
      diaElemToggle     fdring(&dring,QT_TRANSLATE_NOOP("adm","De_ringing"));
      diaElemUInteger   postProcStrength(&pp_value,QT_TRANSLATE_NOOP("adm","_Strength:"),0,5);
      diaElemFrame      framePP(QT_TRANSLATE_NOOP("adm","Default Postprocessing"));
-     
+
      framePP.swallow(&fhzd);
      framePP.swallow(&fvzd);
      framePP.swallow(&fdring);
@@ -384,49 +397,51 @@ std::string currentSdlDriver=getSdlDriverName();
 
 
 //  -- select language
-     typedef struct  { const char *lang;const char *desc;}languageDescriptor;
-     uint32_t languageIndex=0;
-     languageDescriptor myLanguages[]={
-                {"auto","System language"},
+        typedef struct  { const char *lang;const char *desc;}languageDescriptor;
+        uint32_t languageIndex=0;
+        languageDescriptor myLanguages[]={
+                   {"auto",QT_TRANSLATE_NOOP("adm","System language")},
+                {"da","Dansk"},
+                {"de","Deutsch"},
                 {"en","English"},
+                {"es","Español"},
                 {"fr","Français"},
-                {"de","German"},
-                {"es","Spanish"},
-                {"it","Italian"},
-                {"ru","Pyckuu"},
-                {"pl","Polish"},
+                {"it","Italiano"},
+                {"hu","Magyar"},
+                {"pl","Polski"},
+                {"ru","Русский"},
         };
         uint32_t nbLanguages=sizeof(myLanguages)/sizeof(languageDescriptor);
-        char *currentLanguage;
+        std::string currentLanguage;
         int currentIndex=0;
-        if(!prefs->get(DEFAULT_LANGUAGE,&currentLanguage)) currentLanguage=(char *)"auto";
-  
+        if(!prefs->get(DEFAULT_LANGUAGE,currentLanguage)) currentLanguage=std::string("auto");
+
         diaMenuEntryDynamic **languagesMenuItems=new diaMenuEntryDynamic *[nbLanguages+1];
         for(int i=0;i<nbLanguages;i++)
-        {           
+        {
             languageDescriptor *lg=myLanguages+i;
-            if(!strcmp(lg->lang,currentLanguage))
+            if(!strcmp(lg->lang,currentLanguage.c_str()))
                 currentIndex=i;
             languagesMenuItems[i]=new diaMenuEntryDynamic(i,lg->desc,lg->lang);
         }
         languageIndex=currentIndex;
-        diaElemMenuDynamic menuLanguage(&languageIndex,QT_TRANSLATE_NOOP("adm","_Language"), nbLanguages, 
+        diaElemMenuDynamic menuLanguage(&languageIndex,QT_TRANSLATE_NOOP("adm","_Language"), nbLanguages,
                     languagesMenuItems,NULL);
-//--        
-        
-        
+//--
+
+
 
         /* User Interface */
-        diaElem *diaUser[]={&useSysTray,&menuMessage,&menuLanguage};
-        diaElemTabs tabUser(QT_TRANSLATE_NOOP("adm","User Interface"),3,diaUser);
-        
+        diaElem *diaUser[]={&menuMessage,&menuLanguage,&resetEncoder,&enableAltShortcuts,&swapUpDownKeys,&checkForUpdate};
+        diaElemTabs tabUser(QT_TRANSLATE_NOOP("adm","User Interface"),6,diaUser);
+
          /* Automation */
-        
-        
+
+
         /* Output */
-        diaElem *diaOutput[]={&autoSplit,&openDml,&allowAnyMpeg,&togTagMp3};
-        diaElemTabs tabOutput(QT_TRANSLATE_NOOP("adm","Output"),4,(diaElem **)diaOutput);
-        
+        diaElem *diaOutput[]={&autoSplit,&openDml,&allowAnyMpeg,&togTagMp3,&useLastReadAsTarget};
+        diaElemTabs tabOutput(QT_TRANSLATE_NOOP("adm","Output"),5,(diaElem **)diaOutput);
+
         /* Audio */
 
 #if 0 //defined(ALSA_SUPPORT)
@@ -442,74 +457,99 @@ std::string currentSdlDriver=getSdlDriverName();
         diaElemTabs tabAudio(QT_TRANSLATE_NOOP("adm","Audio"),2,(diaElem **)diaAudio);
 #endif
 
-        
-        /* Display */
-        diaElemToggle togDisplayRefreshCap(&refreshCapEnabled,"_Limit Refresh Rate");
-        diaElemUInteger displayRefreshCap(&refreshCapValue,"Refresh Rate Cap (ms)",10,1000);
 
-            
+        /* Display */
+        diaElemToggle togDisplayRefreshCap(&refreshCapEnabled,QT_TRANSLATE_NOOP("adm","_Limit Refresh Rate"));
+        diaElemUInteger displayRefreshCap(&refreshCapValue,QT_TRANSLATE_NOOP("adm","Refresh Rate Cap (ms)"),10,1000);
+        diaElemFrame frameRC(QT_TRANSLATE_NOOP("adm","GUI Rendering Options")); // a hack to fix tabbing order
+
+        // Packing the following elements into frameRC rectifies otherwise wrong tabbing order:
+        // framePP got constructed before the refresh rate spinbox, but after the display refresh
+        // toggle resulting in a tabbing order 1-6-7-2-3-4-5-8, counting elements from top to bottom.
+        // With this extra frame we get 1-2-3-4-5-6-7-8 (video mode, hor. deblocking, vert. delocking,
+        // deringing, deringing strength, OpenGL toggle, refr. rate cap toggle, refr. rate spinbox).
+        frameRC.swallow(&useOpenGl);
+        frameRC.swallow(&togDisplayRefreshCap);
+        frameRC.swallow(&displayRefreshCap);
+
 #ifdef USE_SDL
-        diaElem *diaVideo[]={&menuVideoMode,sdlMenu,&framePP,&useOpenGl,&togDisplayRefreshCap,&displayRefreshCap};
+        diaElem *diaVideo[]={&menuVideoMode,sdlMenu,&framePP,&frameRC};
 #else
-         diaElem *diaVideo[]={&menuVideoMode,&framePP,&useOpenGl,&togDisplayRefreshCap,&displayRefreshCap};
+        diaElem *diaVideo[]={&menuVideoMode,&framePP,&frameRC};
 #endif
         diaElemTabs tabVideo(QT_TRANSLATE_NOOP("adm","Display"),sizeof(diaVideo)/sizeof(diaElem *),(diaElem **)diaVideo);
         /* HW accel */
-          diaElem *diaHwDecoding[]={&useVdpau,&useXvba,&useLibVA,&hwAccelText};
-          diaElemTabs tabHwDecoding(QT_TRANSLATE_NOOP("adm","HW Accel"),4,(diaElem **)diaHwDecoding);
-        
+        diaElem *diaHwDecoding[]={&useVdpau,&useXvba,&useLibVA,&useDxva2,&hwAccelText};
+        diaElemTabs tabHwDecoding(QT_TRANSLATE_NOOP("adm","HW Accel"),5,(diaElem **)diaHwDecoding);
+
         /* CPU tab */
-		diaElem *diaCpu[]={&frameSimd};
-		diaElemTabs tabCpu(QT_TRANSLATE_NOOP("adm","CPU"),1,(diaElem **)diaCpu);
+        diaElem *diaCpu[]={&frameSimd};
+        diaElemTabs tabCpu(QT_TRANSLATE_NOOP("adm","CPU"),1,(diaElem **)diaCpu);
 
         /* Threading tab */
-		diaElem *diaThreading[]={&frameThread, &framePriority};
-		diaElemTabs tabThreading(QT_TRANSLATE_NOOP("adm","Threading"),2,(diaElem **)diaThreading);
+        diaElem *diaThreading[]={&frameThread, &framePriority};
+        diaElemTabs tabThreading(QT_TRANSLATE_NOOP("adm","Threading"),2,(diaElem **)diaThreading);
 
-		/* Avisynth tab */
-		diaElemToggle togAskAvisynthPort(&askPortAvisynth,"_Always ask which port to use");
-		diaElemUInteger uintDefaultPortAvisynth(&defaultPortAvisynth,"Default port to use",1024,65535);
-		diaElem *diaAvisynth[]={&togAskAvisynthPort, &uintDefaultPortAvisynth};
-		diaElemTabs tabAvisynth("Avisynth",2,(diaElem **)diaAvisynth);
+        /* Avisynth tab */
+        diaElemToggle togAskAvisynthPort(&askPortAvisynth,QT_TRANSLATE_NOOP("adm","_Always ask which port to use"));
+        diaElemUInteger uintDefaultPortAvisynth(&defaultPortAvisynth,QT_TRANSLATE_NOOP("adm","Default port to use"),1024,65535);
+        diaElem *diaAvisynth[]={&togAskAvisynthPort, &uintDefaultPortAvisynth};
+        diaElemTabs tabAvisynth("Avisynth",2,(diaElem **)diaAvisynth);
 
         /* Global Glyph tab */
 
-                                    
-// SET
-                int extra=0;
-#ifdef __linux__
-              extra++;  
-#endif
+
                 diaElemTabs *tabs[]={&tabUser,&tabOutput,&tabAudio,&tabVideo,
-#ifdef __linux__                
-                                &tabHwDecoding,
+                                &tabHwDecoding,  &tabCpu,&tabThreading, &tabAvisynth};
+                
+       void *factoryCookiez=diaFactoryRunTabsPrepare(QT_TRANSLATE_NOOP("adm","Preferences"),8,tabs);
+
+// Now we can disable stuff if needed
+  
+#ifndef USE_DXVA2
+       useDxva2.enable(false);       
 #endif
-                                &tabCpu,&tabThreading, &tabAvisynth};
-        if( diaFactoryRunTabs(QT_TRANSLATE_NOOP("adm","Preferences"),7+extra,tabs))
+
+#ifndef USE_VDPAU       
+        useVdpau.enable(false);              
+#endif
+#ifndef USE_XVBA
+        useXvba.enable(false);              
+#endif
+#ifndef USE_LIBVA
+        useLibVA.enable(false);              
+#endif
+      
+#ifndef  USE_OPENGL
+        useOpenGl.enable(false);
+#endif
+        if( diaFactoryRunTabsFinish(factoryCookiez))
 	{
         	//
 #ifdef USE_OPENGL
             prefs->set(FEATURES_ENABLE_OPENGL,hasOpenGl);
 #endif
     // cpu caps
+            uint32_t cpuMaskOut;
             if(capsAll)
             {
-                    CpuCaps::myCpuMask=ADM_CPUCAP_ALL;
+                    cpuMaskOut=ADM_CPUCAP_ALL;
             }else
             {
-                    CpuCaps::myCpuMask=0;
+                    cpuMaskOut=0;
     #undef CPU_CAPS
-    #define CPU_CAPS(x)    	if(caps##x) CpuCaps::myCpuMask|= ADM_CPUCAP_##x;        	    	
-            CPU_CAPS(MMX);
-            CPU_CAPS(MMXEXT);
-            CPU_CAPS(3DNOW);
-            CPU_CAPS(3DNOWEXT);
-            CPU_CAPS(SSE);
-            CPU_CAPS(SSE2);
-            CPU_CAPS(SSE3);
-            CPU_CAPS(SSSE3);
+    #define CPU_CAPS(x)    	if(caps##x) cpuMaskOut|= ADM_CPUCAP_##x;
+                    CPU_CAPS(MMX);
+                    CPU_CAPS(MMXEXT);
+                    CPU_CAPS(3DNOW);
+                    CPU_CAPS(3DNOWEXT);
+                    CPU_CAPS(SSE);
+                    CPU_CAPS(SSE2);
+                    CPU_CAPS(SSE3);
+                    CPU_CAPS(SSSE3);
             }
-            prefs->set(FEATURES_CPU_CAPS,CpuCaps::myCpuMask);
+            prefs->set(FEATURES_CPU_CAPS,cpuMaskOut);
+            CpuCaps::setMask(cpuMaskOut);
             //
             prefs->set(FEATURES_CAP_REFRESH_ENABLED,refreshCapEnabled);
             prefs->set(FEATURES_CAP_REFRESH_VALUE,refreshCapValue);
@@ -549,6 +589,9 @@ std::string currentSdlDriver=getSdlDriverName();
 #endif
             // allow non std audio fq for dvd
             prefs->set(FEATURES_MPEG_NO_LIMIT, mpeg_no_limit);
+            //
+
+            prefs->set(UPDATE_ENABLED,doAutoUpdate);
             // Video render
             prefs->set(VIDEODEVICE,render);
             // Odml
@@ -569,33 +612,41 @@ std::string currentSdlDriver=getSdlDriverName();
             prefs->set(FEATURES_SWAP_IF_A_GREATER_THAN_B, useSwap);
             //
             prefs->set(MESSAGE_LEVEL,msglevel);
-            // Use tray while encoding
-            prefs->set(FEATURES_USE_SYSTRAY,useTray);
+            // Discard changes to output config on video load
+            prefs->set(RESET_ENCODER_ON_VIDEO_LOAD, loadDefault);
 
             // VDPAU
             prefs->set(FEATURES_VDPAU,bvdpau);
+            // DXVA2
+            prefs->set(FEATURES_DXVA2,bdxva2);
             // XVBA
             prefs->set(FEATURES_XVBA,bxvba);
             // LIBVA
             prefs->set(FEATURES_LIBVA,blibva);
             // Alternate mp3 tag (haali)
             prefs->set(FEATURES_ALTERNATE_MP3_TAG,balternate_mp3_tag);
+            // Make users happy who prefer the output dir to be the same as the input dir
+            prefs->set(FEATURES_USE_LAST_READ_DIR_AS_TARGET,lastReadDirAsTarget);
+            // Enable alternate keyboard shortcuts
+            prefs->set(KEYBOARD_SHORTCUTS_USE_ALTERNATE_KBD_SHORTCUTS,altKeyboardShortcuts);
+            // Allow to use the UP key to navigate back, DOWN to navigate forward
+            prefs->set(KEYBOARD_SHORTCUTS_SWAP_UP_DOWN_KEYS,swapUpDown);
 
-            prefs->set(DEFAULT_LANGUAGE,myLanguages[languageIndex].lang);
+            prefs->set(DEFAULT_LANGUAGE,std::string(myLanguages[languageIndex].lang));
 
             // Avisynth
             prefs->set(AVISYNTH_AVISYNTH_DEFAULTPORT,defaultPortAvisynth);
             prefs->set(AVISYNTH_AVISYNTH_ALWAYS_ASK, askPortAvisynth);
 
                 // Initialise SDL again as driver may have changed
-#ifdef USE_SDL                
+#ifdef USE_SDL
             std::string driverName=listOfSdl[sdlMenuIndex].driverName;
             setSdlDriverByName(driverName);
             prefs->set(FEATURES_SDLDRIVER,driverName.c_str());
-#endif    
+#endif
 	}
 #ifdef USE_SDL
-        if(sdlMenu) 
+        if(sdlMenu)
         {
             if(nbSDL&&sdlMenuEntries)
             {
@@ -609,10 +660,10 @@ std::string currentSdlDriver=getSdlDriverName();
             delete sdlMenu;
             sdlMenu=NULL;
         }
-#endif                
+#endif
         for(int i=0;i<nbAudioDevice+1;i++)
         {
-            
+
             delete audioDeviceItems[i];
         }
         delete [] audioDeviceItems;
@@ -636,4 +687,4 @@ void setpp(void)
         }
 //	video_body->setPostProc(type, strength, uv);
 }
-//EOF 
+//EOF
