@@ -17,7 +17,6 @@
 #ifndef ADM_SEGMENT_H
 #define ADM_SEGMENT_H
 #include <vector>
-#include <list>
 class ADM_audioStream;
 class ADM_Audiocodec;
 class decoders;
@@ -100,14 +99,24 @@ public:
     \brief The video is a collection of segment.
             Each segment refers to its source (the reference) and the part of the source the segment is made of.
 */
+
+
 class _SEGMENT
 {
+public:
+  typedef enum
+  {
+    ADM_NO_DROP                 =0,
+    ADM_DROPPING                =2,
+    ADM_DROP_MAYBE_AFER_SWITCH  =1
+  }SegState;
+  
 public:
         uint32_t _reference; /// Reference video
         uint64_t _refStartTimeUs; /// Starting time in reference
         uint64_t _startTimeUs; /// Start time in current (=sum(_duration of previous seg))
         uint64_t _durationUs; ///
-        uint32_t _dropBframes;
+        SegState _dropBframes; /// Internal state machine to know is we should drop bframe that are orphean
         uint64_t _refStartDts;
         void clear(void) 
         {
@@ -115,7 +124,7 @@ public:
             _refStartTimeUs=0;
             _startTimeUs=0;
             _durationUs=0;
-            _dropBframes=0;
+            _dropBframes=ADM_NO_DROP;
             _refStartDts=0;
         }
         _SEGMENT() {clear();}
@@ -134,7 +143,6 @@ class ADM_EditorSegment
 protected:
         ListOfSegments segments;
         ListOfSegments clipboard;
-        std::list <ListOfSegments> undoSegments;
         ListOfVideos   videos;
         bool           updateStartTime(void);
 
@@ -152,7 +160,6 @@ public:
             bool        updateRefVideo(void);
             bool        deleteAll(void);
 
-            bool        undo(void);
             bool        resetSegment(void);
             bool        deleteSegments(void);
             bool        addSegment(_SEGMENT *seg);
@@ -166,6 +173,9 @@ public:
             _SEGMENT    *getSegment(int i);
             int         getNbSegments(void);
 
+            ListOfSegments getSegments(void);
+            bool        setSegments(ListOfSegments segm);
+
             uint64_t    getTotalDuration(void);
             uint32_t    getNbFrames(void);
 
@@ -179,13 +189,16 @@ public:
             bool        isKeyFrameByTime(uint32_t refVideo,uint64_t seekTime);
 
             bool        removeChunk(uint64_t from, uint64_t to);
+            bool        truncateVideo(uint64_t from);
             bool        dtsFromPts(uint32_t refVideo,uint64_t pts,uint64_t *dts);
 
             bool        LinearToRefTime(int segNo,uint64_t linear,uint64_t *refTime);
             
             bool        copyToClipBoard(uint64_t startTime, uint64_t endTime);
             bool        pasteFromClipBoard(uint64_t currentTime);
+            bool        appendFromClipBoard(void);
             bool        dumpClipBoard();
+            bool        clipboardEmpty(void);
 protected:
             void        dumpSegmentsInternal(ListOfSegments &l);
 };
