@@ -68,8 +68,8 @@ bool ADM_Composer::checkCutsAreOnIntra(void)
         // After a seg switch we are at the keyframe before or equal to where we want to go
         // if the dts do not match, it means we went back too much
         // When re-encoding, it's not a problem, it is when copying.
-        ADM_info("seg:%d refDTS=%"PRIu64"\n",seg->_reference,seg->_refStartDts);
-        ADM_info("seg:%d imgDTS=%"PRIu64"\n",seg->_reference,img.demuxerDts);
+        ADM_info("seg:%d refDTS=%" PRIu64"\n",seg->_reference,seg->_refStartDts);
+        ADM_info("seg:%d imgDTS=%" PRIu64"\n",seg->_reference,img.demuxerDts);
         if(!seg->_refStartDts && !seg->_reference)
         {
             ADM_info("Ignoring first seg (unreliable DTS)\n");
@@ -95,9 +95,95 @@ bool ADM_Composer::checkCutsAreOnIntra(void)
 */
 static bool bFrameDroppable(uint32_t fcc)
 {
-    if(isH264Compatible(fcc)) return false;
+    if(isH264Compatible(fcc)) 
+      return false;
+    if(isH265Compatible(fcc)) 
+      return false;    
     return true;
 }
+/**
+ * 
+ * @param time
+ * @param delay
+ * \brief for x264/x265 we dont want to drop the non closed gop bframe(s)
+ * They will be decoded after our first intra but shown before. 
+ * They are needed because they might be used as reference for later frames.
+ * 
+ * For older codec (mpeg4 ASP, Mpeg1,...) these bframes can be just dropped.
+ * 
+ * This function tries to find out the maximum delay we must add
+ * so that the overall PTS of these frames dont get negative.
+ * @return 
+ */
+bool        ADM_Composer::getNonClosedGopDelay(uint64_t time,uint32_t *delay)
+{
+  aviInfo    info;
+  uint32_t   segNo;
+  uint64_t   segTime;
+    *delay=0;
+    if(!_segments.convertLinearTimeToSeg(time,&segNo,&segTime))
+      {
+        ADM_warning("Cannot navigate to get nonclosedgop\n");
+        return false;
+      }
+   _SEGMENT *seg=_segments.getSegment(segNo);
+    ADM_assert(seg);
+   _VIDEOS *vid=_segments.getRefVideo(seg->_reference);   
+   uint64_t pts,dts;
+   
+    vid->_aviheader->getVideoInfo (&info);
+    //
+    if(bFrameDroppable(info.fcc))
+    {
+        return true; // no need to add extra delay
+    }
+    // Look ahead to see if we have some late bframe in the past
+    int nb=vid->_aviheader->getMainHeader ()->dwTotalFrames;
+    int found=-1;
+    if(!segTime)
+    {
+      found=0;
+       vid->_aviheader->getPtsDts(0,&pts,&dts);
+    }
+    else
+        for(int i=0;i<nb;i++)
+        {
+            vid->_aviheader->getPtsDts (i,&pts,&dts);
+            if(pts==segTime)
+              {
+                    found=i;
+                    break;
+              }
+        }
+    if(found==-1)
+      {
+        ADM_warning("Cannot find the frame\n");
+        return false;
+      }
+    for(int i=found+1;i<found+16;i++)
+    {
+            uint32_t flags;
+            vid->_aviheader->getFlags(i,&flags);
+            if(!(flags & AVI_B_FRAME))
+            {
+                ADM_info("Not a bframe, stopping (%d)\n",i-found);
+              break;
+            }
+            vid->_aviheader->getPtsDts(i,&pts,&dts);
+            if(pts<segTime)
+              {
+                ADM_info("frame %d is early \n",i);
+                uint32_t delta=segTime-pts;
+                if(delta>*delay) *delay=delta;
+              }else
+                {
+                    ADM_info("Pts delta = %d\n",(int)(pts-segTime));
+                }
+    }
+    ADM_info("Found maximum non closed gop delay = %d\n",*delay);
+    return true;
+}
+
 /**
         \fn getCompressedPicture
         \brief bypass decoder and directly get the source image
@@ -129,7 +215,7 @@ againGet:
     // Get next pic?
     if(false==demuxer->getFrame (vid->lastSentFrame,img))
     {
-        ADM_info("Failed to get next frame for ref %"PRIu32"\n",seg->_reference);
+        ADM_info("Failed to get next frame for ref %" PRIu32"\n",seg->_reference);
         goto nextSeg;
     }
     aprintf("Got frame %d, PTS=%s  ",img->demuxerFrameNo,ADM_us2plain(img->demuxerPts));
@@ -139,29 +225,29 @@ againGet:
     aviInfo    info;
     vid->_aviheader->getVideoInfo (&info);
     //
+    // after a segment switch, we may have some frames from "the past"
+    // if the cut point is not a keyframe, drop them
+    
     if(bFrameDroppable(info.fcc))
     {
         if(img->flags & AVI_B_FRAME)
         {
-            if(seg->_dropBframes==2) 
+            if(seg->_dropBframes==_SEGMENT::ADM_DROPPING) 
             {
-                ADM_warning("%"PRIu32" Dropping bframes\n",fn);
+                ADM_warning("%" PRIu32" Dropping bframes\n",fn);
                 goto againGet;
             }
         }else
         { // not a bframe
             switch(seg->_dropBframes)
             {
-                case 2: seg->_dropBframes=0;break;
-                case 1: seg->_dropBframes=2;break;
+                case _SEGMENT::ADM_NO_DROP                : break;
+                case _SEGMENT::ADM_DROPPING               : seg->_dropBframes=_SEGMENT::ADM_NO_DROP;break;
+                case _SEGMENT::ADM_DROP_MAYBE_AFER_SWITCH : seg->_dropBframes=_SEGMENT::ADM_DROPPING;break;
                 default: break;
             }
         }
     }
-    //aprintf("Bframe droppable=%d, lastSentFrame=%d\n",seg->_dropBframes,vid->lastSentFrame);
-    // after a segment switch, we may have some frames from "the past"
-    // if the cut point is not a keyframe, drop them
-#if 1
     if( img->demuxerDts!=ADM_NO_PTS)
     {
         bool drop=false;
@@ -174,7 +260,7 @@ againGet:
         }
         // Seeking is not accurate when cutting on non intra
         // we might have some frames that are clearly too early , even in seg0
-        if(img->demuxerPts!=ADM_NO_PTS)
+        if(img->demuxerPts!=ADM_NO_PTS && bFrameDroppable(info.fcc))
         {
             if(img->demuxerPts+seg->_startTimeUs<seg->_refStartTimeUs)
             {
@@ -188,7 +274,7 @@ againGet:
             goto againGet;
         
     }
-#endif
+
     // Need to switch seg ?
     tail=seg->_refStartTimeUs+seg->_durationUs;
     // Guess DTS
@@ -232,11 +318,11 @@ againGet:
 	// border case due to rounding we can have pts slighly above dts
 	if(signedPts!=ADM_NO_PTS && _nextFrameDts!=ADM_NO_PTS)
 	{
-                signedDts=_nextFrameDts;
-                if(signedPts != ADM_NO_PTS && signedDts>signedPts)
+        signedDts=_nextFrameDts;
+        if(signedPts != ADM_NO_PTS && signedDts>signedPts)
 		{
 			// not sure it is correct. We may want to do it the other way around, i.e. bumping pts
-			ADM_warning("Compensating for rounding error with PTS=%"PRId64"ms DTS=%"PRId64"ms \n",signedPts,signedDts);
+			ADM_warning("Compensating for rounding error with PTS=%" PRId64"ms DTS=%" PRId64"ms \n",signedPts,signedDts);
                         signedPts=signedDts;
 		}
 	}
@@ -246,10 +332,11 @@ againGet:
 // we add a bit of timeIncrement to compensate for rounding
         if(_nextFrameDts!=ADM_NO_PTS)
         {
-            if(_nextFrameDts>(signedDts+vid->timeIncrementInUs/10))
+            if(_nextFrameDts>(signedDts+(int64_t)(vid->timeIncrementInUs/10)))
             {
-                ADM_error("Frame %"PRIu32" DTS is going back in time : expected : %"PRId64" ms got : %"PRId64" ms\n",
-                                                fn,_nextFrameDts/1000,signedDts/1000);
+                ADM_error("Frame %d DTS is going back in time : expected:%s ",(int)vid->lastSentFrame, ADM_us2plain(_nextFrameDts));
+                ADM_error("\t got:%s (%ld vs %ld)\n", ADM_us2plain(signedDts),_nextFrameDts,signedDts);
+                goto againGet;
             }
         }
         _nextFrameDts=signedDts;
@@ -264,13 +351,13 @@ againGet:
         int64_t nextDts=nextSeg->_startTimeUs+nextSeg->_refStartDts;
         if(nextDts<nextSeg->_refStartTimeUs)
         {
-            ADM_warning("%"PRIu32" next DTS is negative %"PRIu64" %"PRIu64" ms\n",fn,nextDts,nextSeg->_refStartTimeUs);
+            ADM_warning("%" PRIu32" next DTS is negative %" PRIu64" %" PRIu64" ms\n",fn,nextDts,nextSeg->_refStartTimeUs);
         }else       
         {
             nextDts-=nextSeg->_refStartTimeUs;
             if(signedDts>=nextDts)
             {
-                ADM_warning("%"PRIu32" have to switch segment, DTS limit reached %"PRIu64" %"PRIu64"\n",fn,img->demuxerDts/1000,nextDts/1000);
+                ADM_warning("%" PRIu32" have to switch segment, DTS limit reached %" PRIu64" %" PRIu64"\n",fn,img->demuxerDts/1000,nextDts/1000);
                 goto nextSeg;
             }
         }
@@ -303,7 +390,7 @@ nextSeg:
     }
     // Mark it as drop b frames...
     _SEGMENT *thisseg=_segments.getSegment(_currentSegment);
-    thisseg->_dropBframes=1;
+    thisseg->_dropBframes=_SEGMENT::ADM_DROP_MAYBE_AFER_SWITCH;
     ADM_info("Retrying for next segment\n");
     return getCompressedPicture(videoDelay,img);
    
@@ -327,7 +414,7 @@ bool        ADM_Composer::getDirectImageForDebug(uint32_t frameNum,ADMCompressed
     // Get next pic?
     if(false==demuxer->getFrame (frameNum,img))
     {
-        ADM_info("Failed to get next frame for ref %"PRIu32"\n",seg->_reference);
+        ADM_info("Failed to get next frame for ref %" PRIu32"\n",seg->_reference);
         return false;
     }
    return true;
