@@ -33,10 +33,6 @@
 #include "DIA_coreToolkit.h"
 #include "prefs.h"
 
-#include "ADM_debugID.h"
-#define MODULE_NAME MODULE_EDITOR
-#include "ADM_debug.h"
-
 //#include "ADM_outputfmt.h"
 #include "ADM_edPtsDts.h"
 #include "ADM_vidMisc.h"
@@ -85,7 +81,22 @@ bool        ADM_Composer::pasteFromClipBoard(uint64_t currentTime)
     return _segments.pasteFromClipBoard(currentTime);
     
 }
-
+/**
+    \fn appendFromClipBoard
+    \brief Append the content of the clipboard to the end of the video
+*/
+bool ADM_Composer::appendFromClipBoard(void)
+{
+    return _segments.appendFromClipBoard();
+}
+/**
+    \fn clipboardEmpty
+    \brief Return true if we have nothing to paste or append
+*/
+bool ADM_Composer::clipboardEmpty(void)
+{
+    return _segments.clipboardEmpty();
+}
 /**
     \fn resetSeg
     \brief Redo a 1:1 mapping between ref video and segment
@@ -179,7 +190,7 @@ bool ADM_Composer::addFile (const char *name)
 	if(!video._aviheader)
 	{
 		char str[512+1];
-		snprintf(str,512,QT_TR_NOOP("Cannot find a demuxer for %s"), name);
+		snprintf(str,512,QT_TRANSLATE_NOOP("ADM_Composer","Cannot find a demuxer for %s"), name);
 		str[512] = '\0';
 		GUI_Error_HIG(str,NULL);
 		return false;
@@ -206,7 +217,7 @@ bool ADM_Composer::addFile (const char *name)
 				prefs->set(AVISYNTH_AVISYNTH_LOCALPORT, localPort);
 			}
 		}
-		uint8_t dummy[] = { portValue , portValue >> 8};
+		uint8_t dummy[] = { (uint8_t)portValue ,(uint8_t)( portValue >> 8)};
 		ret = video._aviheader->open((char *)dummy);
 	}
 	else
@@ -215,7 +226,7 @@ bool ADM_Composer::addFile (const char *name)
    // check opening was successful
    if (ret == 0) {
      char str[512+1];
-     snprintf(str,512,QT_TR_NOOP("Attempt to open %s failed!"), name);
+     snprintf(str,512,QT_TRANSLATE_NOOP("ADM_Composer","Attempt to open %s failed!"), name);
       str[512] = '\0';
       GUI_Error_HIG(str,NULL);
       video._aviheader=NULL;
@@ -241,7 +252,7 @@ bool ADM_Composer::addFile (const char *name)
                  (strlen(str)?" and ":""),
                  (strlen(str)?" are ":" is ") );
          str[512] = '\0';
-         GUI_Error_HIG(str,QT_TR_NOOP("You cannot mix different video dimensions yet. Using the partial video filter later, will not work around this problem. The workaround is:\n1.) \"resize\" / \"add border\" / \"crop\" each stream to the same resolution\n2.) concatinate them together"));
+         GUI_Error_HIG(str,QT_TRANSLATE_NOOP("ADM_Composer","You cannot mix different video dimensions yet. Using the partial video filter later, will not work around this problem. The workaround is:\n1.) \"resize\" / \"add border\" / \"crop\" each stream to the same resolution\n2.) concatenate them together"));
          delete video._aviheader;
          return false;
       }
@@ -259,7 +270,6 @@ bool ADM_Composer::addFile (const char *name)
     {
         printf("[Editor]The video codec has some extradata (%d bytes)\n",l);
         mixDump(d,l);
-        printf("\n");
     }
 
   // 1st if it is our first video we update postproc
@@ -343,13 +353,17 @@ bool ADM_Composer::addFile (const char *name)
                 audioTrackPool.addInternalTrack(trackFromVideo);
             }
       }
+      if(!_segments.getNbRefVideos()) // only for 1st video
+      {
         activeAudioTracks.clear();
         for(int i=0;i<nbAStream;i++)
             activeAudioTracks.addTrack(i,audioTrackPool.at(i)); // default add 1st track of video pool
+      }
     }
 
   printf ("[Editor] Decoder FCC: ");
   fourCC::print (info.fcc);
+  printf("\n");
   // ugly hack
   if (info.fps1000 > 2000 * 1000)
     {
@@ -476,7 +490,7 @@ uint32_t ref;
   {
     if(false==_segments.getRefFromTime(time,&ref))
     {
-        ADM_warning("Cannot get ref from time %"PRId64" ms\n",time/1000);
+        ADM_warning("Cannot get ref from time %" PRId64" ms\n",time/1000);
         return false;
     }
     _segments.getRefVideo(ref)->decoder->setParam ();
@@ -525,7 +539,7 @@ uint32_t ref;
 
     if(false==_segments.getRefFromTime(xtime,&ref))
     {
-        ADM_warning("[Editor] getAudioStreamsInfo failed for time %"PRId64" ms\n",xtime);
+        ADM_warning("[Editor] getAudioStreamsInfo failed for time %" PRId64" ms\n",xtime);
         return false;
     }
 
@@ -564,7 +578,7 @@ uint32_t ref;
 
         if(false==_segments.getRefFromTime(xtime,&ref))
         {
-            ADM_warning("[Editor::getCurrentAudioStreamNumber] Cannot get ref video for time %"PRId64" ms\n",xtime/1000);
+            ADM_warning("[Editor::getCurrentAudioStreamNumber] Cannot get ref video for time %" PRId64" ms\n",xtime/1000);
             return 0;
         }
 
@@ -682,6 +696,14 @@ bool            ADM_Composer::remove(uint64_t start,uint64_t end)
 {
     return _segments.removeChunk(start,end);
 }
+/**
+    \fn truncate
+    \brief Truncate video
+*/
+bool ADM_Composer::truncate(uint64_t start)
+{
+    return _segments.truncateVideo(start);
+}
 /**
     \fn dumpEditing
     \brief Dump segment, video & al
@@ -720,7 +742,7 @@ bool               ADM_Composer::dumpTiming(void)
 
             v->_aviheader->getFlags(i,&flags);
             v->_aviheader->getPtsDts(i,&pts,&dts);
-            printf("%"PRIu32" flags:%04"PRIx32" ",i,flags);
+            printf("%" PRIu32" flags:%04" PRIx32" ",i,flags);
             printf("pts :%s ",ADM_us2plain(pts));
             printf("dts :%s \n",ADM_us2plain(dts));
     }
