@@ -14,9 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
-#ifndef T_VDPAURENDER_H
-#define T_VDPAURENDER_H
+#pragma once
 /**
     \fn class XvRender
 */
@@ -36,9 +34,9 @@ class vdpauRender: public VideoRenderBase
               virtual   bool refresh(void);
               virtual   bool usingUIRedraw(void) {return false;}; // we can redraw by ourself
               virtual   ADM_HW_IMAGE getPreferedImage(void ) {return ADM_HW_VDPAU;}
-                        const char *getName() {return "Vdpau";}
+                        const char *getName() {return "VDPAU";}
 };
-#endif
+
 
 
 
