@@ -221,11 +221,12 @@ bool GUIPlayback::initialize(void)
     int nb=videoChain->size();
     videoFilter=(*videoChain)[nb-1];
     FilterInfo *info=videoFilter->getInfo();
+    renderZoom currentZoom=admPreview::getCurrentZoom();
     renderZoom zoom=ZOOM_AUTO;
     // if the video output has same width/height as input, we keep the same zoom
     aviInfo originalVideo;
     video_body->getVideoInfo(&originalVideo);
-    renderZoom currentZoom=admPreview::getCurrentZoom();
+    
     if(info->width==originalVideo.width && info->height==originalVideo.height)
         zoom=currentZoom;
     //
@@ -293,9 +294,13 @@ bool GUIPlayback::run(void)
             {
                 if(stop_req)
                     break;
+                
                 if(delta>10)
                 {
-                    audioPump(true);
+                    if(playbackAudio)
+                        audioPump(true);
+                    else
+                        ADM_usleep(10*1000);
                 }else
                     audioPump(false);
 
@@ -321,8 +326,8 @@ bool  GUIPlayback::audioPump(bool wait)
 {
     uint32_t oaf = 0;
     uint32_t load = 0;
-	uint8_t channels;
-	uint32_t fq;
+    uint8_t channels;
+    uint32_t fq;
     static bool errorMet=false;
 
     if (!playbackAudio)	    return false;
@@ -407,7 +412,7 @@ bool  GUIPlayback::initializeAudio(void)
      audioLatency=latency; // ms -> us
       if (!state)
       {
-          GUI_Error_HIG(QT_TR_NOOP("Trouble initializing audio device"), NULL);
+          GUI_Error_HIG(QT_TRANSLATE_NOOP("adm","Trouble initializing audio device"), NULL);
           cleanupAudio();
           return false;
       }
