@@ -27,7 +27,7 @@ extern const char *shortkey(const char *);
 
 namespace ADM_qt4Factory
 {
-class diaElemFrame : public diaElemFrameBase
+class diaElemFrame : public diaElemFrameBase,QtFactoryUtils
 {
   
 public:
@@ -43,10 +43,9 @@ public:
 };
 
 diaElemFrame::diaElemFrame(const char *toggleTitle, const char *tip)
-  : diaElemFrameBase()
+  : diaElemFrameBase(),QtFactoryUtils(toggleTitle)
 {
   param=NULL;
-  paramTitle=shortkey(toggleTitle);
   this->tip=tip;
    nbElems=0;
   frameSize=0;
@@ -62,14 +61,12 @@ void diaElemFrame::swallow(diaElem *widget)
 }
 diaElemFrame::~diaElemFrame()
 {
-  if(paramTitle)
-    ADM_dealloc(paramTitle);
 }
 
 void diaElemFrame::setMe(void *dialog, void *opaque,uint32_t line)
 {
 	QVBoxLayout *layout = (QVBoxLayout*)opaque;
-	QGroupBox *groupBox = new QGroupBox(QString::fromUtf8(paramTitle));
+	QGroupBox *groupBox = new QGroupBox(myQtTitle);
 	QVBoxLayout *vboxlayout = new QVBoxLayout(groupBox);
 	QLayout *layout2 = NULL;
 	int currentLayout = 0;
