@@ -44,7 +44,7 @@ namespace ADM_Qt4Factory
  *      \class diaElemTimeStamp
  *      \brief Qt4 version of diaElemTimeStamp
  */
-class diaElemTimeStamp : public diaElem
+class diaElemTimeStamp : public diaElem,QtFactoryUtils
 {
   protected :
         uint32_t valueMin;
@@ -64,12 +64,11 @@ public:
  * @param toggleTitle
  */
 diaElemTimeStamp::diaElemTimeStamp(uint32_t *v,const char *toggleTitle,const uint32_t vmin, const uint32_t vmax)
-  : diaElem(ELEM_TIMESTAMP)
+  : diaElem(ELEM_TIMESTAMP),QtFactoryUtils(toggleTitle)
 {
   param=v;
   valueMin=vmin;
   valueMax=vmax;
-  paramTitle=shortkey(toggleTitle);
  }
 /**
  * \fn diaElemTimeStamp
@@ -80,8 +79,6 @@ diaElemTimeStamp::~diaElemTimeStamp()
   myTimeWidget *w=(myTimeWidget *)myWidget;
   myWidget=NULL;
   if(w) delete w;
-  if(paramTitle)
-    ADM_dealloc(paramTitle);
 }
 /**
  * \fn          setMe
@@ -119,9 +116,9 @@ void diaElemTimeStamp::setMe(void *dialog, void *opaque,uint32_t line)
   myTWidget->seconds->setValue(ss);
   myTWidget->mseconds->setValue(msec);
  
- QLabel *text=new QLabel( QString::fromUtf8(this->paramTitle),(QWidget *)dialog);
+ QLabel *text=new QLabel(myQtTitle,(QWidget *)dialog);
  text->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-// text->setBuddy(box);
+ text->setBuddy(myTWidget->hours);
 
  QSpacerItem *spacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
 
