@@ -32,14 +32,9 @@ Ui_aboutWindow::Ui_aboutWindow(QWidget* parent) : QDialog(parent)
 
 	char subversion[128]={0};
 #if defined(ADM_SUBVERSION)
-        int l=strlen(ADM_SUBVERSION);
-        if(l>1)
-        {
-                sprintf(subversion,"%s <br><small>(%s)</small>", ADM_VERSION, ADM_SUBVERSION);// 
-        }else
-        {
-                sprintf(subversion,"%s - Release",ADM_VERSION);
-        }
+        sprintf(subversion,"%s <br><small>(%s-fflibs %s)</small>", ADM_VERSION, ADM_SUBVERSION, ADM_FFMPEG_VERSION);
+#else
+        sprintf(subversion,"%s - Release",ADM_VERSION);
 #endif
         QString  sv(subversion);
         ui.versionLabel->setTextFormat(Qt::RichText);
