@@ -47,6 +47,8 @@ using std::string;
 #include "ADM_edScriptGenerator.h"
 #include "DIA_fileSel.h"
 #include "ADM_script2/include/ADM_script.h"
+
+#include <QMenu>
 /*******************************************************/
 #define NB_TREE 8
 #define myFg 0xFF
@@ -61,6 +63,7 @@ using std::string;
 /*******************************************************/
 #define zprintf(...) {}
 //#define NO_DELEGATE
+#define LABEL_SECURITY_MARGIN 6
 
 extern ADM_Composer *video_body;
 
@@ -77,7 +80,6 @@ bool FilterItemEventFilter::eventFilter(QObject *object, QEvent *event)
     zprintf("Parent : %p\n",parent());
 #if !defined(NO_EVENT_FILTER)
     QListWidget *list=qobject_cast<QListWidget*>(parent());
-    QAbstractItemView *view = qobject_cast<QAbstractItemView*>(parent());
     //printf("Event %d\n",event->type());
     switch(event->type())
     {
@@ -117,17 +119,28 @@ void FilterItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
     QAbstractItemView *view = qobject_cast<QAbstractItemView*>(parent());
     QLabel *label;
 
+    int scrollbarWidth = qApp->style()->pixelMetric(QStyle::PM_ScrollBarExtent);
+    int width=qobject_cast<QWidget*>(view)->width();
+    width -= scrollbarWidth;
+    width -= LABEL_SECURITY_MARGIN;
+
     if (view->indexWidget(index) == 0)
     {
             label = new QLabel();
             label->installEventFilter(filter);
             label->setAutoFillBackground(true);
             label->setFocusPolicy(Qt::TabFocus);
+            label->setMargin(2);
+            label->setWordWrap(true);
             label->setText(index.data().toString());
             view->setIndexWidget(index, label);
     }
 
     label = (QLabel*)view->indexWidget(index);
+    // If label width exceeds the width of the viewport, labels get sometimes painted
+    // over other widgets, especially bad on Windows, where they overlay scrollbars.
+    // Set the width to a fixed value small enough to avoid horizontal scrolling.
+    label->setFixedWidth(width);
 
     if (option.state & QStyle::State_Selected)
             if (option.state & QStyle::State_HasFocus)
@@ -157,12 +170,13 @@ void filtermainWindow::preview(bool b)
      ADM_coreVideoFilter     *filter=ADM_vf_getInstance(itag);
      ADM_assert(filter);
     if (previewDialog)
-            previewDialog->resetVideoStream(filter);
-    else
     {
-        previewDialog = new Ui_seekablePreviewWindow(this, filter, 0);
-        connect(previewDialog, SIGNAL(accepted()), this, SLOT(closePreview()));
+            delete previewDialog;
+            previewDialog=NULL;
     }
+    previewDialog = new Ui_seekablePreviewWindow(this, filter, 0);
+    previewDialog->setModal(true);
+    connect(previewDialog, SIGNAL(accepted()), this, SLOT(closePreview()));
     previewDialog->show();
 }
 /**
@@ -301,6 +315,35 @@ void filtermainWindow::moveUp( )
     buildActiveFilterList ();
     setSelected(itag-1);
 }
+/**
+ * 
+ */
+void filtermainWindow::makePartial()
+{
+    ADM_info("Partial\n");
+    int filterIndex=getTagForActiveSelection();
+    if(-1==filterIndex)
+        return;
+    ADM_info("Partial %d\n",filterIndex);
+    // Check we can partialize it...
+    uint32_t tag=ADM_vf_getTag(filterIndex);
+    if(!ADM_vf_canBePartialized(tag))
+    {
+        GUI_Error_HIG(QT_TRANSLATE_NOOP("qmainfilter","Partial"),QT_TRANSLATE_NOOP("qmainfilter","This filter cannot be made partial"));
+        return;
+    }
+    // Get info about that filter..
+    if(ADM_vf_partialize(filterIndex))
+    {
+        ADM_info("Partializing done, rebuilding \n");
+        buildActiveFilterList ();
+        setSelected(filterIndex);
+    }else
+      {
+        ADM_info("CANCEL \n");
+      }
+}
+
 /**
         \fn     down( bool b)
         \brief  Move selected filter one place down
@@ -337,6 +380,34 @@ void filtermainWindow::filterFamilyClick(int  m)
             displayFamily(m);
 
 }
+
+/**
+    \fn calculateListItemHeight
+ */
+int filtermainWindow::calculateListItemHeight(QListWidget *parent, QString text)
+{
+    QLabel *dummy=new QLabel();
+
+    int width=parent->frameSize().width();
+    int scrollbarWidth = qApp->style()->pixelMetric(QStyle::PM_ScrollBarExtent);
+    width -= scrollbarWidth;
+    width -= LABEL_SECURITY_MARGIN;
+    dummy->setFixedWidth(width);
+    dummy->setMargin(2);
+    dummy->setWordWrap(true);
+    dummy->setText(text);
+
+    QFont fnt=dummy->font();
+    QFontMetrics fm(fnt);
+    int height=fm.boundingRect(0, 0, width, dummy->height(), Qt::TextWordWrap | Qt::AlignLeft, text).height();
+    if(height < (fm.lineSpacing() * 2))
+        height=fm.lineSpacing() * 2;
+    height += 8; // the height might be insufficient at very small font sizes
+    delete dummy;
+    dummy=NULL;
+    return height;
+}
+
 /**
  * \fn displayFamily
  * @param family
@@ -347,7 +418,6 @@ void filtermainWindow::displayFamily(uint32_t family)
 
   uint32_t nb=ADM_vf_getNbFiltersInCategory((VF_CATEGORY)family);
   ADM_info("Video filter Family :%u, nb %d\n",family,nb);
-  QSize sz;
   availableList->clear();
   for (uint32_t i = 0; i < nb; i++)
     {
@@ -358,7 +428,7 @@ void filtermainWindow::displayFamily(uint32_t family)
 
           QListWidgetItem *item;
           item=new QListWidgetItem(str,availableList,ALL_FILTER_BASE+i+family*100);
-          item->setToolTip(desc);
+          item->setSizeHint(QSize(availableList->frameSize().width(),calculateListItemHeight(availableList,str)));
           availableList->addItem(item);
      }
 
@@ -412,10 +482,75 @@ void filtermainWindow::buildActiveFilterList(void)
         QString str = QString("<b>") + name + QString("</b><br>\n<small>") + conf + QString("</small>");
         QListWidgetItem *item=new QListWidgetItem(str,activeList,ACTIVE_FILTER_BASE+i);
         printf("Active item :%p\n",item);
+        item->setSizeHint(QSize(item->sizeHint().width(),calculateListItemHeight(activeList,str)));
         activeList->addItem(item);
     }
 
 }
+
+/**
+    \fn activeListContextMenu
+*/
+void filtermainWindow::activeListContextMenu(const QPoint &pos)
+{
+    QMenu *cm=new QMenu();
+
+    QAction *up = new QAction(QString(QT_TRANSLATE_NOOP("qmainfilter","Move up")),this);
+    QAction *down = new QAction(QString(QT_TRANSLATE_NOOP("qmainfilter","Move down")),this);
+    QAction *configure = new QAction(QString(QT_TRANSLATE_NOOP("qmainfilter","Configure")),this);
+    QAction *remove = new QAction(QString(QT_TRANSLATE_NOOP("qmainfilter","Remove")),this);
+    QAction *partial = new QAction(QString(QT_TRANSLATE_NOOP("qmainfilter","Make partial")),this);
+
+    cm->addAction(up);
+    cm->addAction(down);
+    cm->addAction(configure);
+    cm->addAction(remove);
+    cm->addAction(partial);
+
+    connect(up,SIGNAL(triggered()),this,SLOT(moveUp()));
+    connect(down,SIGNAL(triggered()),this,SLOT(moveDown()));
+    connect(configure,SIGNAL(triggered()),this,SLOT(configureAction()));
+    connect(remove,SIGNAL(triggered()),this,SLOT(removeAction()));
+    connect(partial,SIGNAL(triggered()),this,SLOT(makePartial()));
+
+    updateContextMenu(cm);
+    cm->exec(activeList->viewport()->mapToGlobal(pos));
+}
+
+/**
+    \fn updateContextMenu
+    \brief Disable not applicable entries in the active filters context menu
+*/
+void filtermainWindow::updateContextMenu(QMenu *contextMenu)
+{
+    if(!nb_active_filter)
+        return;
+    if(!contextMenu->actions().size())
+        return;
+    bool canMoveUp=true;
+    bool canMoveDown=true;
+    bool canPartialize=true;
+    QListWidgetItem *item=activeList->currentItem();
+    if(!item)
+        return;
+
+    int itag=item->type();
+    ADM_assert(itag>=ACTIVE_FILTER_BASE);
+    itag -= ACTIVE_FILTER_BASE;
+    uint32_t tag=ADM_vf_getTag(itag);
+    canPartialize=ADM_vf_canBePartialized(tag);
+
+    int row=item->listWidget()->row(item);
+    if(!row)
+        canMoveUp=false;
+    if(row==nb_active_filter-1)
+        canMoveDown=false;
+
+    contextMenu->actions().at(0)->setEnabled(canMoveUp);
+    contextMenu->actions().at(1)->setEnabled(canMoveDown);
+    contextMenu->actions().at(4)->setEnabled(canPartialize);
+}
+
   /**
   */
 filtermainWindow::filtermainWindow(QWidget* parent) : QDialog(parent)
@@ -450,7 +585,7 @@ filtermainWindow::filtermainWindow(QWidget* parent) : QDialog(parent)
     connect(ui.buttonClose, SIGNAL(clicked(bool)), this, SLOT(accept()));
     connect(ui.pushButtonPreview, SIGNAL(clicked(bool)), this, SLOT(preview(bool)));
 
-
+    qobject_cast<QAbstractScrollArea*>(availableList)->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     availableList->setItemDelegate(new FilterItemDelegate(availableList));
 
     displayFamily(0);
@@ -463,27 +598,13 @@ filtermainWindow::filtermainWindow(QWidget* parent) : QDialog(parent)
     //____________________
     //  Context Menu
     //____________________
-    QAction *add = new  QAction(QString("Add"),this);
+    QAction *add = new  QAction(QString(QT_TRANSLATE_NOOP("qmainfilter","Add")),this);
     availableList->setContextMenuPolicy(Qt::ActionsContextMenu);
     availableList->addAction(add );
-    connect(add,SIGNAL(activated()),this,SLOT(addSlot()));
-    
-    
-    QAction *remove = new  QAction(QString("Remove"),this);
-    QAction *configure = new  QAction(QString("Configure"),this);
-    QAction *up = new  QAction(QString("Move up"),this);
-    QAction *down = new  QAction(QString("Move down"),this);
-    
-    activeList->setContextMenuPolicy(Qt::ActionsContextMenu);
-    activeList->addAction(up);
-    activeList->addAction(down);
-    activeList->addAction(configure);
-    activeList->addAction(remove);
-    
-    connect(remove,SIGNAL(triggered()),this,SLOT(removeAction()));
-    connect(configure,SIGNAL(triggered()),this,SLOT(configureAction()));
-    connect(up,SIGNAL(triggered()),this,SLOT(moveUp()));
-    connect(down,SIGNAL(triggered()),this,SLOT(moveDown()));
+    connect(add,SIGNAL(triggered(bool )),this,SLOT(addSlot()));
+
+    activeList->setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(activeList,SIGNAL(customContextMenuRequested(const QPoint &)),this,SLOT(activeListContextMenu(const QPoint &)));
 
  }
 /**
@@ -549,7 +670,7 @@ void filtermainWindow::loadFilters( bool b)
 
     char name[1024];
 
-    if(!FileSel_SelectRead(QT_TR_NOOP("Load video filters.."),name,1023,NULL))
+    if(!FileSel_SelectRead(QT_TRANSLATE_NOOP("qmainfilter","Load video filters.."),name,1023,NULL))
         return;
     call_scriptEngine(name);
     buildActiveFilterList();
@@ -564,7 +685,7 @@ void filtermainWindow::saveFilters( bool b)
     printf("save filters\n");
     char name[1024];
 
-    if(!FileSel_SelectWrite(QT_TR_NOOP("Save video filters.."),name,1023,NULL))
+    if(!FileSel_SelectWrite(QT_TRANSLATE_NOOP("qmainfilter","Save video filters.."),name,1023,NULL))
         return;
     printf("save filters, part 2\n");
     IScriptEngine *engine=getPythonScriptEngine();
