@@ -48,27 +48,27 @@ void MainWindow::addScriptEnginesToFileMenu(vector<MenuEntry>& fileMenu)
 
                 if (this->_scriptEngines.size() == 1)
                 {
-                    itemName = "Project Script";
+                    itemName = QT_TRANSLATE_NOOP("qgui2menu","Project Script");
                 }
                 else
                 {
-                    itemName = this->_scriptEngines[engineIndex]->name() + " Project";
+                    itemName = this->_scriptEngines[engineIndex]->name() + QT_TRANSLATE_NOOP("qgui2menu"," Project");
                 }
 
                 MenuEntry dummyEntry = {MENU_SUBMENU, itemName, NULL, ACT_DUMMY, NULL, NULL};
                 it = fileMenu.insert(it, dummyEntry);
 
-                MenuEntry runProjectEntry = {MENU_SUBACTION, "&Run Project...", NULL, firstMenuId, NULL, NULL};
+                MenuEntry runProjectEntry = {MENU_SUBACTION, QT_TRANSLATE_NOOP("qgui2menu","&Run Project..."), NULL, firstMenuId, NULL, NULL};
                 it = fileMenu.insert(it + 1, runProjectEntry);
 
                 if ((this->_scriptEngines[engineIndex]->capabilities() & IScriptEngine::Debugger) == IScriptEngine::Debugger)
                 {
-                    MenuEntry debugEntry = {MENU_SUBACTION, "&Debug Project...", NULL, (Action)(firstMenuId + 1), NULL, NULL};
+                    MenuEntry debugEntry = {MENU_SUBACTION, QT_TRANSLATE_NOOP("qgui2menu","&Debug Project..."), NULL, (Action)(firstMenuId + 1), NULL, NULL};
                     it = fileMenu.insert(it + 1, debugEntry);
                     i++;
                 }
 
-                MenuEntry saveAsProjectEntry = {MENU_SUBACTION, "Save &As Project...", NULL, (Action)(firstMenuId + 2), NULL, NULL};
+                MenuEntry saveAsProjectEntry = {MENU_SUBACTION, QT_TRANSLATE_NOOP("qgui2menu","Save &As Project..."), NULL, (Action)(firstMenuId + 2), NULL, NULL};
                 it = fileMenu.insert(it + 1, saveAsProjectEntry);
                 i += 3;
             }
@@ -88,11 +88,11 @@ void MainWindow::addScriptShellsToToolsMenu(vector<MenuEntry>& toolMenu)
 
         if (this->_scriptEngines.size() == 1)
         {
-            itemName = "Scripting Shell";
+            itemName = QT_TRANSLATE_NOOP("qgui2menu","Scripting Shell");
         }
         else
         {
-            itemName = this->_scriptEngines[engineIndex]->name() + " Shell";
+            itemName = this->_scriptEngines[engineIndex]->name() + QT_TRANSLATE_NOOP("qgui2menu"," Shell");
         }
 
         MenuEntry entry = {MENU_ACTION, itemName, NULL, (Action)(ACT_SCRIPT_ENGINE_SHELL_FIRST + engineIndex), NULL, NULL};
@@ -114,11 +114,11 @@ void MainWindow::addScriptReferencesToHelpMenu()
         {
             if (this->_scriptEngines.size() == 1)
             {
-                itemName = "Scripting Reference";
+                itemName = QT_TRANSLATE_NOOP("qgui2menu","Scripting Reference");
             }
             else
             {
-                itemName = this->_scriptEngines[engineIndex]->name() + " Reference";
+                itemName = this->_scriptEngines[engineIndex]->name() + QT_TRANSLATE_NOOP("qgui2menu"," Reference");
             }
 
             FileAction *action = new FileAction(
@@ -190,6 +190,7 @@ void MainWindow::scriptFileActionHandler()
             printf("Executing %s with %s engine\n", filePath.toUtf8().constData(), this->_scriptEngines[engineIndex]->name().c_str());
 
             A_parseScript(this->_scriptEngines[engineIndex], filePath.toUtf8().constData());
+            A_Resync();
         }
     }
 }
@@ -211,17 +212,19 @@ void MainWindow::buildCustomMenu(void)
 
     this->addScriptDirToMenu(ui.menuCustom, ADM_getCustomDir(), fileExts);
     this->addScriptDirToMenu(ui.menuAuto, ADM_getAutoDir(), fileExts);
+    buildActionLists(); // since we change the menu, the list of stuff needs to be refreshed else it points to deleted items
+
 }
 
-void MainWindow::buildRecentMenu(QMenu *menu, const char **files, QAction **actions)
+void MainWindow::buildRecentMenu(QMenu *menu, std::vector<std::string>files, QAction **actions)
 {
 	menu->clear();
 
 	for (int i = 0; i < NB_LAST_FILES; i++)
 	{
-		if (files[i])
+		if (files[i].size())
 		{
-			actions[i] = menu->addAction(QString('0' + i) + QString(":") + QString::fromUtf8(files[i]));
+			actions[i] = menu->addAction(QString('0' + i) + QString(":") + QString::fromUtf8(files[i].c_str()));
 		}
 		else
 		{
@@ -236,11 +239,13 @@ void MainWindow::buildRecentMenu(QMenu *menu, const char **files, QAction **acti
 void MainWindow::buildRecentMenu(void)
 {
 	this->buildRecentMenu(this->recentFiles, prefs->get_lastfiles(), this->recentFileAction);
+	buildActionLists();
 }
 
 void MainWindow::buildRecentProjectMenu(void)
 {
 	this->buildRecentMenu(this->recentProjects, prefs->get_lastprojectfiles(), this->recentProjectAction);
+	buildActionLists();
 }
 
 void MainWindow::searchRecentFiles(QAction *action, QAction **actionList, int firstEventId)
@@ -270,4 +275,4 @@ void MainWindow::searchRecentFiles(QAction * action)
 void MainWindow::searchRecentProjects(QAction * action)
 {
 	this->searchRecentFiles(action, this->recentProjectAction, ACT_RECENT_PROJECT0);
-}
\ No newline at end of file
+}
