@@ -18,9 +18,11 @@
 #include "ADM_audiodef.h"
 #include "ADM_mp3info.h"
 #include "ADM_a52info.h"
+#include "ADM_eac3info.h"
 #include "ADM_audioCodecEnum.h"
 #include "ADM_audioIdentify.h"
 #include "fourcc.h"
+#include "ADM_aacadts.h"
 
 extern void Endian_WavHeader(WAVHeader *w);
 #define INVALID_OFFSET 0XFFFFFFF
@@ -174,6 +176,41 @@ static bool idWAV(int bufferSize,const uint8_t *data,WAVHeader &info,uint32_t &o
         ADM_info("No, not riff/wav...\n");
 	    return false;
 }
+/**
+ * \fn idEAC3
+ */
+static bool idEAC3(int bufferSize,const uint8_t *data,WAVHeader &oinfo,uint32_t &offset)
+{
+    uint32_t syncOffset;
+    ADM_EAC3_INFO info,info2;
+
+   if( !ADM_EAC3GetInfo(data,bufferSize, &syncOffset,&info))
+    {
+            ADM_info("Not EAC3\n");
+            return false;
+    };
+    // Need a 2nd packet...
+    const uint8_t *second=data+syncOffset+info.frameSizeInBytes;
+    int size2=bufferSize-syncOffset;
+    ADM_assert(size2>0);
+    ADM_info("Maybe EAC3... \n");
+    // Try on 2nd packet...
+    if( ADM_EAC3GetInfo(second,size2, &syncOffset,&info2))
+    {
+        if((info.frequency==info2.frequency) && (info.channels==info2.channels) && (info.byterate==info2.byterate) && !syncOffset)
+        {
+            ADM_warning("\tProbably EAC3 : Fq=%d br=%d chan=%d, offset=%d\n",(int)info.frequency,(int)info.byterate,(int)info.channels,syncOffset);
+            oinfo.encoding=WAV_EAC3;
+            oinfo.channels=info.channels;
+            oinfo.byterate=info.byterate; // already in bytes/sec
+            oinfo.frequency=info.frequency;
+            return true;
+        }
+    }
+    ADM_info("Cannot confirm EAC3\n");
+    return false; 
+}
+
 /**
     \fn idAC3
     \brief return true if the tracks is mp2
@@ -210,6 +247,53 @@ static bool idAC3(int bufferSize,const uint8_t *data,WAVHeader &info,uint32_t &o
     ADM_info("Cannot confirm ac3\n");
     return false;
 }
+/**
+ * 
+ * @param bufferSize
+ * @param data
+ * @param info
+ * @param offset
+ * @return 
+ */
+static bool idAAACADTS(int bufferSize,const uint8_t *data,WAVHeader &info,uint32_t &offset)
+{
+    ADM_adts2aac aac;
+    const uint8_t *start=data;
+    const uint8_t *end=data+bufferSize;
+    while(start<end)
+    {
+        int incoming=500;
+        int outLen;
+        if(start+500>end) incoming=end-start;
+        ADM_adts2aac::ADTS_STATE state=aac.convert2(incoming,start,&outLen,NULL);
+        start+=incoming;
+        switch(state)
+        {
+            case ADM_adts2aac::ADTS_ERROR: 
+                    return false;
+                    break;
+            case ADM_adts2aac::ADTS_MORE_DATA_NEEDED: 
+                    continue;
+                    break;
+            case ADM_adts2aac::ADTS_OK:
+                    // Got sync
+                    info.encoding=WAV_AAC;
+                    info.channels=aac.getChannels();
+                    info.blockalign=0;
+                    info.bitspersample=16;
+                    info.byterate=128000>>3;
+                    info.frequency=aac.getFrequency();
+                    ADM_info("Detected as AAC, fq=%d, channels=%d\n",info.frequency,info.channels);
+                    return true;
+                    break;
+            default:
+                ADM_assert(0);
+                break;
+        }
+    }
+    return false;
+}
+
 /**
     \fn ADM_identifyAudioStream
     \param bufferSize : nb of bytes available for scanning
@@ -222,7 +306,10 @@ bool ADM_identifyAudioStream(int bufferSize,const uint8_t *buffer,WAVHeader &inf
     memset(&info,0,sizeof(info));
     if(idWAV(bufferSize,buffer,info,offset)) return true;
     if(idMP2(bufferSize,buffer,info,offset)) return true;
+    if(idEAC3(bufferSize,buffer,info,offset)) return true;
+    if(idAAACADTS(bufferSize,buffer,info,offset)) return true;
     if(idAC3(bufferSize,buffer,info,offset)) return true;
+    
 
     return false;
 }
