@@ -38,7 +38,9 @@
     ADM_COLOR_XVBA,
     ADM_COLOR_LIBVA,
     ADM_COLOR_YV12_10BITS,
-    ADM_COLOR_Y8
+    ADM_COLOR_Y8,
+    ADM_COLOR_YUV444_10BITS,
+    ADM_COLOR_NV12_10BITS
  } ADM_colorspace;
 #define ADM_COLOR_BACKWARD 0x8000
 #define ADM_COLOR_MASK     0x7FFF
