@@ -25,6 +25,7 @@
 
 extern "C" {
 #include "libavformat/url.h"
+#include "ADM_audioClock.h"
 }
 
 #if 1
@@ -44,7 +45,7 @@ bool ffmpuxerSetExtradata(AVCodecContext *context, int size, const uint8_t *data
         context->extradata_size=0;
         return true;
     }
-    uint8_t *copy=(uint8_t *)av_malloc(size);;
+    uint8_t *copy=(uint8_t *)av_malloc( (1+(size>>4))<<4);;
     memcpy(copy,data,size);
     context->extradata=copy;
     context->extradata_size=size;
@@ -133,10 +134,6 @@ bool muxerFFmpeg::setupMuxer(const char *format,const char *filename)
     // probably a memeleak here
 
 //#warning use AV METADATA
-#if 0
-    strcpy(oc->title,ADM_GetFileName(foo));
-    strcpy(oc->author,"Avidemux");
-#endif
     printf("[FF] Muxer opened\n");
     return true;
 }
@@ -187,7 +184,7 @@ bool muxerFFmpeg::initVideo(ADM_videoStream *stream)
 
         if(isMpeg4Compatible(fcc))
         {
-                c->codec_id = CODEC_ID_MPEG4;
+                c->codec_id = AV_CODEC_ID_MPEG4;
                 if(stream->providePts()==true)
                 {
                     c->has_b_frames=1; // in doubt...
@@ -217,26 +214,26 @@ bool muxerFFmpeg::initVideo(ADM_videoStream *stream)
                             c->codec_id = AV_CODEC_ID_HEVC;
                              setAvCodec(c,AV_CODEC_ID_HEVC);
                         } else {
-                            c->codec_id = CODEC_ID_H264;
-                             setAvCodec(c,CODEC_ID_H264);
+                            c->codec_id = AV_CODEC_ID_H264;
+                             setAvCodec(c,AV_CODEC_ID_H264);
                         }
                 }
                 else
                 {
                         if(isDVCompatible(fcc))
                         {
-                          c->codec_id = CODEC_ID_DVVIDEO;
+                          c->codec_id = AV_CODEC_ID_DVVIDEO;
                         }else
                         {
                           if(fourCC::check(fcc,(uint8_t *)"H263"))
                           {
-                                    c->codec_id=CODEC_ID_H263;
+                                    c->codec_id= AV_CODEC_ID_H263;
                             }else
 
                            if(isVP6Compatible(stream->getFCC()))
                                 {
-                                         c->codec_id=CODEC_ID_VP6F;
-                                         setAvCodec(c,CODEC_ID_VP6F);
+                                         c->codec_id= AV_CODEC_ID_VP6F;
+                                         setAvCodec(c,AV_CODEC_ID_VP6F);
                                          c->has_b_frames=0; // No PTS=cannot handle CTS...
                                          c->max_b_frames=0;
                                 }else
@@ -244,28 +241,28 @@ bool muxerFFmpeg::initVideo(ADM_videoStream *stream)
                                         {
                                                 c->has_b_frames=0; // No PTS=cannot handle CTS...
                                                 c->max_b_frames=0;
-                                                c->codec_id=CODEC_ID_FLV1;
-                                                setAvCodec(c,CODEC_ID_FLV1);
+                                                c->codec_id= AV_CODEC_ID_FLV1;
+                                                setAvCodec(c,AV_CODEC_ID_FLV1);
 
                                         }else
                                         {
-                                            if(fourCC::check(stream->getFCC(),(uint8_t *)"MPEG1"))
+                                            if(fourCC::check(stream->getFCC(),(uint8_t *)"mpg1"))
                                             {
                                                 c->has_b_frames=1; // No PTS=cannot handle CTS...
                                                 c->max_b_frames=2;
-                                                c->codec_id=CODEC_ID_MPEG1VIDEO;
+                                                c->codec_id= AV_CODEC_ID_MPEG1VIDEO;
                                             }
-                                            else if(fourCC::check(stream->getFCC(),(uint8_t *)"MPEG2"))
+                                            else if(fourCC::check(stream->getFCC(),(uint8_t *)"MPEG"))
                                             {
                                                 c->has_b_frames=1; // No PTS=cannot handle CTS...
                                                 c->max_b_frames=2;
-                                                c->codec_id=CODEC_ID_MPEG2VIDEO;
+                                                c->codec_id= AV_CODEC_ID_MPEG2VIDEO;
                                             }else
                                             {
                                                 uint32_t id=stream->getFCC();
 
                                                 AVCodecID cid=ADM_codecIdFindByFourcc(fourCC::tostring(id));
-                                                if(cid==CODEC_ID_NONE)
+                                                if(cid== AV_CODEC_ID_NONE)
                                                 {
                                                     printf("[FF] Unknown video codec\n");
                                                     return false;
@@ -326,29 +323,38 @@ bool muxerFFmpeg::initAudio(uint32_t nbAudioTrack,ADM_audioStream **audio)
           switch(audioheader->encoding)
           {
                   case WAV_OGG_VORBIS:
-                                c->codec_id = CODEC_ID_VORBIS;c->frame_size=6*256;
+                                c->codec_id = AV_CODEC_ID_VORBIS;c->frame_size=6*256;
                                 ffmpuxerSetExtradata(c,audioextraSize,audioextraData);
                                 break;
-                  case WAV_DTS: c->codec_id = CODEC_ID_DTS;c->frame_size=1024;break;
-                  case WAV_OPUS:    c->codec_id = CODEC_ID_OPUS;
+                  case WAV_FLAC:
+                                c->codec_id = AV_CODEC_ID_FLAC;
+                                // Do we already have the flac header ? FFmpeg will add it..
+                                // If we have it, skip it
+                                if(audioextraSize>=8 && audioextraData[0]==0x66 && audioextraData[1]==0x4c &&audioextraData[2]==0x61 && audioextraData[3]==0x43 )
+                                    ffmpuxerSetExtradata(c,audioextraSize-8,audioextraData+8);
+                                else
+                                    ffmpuxerSetExtradata(c,audioextraSize,audioextraData);
+                                break;                                
+                  case WAV_DTS: c->codec_id = AV_CODEC_ID_DTS;c->frame_size=1024;break;
+                  case WAV_OPUS:    c->codec_id = AV_CODEC_ID_OPUS;
                                     c->frame_size=1024;
                                     ffmpuxerSetExtradata(c,audioextraSize,audioextraData);
                                     break;
-                  case WAV_EAC3: c->codec_id = CODEC_ID_EAC3;c->frame_size=6*256;break;
-                  case WAV_AC3: c->codec_id = CODEC_ID_AC3;c->frame_size=6*256;break;
-                  case WAV_MP2: c->codec_id = CODEC_ID_MP2;c->frame_size=1152;break;
+                  case WAV_EAC3: c->codec_id = AV_CODEC_ID_EAC3;c->frame_size=6*256;break;
+                  case WAV_AC3: c->codec_id = AV_CODEC_ID_AC3;c->frame_size=6*256;break;
+                  case WAV_MP2: c->codec_id = AV_CODEC_ID_MP2;c->frame_size=1152;break;
                   case WAV_MP3:
 //  #warning FIXME : Probe deeper
                               c->frame_size=1152;
-                              c->codec_id = CODEC_ID_MP3;
+                              c->codec_id = AV_CODEC_ID_MP3;
                               break;
                   case WAV_PCM:
                                   // One chunk is 10 ms (1/100 of fq)
                                   c->frame_size=4;
-                                  c->codec_id = CODEC_ID_PCM_S16LE;break;
+                                  c->codec_id = AV_CODEC_ID_PCM_S16LE;break;
                   case WAV_AAC:
                                   ffmpuxerSetExtradata(c,audioextraSize,audioextraData);
-                                  c->codec_id = CODEC_ID_AAC;
+                                  c->codec_id = AV_CODEC_ID_AAC;
                                   c->frame_size=1024;
                                   break;
                   default:
@@ -386,16 +392,28 @@ bool muxerFFmpeg::initAudio(uint32_t nbAudioTrack,ADM_audioStream **audio)
         return true;
 }
 #define AUDIO_BUFFER_SIZE 48000*6*sizeof(float)
+/**
+ * \class MuxAudioPacket
+ */
 class MuxAudioPacket
 {
 public:
-    MuxAudioPacket() {eof=false;dts=ADM_NO_PTS;present=false;size=0;}
+    MuxAudioPacket() {eof=false;dts=ADM_NO_PTS;present=false;size=0;clock=NULL;}
+    ~MuxAudioPacket() 
+    {
+        if(clock) 
+        {
+            delete clock;
+            clock=NULL;
+        }
+    }
     uint8_t     buffer[AUDIO_BUFFER_SIZE];
     uint32_t    size;
     bool        eof;
     bool        present;
     uint64_t    dts;
     uint32_t    samples;
+    audioClock  *clock;
 };
 
 /**
@@ -429,6 +447,8 @@ bool muxerFFmpeg::saveLoop(const char *title)
     initUI(QT_TRANSLATE_NOOP("adm","Saving"));
     encoding->setContainer(getContainerName());
     MuxAudioPacket *audioPackets=new MuxAudioPacket[nbAStreams];
+    for(int i=0;i<nbAStreams;i++) // ugly...
+            audioPackets[i].clock=new audioClock(aStreams[i]->getInfo()->frequency);
     ADMBitstream out(bufSize);
     out.data=buffer;
 
@@ -446,9 +466,9 @@ bool muxerFFmpeg::saveLoop(const char *title)
             int64_t xdts=(int64_t)out.dts;
             if(out.pts==ADM_NO_PTS) xpts=-1;
             if(out.dts==ADM_NO_PTS) xdts=-1;
-            aprintf("[FF:V] Pts: %"PRId64" DTS:%"PRId64" ms\n",xpts/1000,xdts/1000);
+            aprintf("[FF:V] Pts: %" PRId64" DTS:%" PRId64" ms\n",xpts/1000,xdts/1000);
 
-            aprintf("[FF:V] LastDts:%08"PRIu64" Dts:%08"PRIu64" (%04"PRIu64") Delta : %"PRIu64"\n",
+            aprintf("[FF:V] LastDts:%08" PRIu64" Dts:%08" PRIu64" (%04" PRIu64") Delta : %" PRIu64"\n",
                         lastVideoDts,out.dts,out.dts/1000000,out.dts-lastVideoDts);
             rawDts=out.dts;
             if(rawDts==ADM_NO_PTS)
@@ -460,7 +480,7 @@ bool muxerFFmpeg::saveLoop(const char *title)
             }
             if(out.pts==ADM_NO_PTS)
             {
-                ADM_warning("No PTS information for frame %"PRIu32"\n",written);
+                ADM_warning("No PTS information for frame %" PRIu32"\n",written);
                 missingPts++;
                 out.pts=lastVideoDts;
             }
@@ -470,7 +490,7 @@ bool muxerFFmpeg::saveLoop(const char *title)
             muxerRescaleVideoTimeDts(&(out.dts),lastVideoDts);
             muxerRescaleVideoTime(&(out.pts));
             aprintf("[FF:V] RawDts:%lu Scaled Dts:%lu\n",rawDts,out.dts);
-            aprintf("[FF:V] Rescaled: Len : %d flags:%x Pts:%"PRIu64" Dts:%"PRIu64"\n",out.len,out.flags,out.pts,out.dts);
+            aprintf("[FF:V] Rescaled: Len : %d flags:%x Pts:%" PRIu64" Dts:%" PRIu64"\n",out.len,out.flags,out.pts,out.dts);
 
             av_init_packet(&pkt);
             pkt.dts=out.dts;
@@ -530,6 +550,11 @@ bool muxerFFmpeg::saveLoop(const char *title)
                     AVPacket pkt;
                     uint64_t rescaledDts;
                     rescaledDts=audioTrack->dts;
+                    if(rescaledDts==ADM_NO_PTS)
+                        rescaledDts=audioTrack->clock->getTimeUs(); // we assume the 1st one has a PTS/DTS..., can we ?
+                    else
+                        audioTrack->clock->setTimeUs(rescaledDts);
+                    audioTrack->clock->advanceBySample(audioTrack->samples);
                     encoding->pushAudioFrame(audioTrack->size);
                     muxerRescaleAudioTime(audio,&rescaledDts,a->getInfo()->frequency);
                    //printf("[FF] A: Video frame  %d, audio Dts :%"PRIu64" size :%"PRIu32" nbSample : %"PRIu32" rescaled:%"PRIu64"\n",
@@ -558,7 +583,7 @@ bool muxerFFmpeg::saveLoop(const char *title)
     delete [] buffer;
     if((videoDuration *4)/5 > lastVideoDts)
     {
-        GUI_Error_HIG("Too short","The video has been saved but seems to be incomplete.");
+        GUI_Error_HIG(QT_TRANSLATE_NOOP("adm","Too short"), QT_TRANSLATE_NOOP("adm","The video has been saved but seems to be incomplete."));
         result=false;
     }
     ADM_info("[FF] Wrote %d frames, nb audio streams %d\n",written,nbAStreams);
