@@ -13,14 +13,11 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#define __STDC_CONSTANT_MACROS  1 // Lavcodec crap
-#define __STDC_LIMIT_MACROS 1
 #include "ADM_default.h"
 #include "ADM_muxerInternal.h"
 #include "ADM_muxerUtils.h"
 #include "fourcc.h"
 #include "ADM_vidMisc.h"
-#include "prefs.h"
 
 /**
     \fn rescaleFps
@@ -47,7 +44,7 @@ void  rescaleFps(uint32_t fps1000, AVRational *rational)
     rational->num=1000;
     rational->den=fps1000;
     }
-    printf("[MP3] TimeBase for video %d/%d\n",rational->num,rational->den);
+    ADM_info(" TimeBase for video %d/%d\n",rational->num,rational->den);
 }
 /**
         \fn rescaleLavPts
@@ -75,15 +72,13 @@ uint64_t rescaleLavPts(uint64_t us, AVRational *scale)
 */
 bool     ADM_muxer::initUI(const char *title)
 {
-        bool useTray = false;
-
-        if (!prefs->get(FEATURES_USE_SYSTRAY, &useTray))
-            useTray = false;
-
         videoIncrement=vStream->getFrameIncrement();  // Video increment in AVI-Tick
         videoDuration=vStream->getVideoDuration();
-        ADM_info("Muxer, creating UI, video duration is %s\n",ADM_us2plain(videoDuration));
-        encoding=createEncoding(videoDuration,useTray);
+        if(!encoding)
+        {
+            ADM_info("Muxer, creating UI, video duration is %s\n",ADM_us2plain(videoDuration));
+            createUI(videoDuration);
+        }
         // Set video stream etc...
         encoding->setPhasis(title);
         encoding->setVideoCodec(fourCC::tostring(vStream->getFCC()));
@@ -92,6 +87,17 @@ bool     ADM_muxer::initUI(const char *title)
                 else    encoding->setAudioCodec(getStrFromAudioCodec(aStreams[0]->getInfo()->encoding));
         return true;
 }
+
+/**
+    \fn createUI
+    \brief create an encoding dialog / progress indicator
+*/
+bool ADM_muxer::createUI(uint64_t duration)
+{
+    encoding=createEncoding(duration);
+    return true;
+}
+
 /**
         \fn updateUI
         \brief Update the progress bar
