@@ -23,47 +23,48 @@
 const ffVideoCodec ffCodec[]=
 {
                                 // Refcopy // extrdata // Can have  B frame
-  {"SNOW",  CODEC_ID_SNOW,      false, false,    false},
-  {"cvid",  CODEC_ID_CINEPAK,   false, false,    false},
-  {"CRAM",  CODEC_ID_MSVIDEO1,  false, false,    false},
-  {"VP6F",  CODEC_ID_VP6F,      false, false,    false},
-  {"VP6A",  CODEC_ID_VP6A,      false, false,    false},
-  {"VP8 ",  CODEC_ID_VP8,       false, false,    false},
-  {"SVQ1",  CODEC_ID_SVQ1,      false, false,    false},
-  {"FLV1",  CODEC_ID_FLV1,      false, false,    false},
-  {"AMV",   CODEC_ID_AMV,       false, false,    false},
-  {"MJPG",  CODEC_ID_MJPEG,     false, false,    false},
-  {"mjpa",  CODEC_ID_MJPEG,     false, false,    false},
-  {"MJPB",  CODEC_ID_MJPEGB,    false, false,    false},
-  {"FPS1",  CODEC_ID_FRAPS,     false, false,    false},
-  {"cvid",  CODEC_ID_CINEPAK,   false, false,    false},
+  {"LAGS",  AV_CODEC_ID_LAGARITH,  false, false,    false},    
+  {"SNOW",  AV_CODEC_ID_SNOW,      false, false,    false},
+  {"cvid",  AV_CODEC_ID_CINEPAK,   false, false,    false},
+  {"CRAM",  AV_CODEC_ID_MSVIDEO1,  false, false,    false},
+  {"VP6F",  AV_CODEC_ID_VP6F,      false, false,    false},
+  {"VP6A",  AV_CODEC_ID_VP6A,      false, false,    false},
+  {"VP8 ",  AV_CODEC_ID_VP8,       false, false,    false},
+  {"SVQ1",  AV_CODEC_ID_SVQ1,      false, false,    false},
+  {"FLV1",  AV_CODEC_ID_FLV1,      false, false,    false},
+  {"AMV",   AV_CODEC_ID_AMV,       false, false,    false},
+  {"MJPG",  AV_CODEC_ID_MJPEG,     false, false,    false},
+  {"mjpa",  AV_CODEC_ID_MJPEG,     false, false,    false},
+  {"MJPB",  AV_CODEC_ID_MJPEGB,    false, false,    false},
+  {"FPS1",  AV_CODEC_ID_FRAPS,     false, false,    false},
+  {"cvid",  AV_CODEC_ID_CINEPAK,   false, false,    false},
 // Need extradata
-  {"WMV2", CODEC_ID_WMV2,       true, false,    false},
-  {"WMV1", CODEC_ID_WMV1,       true, false,    false},
-  {"WMV3", CODEC_ID_WMV3,       true, false,    true},
-  {"WVC1", CODEC_ID_VC1,        true, false,    true},
-  {"WMVA", CODEC_ID_VC1,        true, false,    true},
-  {"VP8 ", CODEC_ID_VP8,        true, false,    false},
-  {"VP9 ", AV_CODEC_ID_VP9,     true, false,    false},
-  {"tscc", CODEC_ID_TSCC,       false,false,    false},
-  {"CSCD", CODEC_ID_CSCD,       false,false,    false},
+  {"WMV2", AV_CODEC_ID_WMV2,       true, false,    false},
+  {"WMV1", AV_CODEC_ID_WMV1,       true, false,    false},
+  {"WMV3", AV_CODEC_ID_WMV3,       true, false,    true},
+  {"WVC1", AV_CODEC_ID_VC1,        true, false,    true},
+  {"WMVA", AV_CODEC_ID_VC1,        true, false,    true},
+  {"VP8 ", AV_CODEC_ID_VP8,        true, false,    false},
+  {"VP9 ", AV_CODEC_ID_VP9,        true, false,    false},
+  {"tscc", AV_CODEC_ID_TSCC,       false,false,    false},
+  {"CSCD", AV_CODEC_ID_CSCD,       false,false,    false},
 
   
 // RefCopy
-  {"FFV1", CODEC_ID_FFV1,       true, true,    false},
-  {"H263", CODEC_ID_H263,       false, true,   false},
-  {"MP42", CODEC_ID_MSMPEG4V2,  true, true,    false},
-  {"SVQ3", CODEC_ID_SVQ3,       true, true,    false},
-  {"FFVH", CODEC_ID_FFVHUFF,    true, true,    false},
-  {"HFYU", CODEC_ID_HUFFYUV,    true, true,    false},
-  {"VC1 ", CODEC_ID_VC1,        true, true,    true},
+  {"FFV1", AV_CODEC_ID_FFV1,       true, true,    false},
+  {"H263", AV_CODEC_ID_H263,       false, true,   false},
+  {"MP42", AV_CODEC_ID_MSMPEG4V2,  true, true,    false},
+  {"SVQ3", AV_CODEC_ID_SVQ3,       true, true,    false},
+  {"FFVH", AV_CODEC_ID_FFVHUFF,    true, true,    false},
+  {"HFYU", AV_CODEC_ID_HUFFYUV,    true, true,    false},
+  {"VC1 ", AV_CODEC_ID_VC1,        true, true,    true},
 
 
- //{CODEC_ID_FFVHUFF,"FFVH"},
-//    {CODEC_ID_HUFFYUV,"HFYU"},
-  //{"MJPB", CODEC_ID_CYUV,       true},
- // {"MJPB", CODEC_ID_THEORA),    true}
-  {"xxxx", CODEC_ID_NONE, false,false,    false}
+ //{AV_CODEC_ID_FFVHUFF,"FFVH"},
+//    {AV_CODEC_ID_HUFFYUV,"HFYU"},
+  //{"MJPB", AV_CODEC_ID_CYUV,       true},
+ // {"MJPB", AV_CODEC_ID_THEORA),    true}
+  {"xxxx", AV_CODEC_ID_NONE, false,false,    false}
 };
 
 /**
@@ -92,15 +93,15 @@ AVCodecID ADM_codecIdFindByFourcc(const char *fcc)
     // Special cases
  if (isMSMpeg4Compatible (fid) == 1)
     {
-      return CODEC_ID_MSMPEG4V3;
+      return AV_CODEC_ID_MSMPEG4V3;
     }
   if (isDVCompatible(fid))//"CDVC"))
     {
-      return CODEC_ID_DVVIDEO;
+      return AV_CODEC_ID_DVVIDEO;
     }
   if (isH264Compatible (fid))
     {
-        return CODEC_ID_H264;
+        return AV_CODEC_ID_H264;
     }
   if (isH265Compatible (fid))
     {
@@ -108,7 +109,7 @@ AVCodecID ADM_codecIdFindByFourcc(const char *fcc)
     }
   if (isMpeg4Compatible (fid) == 1)
     {
-      return CODEC_ID_MPEG4;
+      return AV_CODEC_ID_MPEG4;
     }
 
     uint32_t nb=sizeof(ffCodec)/sizeof(ffVideoCodec);
@@ -116,5 +117,5 @@ AVCodecID ADM_codecIdFindByFourcc(const char *fcc)
     {
         if(!strcmp(fcc,ffCodec[i].string)) return ffCodec[i].codecId;
     }
-    return CODEC_ID_NONE;
+    return AV_CODEC_ID_NONE;
 }
