@@ -1,7 +1,7 @@
 /***************************************************************************
-    \file             : ADM_coreXvba.cpp
-    \brief            : Wrapper around xvba functions
-    \author           : (C) 2013 by mean fixounet@free.fr, derived from xbmc_pvr
+    \file             : ADM_coreLibVA.cpp
+    \brief            : Wrapper around libVA functions
+    \author           : (C) 2013/2016 by mean fixounet@free.fr, derived from xbmc_pvr
  ***************************************************************************/
 
 /***************************************************************************
@@ -25,6 +25,7 @@
 #include "ADM_imageFlags.h"
 
 #include "fourcc.h"
+#include <map>
 
 #define CHECK_WORKING(x)   if(!coreLibVAWorking) {ADM_warning("Libva not operationnal\n");return x;}
 
@@ -34,35 +35,68 @@
 #define aprintf(...) {}
 #endif
 
+
+
+
 /**
- * 
+ *
  */
- 
+
+
+static std::map <VASurfaceID, bool>listOfAllocatedSurface;
+typedef std::map<VASurfaceID, bool> surfaceList;
+
+static std::map <VAImageID, bool>listOfAllocatedVAImage;
+typedef std::map<VAImageID, bool> vaImageList;
+
+
+
+
 GUI_WindowInfo      admLibVA::myWindowInfo;
 
 namespace ADM_coreLibVA
 {
  void                   *context;
  VADisplay              display;
- VAConfigID             config;
+ VAConfigID             configH264;
+ VAConfigID             configMpeg2;
+ VAConfigID             configH265;
+ VAConfigID             configH26510Bits;
+ VAConfigID             configVC1;
+ VAConfigID             configVP9;
  VAImageFormat          imageFormatNV12;
  VAImageFormat          imageFormatYV12;
  bool                   directOperation;
  bool                   indirectOperationYV12;
  bool                   indirectOperationNV12;
 admLibVA::LIBVA_TRANSFER_MODE    transferMode;
- 
+
  namespace decoders
  {
-        bool            h264; 
+        bool            h264;
  }
 }
 namespace ADM_coreLibVAEnc
 {
+ class vaEncoder
+ {
+ public:
+     bool       enabled;
+     VAConfigID configId;
+     bool       hasCBR;
+     bool       hasVBR;
+                vaEncoder()
+                {
+                    enabled=false;
+                    configId=-1;
+                    hasCBR=false;
+                    hasVBR=false;
+                }
+
+ };
  namespace encoders
  {
-        bool            h264;
-        VAConfigID      h264ConfigID;
+        vaEncoder vaH264,vaH265;
  }
 }
 static bool                  coreLibVAWorking=false;
@@ -76,7 +110,7 @@ static bool                  coreLibVAWorking=false;
 
 /**
  * \fn checkSupportedFunctionsAndImageFormat
- * \brief check if operation through vaDeriveImage is supported and if 
+ * \brief check if operation through vaDeriveImage is supported and if
  *           YV12 or NV12 is supported
  * @param func
  * @param dis
@@ -87,24 +121,24 @@ static bool checkSupportedFunctionsAndImageFormat(void)
     bool r=false;
     ADMImageDefault  image1(640,400),image2(640,400);
     VASurfaceID      surface=admLibVA::allocateSurface(640,400); // freed with admSurface
-    ADM_vaSurface    admSurface(NULL,640,400);            
+    ADM_vaSurface    admSurface(640,400);
     admSurface.surface=VA_INVALID;
-    
+
     if(surface==VA_INVALID)
     {
         ADM_info("Cannot allocate a surface => not working\n");
         return false;
-    }    
+    }
     admSurface.surface=surface;
-    
-    // Check direct upload/Download works    
+
+    // Check direct upload/Download works
     ADM_info("--Trying direct operations --\n");
     ADM_coreLibVA::directOperation      =tryDirect("direct",admSurface, image1,  image2);
     ADM_info("-- Trying indirect (YV12) --\n");
     ADM_coreLibVA::indirectOperationYV12=tryIndirect(0,admSurface, image1 ,image2);
     ADM_info("-- Trying indirect (NV12) --\nSKIPPED\n");
     ADM_coreLibVA::indirectOperationNV12=false; //tryIndirect(1,admSurface, image1, image2 );
-    
+
     ADM_info("Direct           : %d\n",ADM_coreLibVA::directOperation);
     ADM_info("Indirect NV12    : %d\n",ADM_coreLibVA::indirectOperationNV12);
     ADM_info("Indirect YV12    : %d\n",ADM_coreLibVA::indirectOperationYV12);
@@ -131,14 +165,14 @@ static bool checkSupportedFunctionsAndImageFormat(void)
  */
 static void displayXError(const char *func,const VADisplay dis,const VAStatus er)
 {
-    if(!er) return;    
-    ADM_warning("LibVA Error : <%s:%s>\n",func,vaErrorStr((er)));
-    
+    if(!er) return;
+    ADM_warning("LibVA Error : <%s:%s:%d>\n",func,vaErrorStr(er),(int)er);
+
 
 }
 /**
  * \fn setupEncodingConfig
- * @return 
+ * @return
  */
 bool admLibVA::setupEncodingConfig(void)
 {
@@ -146,19 +180,21 @@ bool admLibVA::setupEncodingConfig(void)
     VAEntrypoint entrypoints[5];
     int num_entrypoints;
     VAConfigAttrib attrib[2];
-    
- 
-    CHECK_ERROR(vaQueryConfigEntrypoints(ADM_coreLibVA::display, VAProfileH264Baseline, entrypoints,        &num_entrypoints));
-    
+
+
+    CHECK_ERROR(vaQueryConfigEntrypoints(ADM_coreLibVA::display, VAProfileH264Main, entrypoints,        &num_entrypoints));
+
     int found=-1;
-    for	(int slice_entrypoint = 0; slice_entrypoint < num_entrypoints; slice_entrypoint++) 
+    ADM_info("Found %d entry points\n",num_entrypoints);
+    for	(int slice_entrypoint = 0; slice_entrypoint < num_entrypoints; slice_entrypoint++)
     {
+            ADM_info("   %d is a %d\n",slice_entrypoint,entrypoints[slice_entrypoint] );
         if (entrypoints[slice_entrypoint] == VAEntrypointEncSlice)
         {
             found=slice_entrypoint;
             break;
         }
-            
+
     }
     if(-1 == found)
     {
@@ -168,27 +204,84 @@ bool admLibVA::setupEncodingConfig(void)
      /* find out the format for the render target, and rate control mode */
     attrib[0].type = VAConfigAttribRTFormat;
     attrib[1].type = VAConfigAttribRateControl;
-    CHECK_ERROR(vaGetConfigAttributes(ADM_coreLibVA::display, VAProfileH264Baseline, VAEntrypointEncSlice,    &attrib[0], 2));
-    if (!(attrib[0].value & VA_RT_FORMAT_YUV420))
+    CHECK_ERROR(vaGetConfigAttributes(ADM_coreLibVA::display, VAProfileH264Main, VAEntrypointEncSlice,    &attrib[0], 2));
+    int check=0;
+    for(int i=0;i<2;i++)
     {
-        ADM_warning("Encoder does not support YV12\n");
-        return false;
-    }
-    ADM_info("YV12 supported..\n");
-    if (!(attrib[1].value & VA_RC_VBR))
-    {
-        ADM_warning("Encoder does not support VBR\n");
-        return false;
-    }
-    ADM_info("VBR supported..\n");
-    CHECK_ERROR(vaCreateConfig(ADM_coreLibVA::display, VAProfileH264Baseline, VAEntrypointEncSlice,
-                              &attrib[0], 2,&(ADM_coreLibVAEnc::encoders::h264ConfigID)));
+           unsigned int value=attrib[i].value;
+           int type=attrib[i].type;
+           switch(type)
+           {
+                case VAConfigAttribRTFormat:
+                        if(value & VA_RT_FORMAT_YUV420)
+                        {
+                                ADM_info("YUV420 supported\n");
+                                check|=1;
+                        }
+                        break;
+                case VAConfigAttribRateControl:
+                        #define MKK(x,y) if(type & x) {ADM_info(#x " is supported\n");y;}
+                        MKK(VA_RC_CBR,;);
+                        MKK(VA_RC_VBR,check|=2);
+                        MKK(VA_RC_CQP,;);
+                        MKK(VA_RC_VBR_CONSTRAINED,;);
+                        break;
+                default:
+                        ADM_warning("Unknown attribute %d\n",type);
+                        break;
 
-    
-    ADM_info("H264 Encoding config created\n");
+           }
+
+    }
+    if(check!=3)
+    {
+        ADM_warning("Some configuration are missing, bailing\n");
+        return false;
+    }
+    CHECK_ERROR(vaCreateConfig(ADM_coreLibVA::display, VAProfileH264Main, VAEntrypointEncSlice,
+                              &attrib[0], 2,&(ADM_coreLibVAEnc::encoders::vaH264.configId)));
+    if(xError)
+    {
+        ADM_coreLibVAEnc::encoders::vaH264.configId=-1;
+        return false;
+
+    }else
+    {
+        ADM_info("H264 Encoding config created\n");
+        ADM_coreLibVAEnc::encoders::vaH264.enabled=true;
+    }
     return true;
 }
+/**
+ * \fn checkProfile
+ * @param profile
+ * @param cid
+ * @param name
+ * @return
+ */
+static bool checkProfile(const VAProfile &profile,VAConfigID *cid,const char *name)
+{
+    VAStatus xError;
 
+    *cid=-1;
+    VAConfigAttrib attrib;
+    attrib.type = VAConfigAttribRTFormat;
+    CHECK_ERROR(vaGetConfigAttributes(ADM_coreLibVA::display, profile, VAEntrypointVLD, &attrib, 1));
+    if(xError)
+    {
+         ADM_warning("Cannot get attribute for %s \n",name);
+         return false;
+    }
+    CHECK_ERROR(vaCreateConfig( ADM_coreLibVA::display, profile, VAEntrypointVLD,&attrib, 1,cid));
+    if(xError)
+    {
+        ADM_warning("Cannot create config %s\n",name);
+        *cid=-1;
+        return false;
+     }
+    ADM_info("Config created %s \n",name);
+    return true;
+}
 /**
  *      \fn setupConfig
  *      \brief verify that h264 main profile is supported
@@ -199,7 +292,7 @@ bool admLibVA::setupConfig(void)
     bool r=false;
     int nb=vaMaxNumProfiles(ADM_coreLibVA::display);
     ADM_info("Max config =  %d \n",nb);
-    VAProfile *prof=new VAProfile[nb];
+    VAProfile *prof=(VAProfile *)admAlloca(sizeof(VAProfile)*nb);
     int nbProfiles;
     CHECK_ERROR(vaQueryConfigProfiles (ADM_coreLibVA::display, prof,&nbProfiles));
 
@@ -216,48 +309,27 @@ bool admLibVA::setupConfig(void)
             }
         }
     }
-    // supported ?
-    if(r)
-    {
-        VAConfigAttrib attrib;
-                attrib.type = VAConfigAttribRTFormat;
-                CHECK_ERROR(vaGetConfigAttributes(ADM_coreLibVA::display, VAProfileH264High, VAEntrypointVLD, &attrib, 1))
+    // if H264 is not supported, no need to go further
+    if(!r)
+        return false;
 
-                if (!(attrib.value & VA_RT_FORMAT_YUV420) )
-                {
-                    ADM_warning("YUV420 not supported\n");
-                    r=false;
-                }else
-                {
-                    ADM_info("YUV420 supported\n");
-                    
-                    VAConfigID id;
-                    CHECK_ERROR(vaCreateConfig( ADM_coreLibVA::display, VAProfileH264High, VAEntrypointVLD,&attrib, 1,&id));
-                    if(xError)
-                    {
-                        ADM_warning("Cannot create config\n");
-                     }
-                    else
-                    {
-                        ADM_info("Config created\n");
-                        ADM_coreLibVA::config=id;
-                        r=true;
-                    }
-                    
-                }
+    checkProfile(VAProfileMPEG2Main,    &ADM_coreLibVA::configMpeg2,    "Mpeg 2 Main");
+    checkProfile(VAProfileH264High,     &ADM_coreLibVA::configH264,     "H264 Hight");
+    checkProfile(VAProfileVC1Advanced,  &ADM_coreLibVA::configVC1 ,     "VC1");
+#ifdef LIBVA_HEVC_DEC
+    checkProfile(VAProfileHEVCMain,     &ADM_coreLibVA::configH265,     "HEVC Main");
+    checkProfile(VAProfileHEVCMain10,   &ADM_coreLibVA::configH26510Bits,"H265 10Bits");
+#endif
 
- 
-    }
-   
-    delete [] prof;
-    return r;
-    
-    
+#ifdef LIBVA_VP9_DEC
+    checkProfile(VAProfileVP9Profile3,  &ADM_coreLibVA::configVP9 ,     "VP9");
+#endif
+    return true;
 }
 /**
  * \fn fourCC_tostring
  * @param fourcc
- * @return 
+ * @return
  */
 static char *fourCC_tostring(uint32_t fourcc)
 {
@@ -271,6 +343,15 @@ static char *fourCC_tostring(uint32_t fourcc)
 
     return s;
 }
+
+/**
+ *
+ * @return
+ */
+VADisplay admLibVA::getDisplay()
+{
+        return ADM_coreLibVA::display;
+}
 /**
  * \fn setupImageFormat
  */
@@ -293,7 +374,7 @@ bool admLibVA::setupImageFormat()
                 aprintf("----------");
                 aprintf("bpp : %d\n",list[i].bits_per_pixel);
                 uint32_t fcc=list[i].fourcc;
-                aprintf("fcc : 0x%x:%s\n",fcc,fourCC_tostring(fcc));  
+                aprintf("fcc : 0x%x:%s\n",fcc,fourCC_tostring(fcc));
                 switch(fcc)
                 {
                 case VA_FOURCC_NV12:
@@ -306,7 +387,7 @@ bool admLibVA::setupImageFormat()
                      break;
                 }
             }
-            
+
         }
         if(r==false)
         {
@@ -318,17 +399,35 @@ bool admLibVA::setupImageFormat()
 /**
  * \fn fillContext
  * @param c
- * @return 
- */    
-bool admLibVA::fillContext(vaapi_context *c)
+ * @return
+ */
+bool admLibVA::fillContext(VAProfile profile ,vaapi_context *c)
 {
     CHECK_WORKING(false);
-    c->config_id=ADM_coreLibVA::config;
+    VAConfigID cid;
+    switch(profile)
+    {
+       case VAProfileMPEG2Main:     cid=ADM_coreLibVA::configMpeg2;break;
+       case VAProfileH264High:      cid=ADM_coreLibVA::configH264;break;
+       case VAProfileVC1Advanced:   cid=ADM_coreLibVA::configVC1;break;
+#ifdef LIBVA_HEVC_DEC
+       case VAProfileHEVCMain:      cid=ADM_coreLibVA::configH265;break;
+       case VAProfileHEVCMain10:    cid=ADM_coreLibVA::configH26510Bits;break;
+#endif
+
+#ifdef LIBVA_VP9_DEC
+       case VAProfileVP9Profile3: cid=ADM_coreLibVA::configVP9;break;
+#endif
+       default:
+                ADM_assert(0);
+
+    }
+    c->config_id=cid;
     c->display=ADM_coreLibVA::display;
     return true;
 }
-    
-    
+
+
 
 /**
     \fn     init
@@ -341,13 +440,12 @@ bool admLibVA::init(GUI_WindowInfo *x)
     int maj=0,min=0,patch=0;
     ADM_info("[LIBVA] Initializing LibVA library ...\n");
 
-    ADM_coreLibVAEnc::encoders::h264=false;
-    
+
     ADM_coreLibVA::context=NULL;
     ADM_coreLibVA::decoders::h264=false;
     ADM_coreLibVA::directOperation=true;
     ADM_coreLibVA::transferMode=ADM_LIBVA_NONE;
-            
+
     myWindowInfo=*x;
     VAStatus xError;
     int majv,minv;
@@ -358,14 +456,13 @@ bool admLibVA::init(GUI_WindowInfo *x)
         return false;
     }
     ADM_info("VA %d.%d, Vendor = %s\n",majv,minv,vaQueryVendorString(ADM_coreLibVA::display));
-    
+
     if(setupConfig() && setupImageFormat())
     {
         coreLibVAWorking=true;
     }
-    
-    ADM_coreLibVAEnc::encoders::h264=setupEncodingConfig();
-    if(ADM_coreLibVAEnc::encoders::h264)
+
+    if(setupEncodingConfig())
     {
         ADM_info("VA: Encoding supported\n");
     }else
@@ -383,8 +480,8 @@ bool admLibVA::cleanup(void)
     ADM_info("[LIBVA] De-Initializing LibVA library ...\n");
     if(true==coreLibVAWorking)
     {
-         CHECK_ERROR(vaTerminate(ADM_coreLibVA::display));   
-          
+         CHECK_ERROR(vaTerminate(ADM_coreLibVA::display));
+
     }
     coreLibVAWorking=false;
     return true;
@@ -396,23 +493,72 @@ bool admLibVA::isOperationnal(void)
 {
     return coreLibVAWorking;
 }
+/**
+ *
+ * @param profile
+ * @return
+ */
+bool        admLibVA::supported(VAProfile profile)
+{
+#define SUPSUP(a,b) case a: if(ADM_coreLibVA::b!=-1) return true;break;
+    switch(profile)
+    {
+        SUPSUP(VAProfileMPEG2Main,configMpeg2)
+        SUPSUP(VAProfileH264High,configH264)
+        SUPSUP(VAProfileVC1Advanced,configVC1)
+#ifdef LIBVA_HEVC_DEC
+        SUPSUP(VAProfileHEVCMain,configH265)
+        SUPSUP(VAProfileHEVCMain10,configH26510Bits)
+#endif
 
-
+#ifdef LIBVA_VP9_DEC
+        SUPSUP(VAProfileVP9Profile3,configVP9)
+#endif
+        default:
+            ADM_info("This profile is not supported by libva\n");
+            break;
+    }
+    ADM_info("Unknown profile (%d)\n",(int)profile);
+#ifdef LIBVA_VP9_DEC
+    ADM_info("Compiled with vp9 support, library says %d\n",ADM_coreLibVA::configVP9);
+#endif
+    return false;
+}
 
 /**
  * \fn createDecoder
  * @param width
  * @param height
- * @return 
+ * @return
  */
 
-VAContextID        admLibVA::createDecoder(int width, int height,int nbSurface, VASurfaceID *surfaces)
+VAContextID        admLibVA::createDecoder(VAProfile profile,int width, int height,int nbSurface, VASurfaceID *surfaces)
 {
     int xError=1;
     CHECK_WORKING(VA_INVALID);
     VAContextID id;
-    CHECK_ERROR(vaCreateContext ( ADM_coreLibVA::display, ADM_coreLibVA::config,
-                width,    height,    
+    VAConfigID cid;
+
+    switch(profile)
+    {
+       case VAProfileMPEG2Main:   cid=ADM_coreLibVA::configMpeg2;break;
+       case VAProfileH264High:    cid=ADM_coreLibVA::configH264;break;
+       case VAProfileVC1Advanced: cid=ADM_coreLibVA::configVC1;break;
+#ifdef LIBVA_HEVC_DEC
+       case VAProfileHEVCMain:    cid=ADM_coreLibVA::configH265;break;
+       case VAProfileHEVCMain10:  cid=ADM_coreLibVA::configH26510Bits;break;
+#endif
+#ifdef LIBVA_VP9_DEC
+       case VAProfileVP9Profile3: cid=ADM_coreLibVA::configVP9;break;
+#endif
+       default:
+                ADM_assert(0);
+                break;
+
+    }
+
+    CHECK_ERROR(vaCreateContext ( ADM_coreLibVA::display, cid,
+                width,    height,
                 VA_PROGRESSIVE, // ?? NOT SURE ??
                 surfaces,
                 nbSurface,
@@ -430,14 +576,14 @@ VAContextID        admLibVA::createDecoder(int width, int height,int nbSurface,
  * \brief allocate the correct image type for transfer : None, YV12 or NV12
  * @param w
  * @param h
- * @return 
+ * @return
  */
  VAImage    *admLibVA::allocateImage( int w, int h)
  {
     switch(ADM_coreLibVA::transferMode)
     {
     case   admLibVA::ADM_LIBVA_NONE: ADM_warning("No transfer supported\n");
-    case   admLibVA::ADM_LIBVA_DIRECT:        
+    case   admLibVA::ADM_LIBVA_DIRECT:
                 return NULL;break;
     case   admLibVA::ADM_LIBVA_INDIRECT_NV12:
                 return admLibVA::allocateNV12Image(w,h);break;
@@ -449,10 +595,10 @@ VAContextID        admLibVA::createDecoder(int width, int height,int nbSurface,
  }
 
 /**
- * 
+ *
  * @param w
  * @param h
- * @return 
+ * @return
  */
 VAImage   *admLibVA::allocateNV12Image( int w, int h)
 {
@@ -461,7 +607,7 @@ VAImage   *admLibVA::allocateNV12Image( int w, int h)
     VAImage *image=new VAImage;
     memset(image,0,sizeof(*image));
     CHECK_ERROR(vaCreateImage ( ADM_coreLibVA::display, &ADM_coreLibVA::imageFormatNV12,
-                w,    h,    
+                w,    h,
                 image));
     if(xError)
     {
@@ -469,13 +615,14 @@ VAImage   *admLibVA::allocateNV12Image( int w, int h)
         delete image;
         return NULL;
     }
+    listOfAllocatedVAImage[image->image_id]=true;
     return image;
 }
 /**
- * 
+ *
  * @param w
  * @param h
- * @return 
+ * @return
  */
 VAImage   *admLibVA::allocateYV12Image( int w, int h)
 {
@@ -484,7 +631,7 @@ VAImage   *admLibVA::allocateYV12Image( int w, int h)
     VAImage *image=new VAImage;
     memset(image,0,sizeof(*image));
     CHECK_ERROR(vaCreateImage ( ADM_coreLibVA::display, &ADM_coreLibVA::imageFormatYV12,
-                w,    h,    
+                w,    h,
                 image));
     if(xError)
     {
@@ -492,16 +639,24 @@ VAImage   *admLibVA::allocateYV12Image( int w, int h)
         delete image;
         return NULL;
     }
+    listOfAllocatedVAImage[image->image_id]=true;
     return image;
 }
 /**
- * 
+ *
  * @param surface
  */
 void        admLibVA::destroyImage(  VAImage *image)
 {
     int xError=1;
     CHECK_WORKING();
+    if(listOfAllocatedVAImage.end()==listOfAllocatedVAImage.find(image->image_id))
+    {
+        ADM_warning("Trying to destroy an unallocated VAImage\n");
+        ADM_assert(0);
+    }
+    listOfAllocatedVAImage.erase(image->image_id);
+
     CHECK_ERROR(vaDestroyImage(ADM_coreLibVA::display, image->image_id));
     delete image;
     if(xError)
@@ -517,10 +672,10 @@ void        admLibVA::destroyImage(  VAImage *image)
  */
 bool admLibVA::destroyDecoder(VAContextID session)
 {
-       
+
        int xError;
        CHECK_WORKING(false);
-       
+
        aprintf("Destroying decoder %x\n",session);
         CHECK_ERROR(vaDestroyContext(ADM_coreLibVA::display,session));
         if(!xError)
@@ -536,16 +691,16 @@ bool admLibVA::destroyDecoder(VAContextID session)
  * \fn allocateSurface
  * @param w
  * @param h
- * @return 
+ * @return
  */
 VASurfaceID        admLibVA::allocateSurface(int w, int h)
 {
        int xError;
        CHECK_WORKING(VA_INVALID);
-       
+
        aprintf("Creating surface %d x %d\n",w,h);
        VASurfaceID s;
- 
+
         CHECK_ERROR(vaCreateSurfaces(ADM_coreLibVA::display,
                         VA_RT_FORMAT_YUV420,
                         w,h,
@@ -554,11 +709,18 @@ VASurfaceID        admLibVA::allocateSurface(int w, int h)
 
         if(!xError)
         {
+            surfaceList::iterator already;
+            already=listOfAllocatedSurface.find(s);
+            if(already!=listOfAllocatedSurface.end())
+            {
+                ADM_warning("Doubly allocated va surface\n");
+                ADM_assert(0);
+            }
+            listOfAllocatedSurface[s]=true;
             return s;
         }
         aprintf("Error creating surface\n");
         return VA_INVALID;
-    
 }
 /**
  * \fn destroySurface
@@ -569,6 +731,15 @@ void        admLibVA::destroySurface( VASurfaceID surface)
 {
       int xError;
       CHECK_WORKING();
+
+      surfaceList::iterator already;
+      already=listOfAllocatedSurface.find(surface);
+      if(already==listOfAllocatedSurface.end())
+      {
+          ADM_warning("Trying to destroy an unallocated surface\n");
+          ADM_assert(0);
+      }
+      listOfAllocatedSurface.erase(surface);
       CHECK_ERROR(vaDestroySurfaces(ADM_coreLibVA::display,&surface,1));
         if(!xError)
         {
@@ -582,7 +753,7 @@ void        admLibVA::destroySurface( VASurfaceID surface)
  * \fn surfaceToImage
  * @param id
  * @param img
- * @return 
+ * @return
  */
 bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src)
 {
@@ -594,8 +765,9 @@ bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src)
     //--------------------------
     // Wait for surface to be ready...
     //--------------------------
-    int countDown=20;
-    while(1)
+    int countDown=50;
+    bool end=false;
+    while(!end)
     {
      CHECK_ERROR(vaQuerySurfaceStatus ( ADM_coreLibVA::display, src->surface,&status));
      if(xError)
@@ -603,14 +775,34 @@ bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src)
          ADM_warning("QuerySurfacStatus failed\n");
          return false;
      }
-     if(status==VASurfaceReady) break;
-     countDown--;
-     if(!countDown) 
+     aprintf("surface status = %d\n",status);
+     switch(status)
      {
-         ADM_warning("Timeout waiting for surface\n");
-         return false;
-     }
-     ADM_usleep(1000);
+        case VASurfaceReady:
+                end=true;
+                continue;
+                break;
+        case VASurfaceSkipped:
+                end=true;
+                continue;
+                break;
+      default:
+          countDown--;
+          if(!countDown)
+          {
+              ADM_warning("Timeout waiting for surface\n");
+              end=true;
+              continue;
+          }
+          ADM_usleep(1000);
+          break;
+    }
+   }
+    if(status!=VASurfaceReady)
+    {
+      ADM_warning("Error getting surface within timeout = %d\n",(int)status);
+      dest->_noPicture=true;
+      return true;
     }
     //--------------------------
     // Derive Image
@@ -626,14 +818,14 @@ bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src)
     {
         case VA_FOURCC_YV12:break;
         case VA_FOURCC_NV12:break;
-        default:  
+        default:
             ADM_warning("Unknown format %s\n",fourCC_tostring(vaImage.format.fourcc));
             goto dropIt;
     }
     // Map image...
-     
+
     CHECK_ERROR(vaMapBuffer(ADM_coreLibVA::display, vaImage.buf, (void**)&ptr))
-    if(!xError)        
+    if(!xError)
     {
          switch(vaImage.format.fourcc)
         {
@@ -653,16 +845,17 @@ bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src)
                     dest->convertFromNV12(ptr+vaImage.offsets[0],ptr+vaImage.offsets[1], vaImage.pitches[0], vaImage.pitches[1]);
                     break;
                 }
-                default:  
-                        goto dropIt;
-    }
-         r=true;
+                default:
+                    goto dropIt;
+                    break;
+        }
+        r=true;
         CHECK_ERROR(vaUnmapBuffer(ADM_coreLibVA::display, vaImage.buf))
     }
-dropIt:    
+dropIt:
     CHECK_ERROR(vaDestroyImage (ADM_coreLibVA::display,vaImage.image_id));
-    
-    
+
+
     return r;
 }
 /**
@@ -671,7 +864,7 @@ dropIt:
  * @param widget
  * @param displayWidth
  * @param displayHeight
- * @return 
+ * @return
  */
 bool        admLibVA::putX11Surface(ADM_vaSurface *img,int widget,int displayWidth,int displayHeight)
 {
@@ -694,7 +887,7 @@ bool        admLibVA::putX11Surface(ADM_vaSurface *img,int widget,int displayWid
  */
 bool   admLibVA::imageToSurface(VAImage *src, ADM_vaSurface *dst)
 {
-    
+
     int xError;
     VASurfaceStatus status;
     CHECK_WORKING(false);
@@ -718,12 +911,12 @@ bool   admLibVA::imageToSurface(VAImage *src, ADM_vaSurface *dst)
  */
 bool   admLibVA::surfaceToImage(ADM_vaSurface *dst,VAImage *src )
 {
-    
+
     int xError;
     VASurfaceStatus status;
     CHECK_WORKING(false);
     CHECK_ERROR(vaGetImage(ADM_coreLibVA::display,
-                           dst->surface,                           
+                           dst->surface,
                            0,0,
                            dst->w,dst->h,
                            src->image_id
@@ -740,7 +933,7 @@ bool   admLibVA::surfaceToImage(ADM_vaSurface *dst,VAImage *src )
  * \fn uploadToImage
  * @param dest
  * @param src
- * @return 
+ * @return
  */
 bool   admLibVA::uploadToImage( ADMImage *src,VAImage *dest)
 {
@@ -749,7 +942,7 @@ bool   admLibVA::uploadToImage( ADMImage *src,VAImage *dest)
     CHECK_WORKING(false);
     uint8_t *ptr=NULL;
     CHECK_ERROR(vaMapBuffer(ADM_coreLibVA::display, dest->buf, (void**)&ptr))
-    if(xError)        
+    if(xError)
     {
         ADM_warning("Cannot map image\n");
         return false;
@@ -770,7 +963,7 @@ bool   admLibVA::uploadToImage( ADMImage *src,VAImage *dest)
         case VA_FOURCC_NV12:src->convertToNV12(  ptr+dest->offsets[0], ptr+dest->offsets[1],dest->pitches[0],dest->pitches[1]);break;
         default: ADM_assert(0);
     }
-    CHECK_ERROR(vaUnmapBuffer (ADM_coreLibVA::display,dest->buf));    
+    CHECK_ERROR(vaUnmapBuffer (ADM_coreLibVA::display,dest->buf));
     return true;
 }
 
@@ -778,7 +971,7 @@ bool   admLibVA::uploadToImage( ADMImage *src,VAImage *dest)
  * \fn uploadToImage
  * @param dest
  * @param src
- * @return 
+ * @return
  */
 bool   admLibVA::downloadFromImage( ADMImage *src,VAImage *dest)
 {
@@ -787,7 +980,7 @@ bool   admLibVA::downloadFromImage( ADMImage *src,VAImage *dest)
     CHECK_WORKING(false);
     uint8_t *ptr=NULL;
     CHECK_ERROR(vaMapBuffer(ADM_coreLibVA::display, dest->buf, (void**)&ptr))
-    if(xError)        
+    if(xError)
     {
         ADM_warning("Cannot map image\n");
         return false;
@@ -811,7 +1004,7 @@ bool   admLibVA::downloadFromImage( ADMImage *src,VAImage *dest)
                         break;
         default: ADM_assert(0);
     }
-    CHECK_ERROR(vaUnmapBuffer (ADM_coreLibVA::display,dest->buf));    
+    CHECK_ERROR(vaUnmapBuffer (ADM_coreLibVA::display,dest->buf));
     return true;
 }
 /**
@@ -820,7 +1013,7 @@ bool   admLibVA::downloadFromImage( ADMImage *src,VAImage *dest)
  * @param dest
  * @param src
  */
-static void  copyNV12(uint8_t *ptr, VAImage *dest, ADMImage *src) 
+static void  copyNV12(uint8_t *ptr, VAImage *dest, ADMImage *src)
 {
           int w=src->_width;
 
@@ -835,7 +1028,7 @@ static void  copyNV12(uint8_t *ptr, VAImage *dest, ADMImage *src)
                 s+=srcStride;
                 d+=dstStride;
          }
-         
+
         w=w/2;
         h=h/2;
         uint8_t *srcu=src->GetReadPtr(PLANAR_U);
@@ -849,15 +1042,15 @@ static void  copyNV12(uint8_t *ptr, VAImage *dest, ADMImage *src)
                 uint8_t *ssrcu=srcu;
                 uint8_t *ssrcv=srcv;
                 uint8_t *d=dstPtr;
-                
+
                 srcu+=uStride;
                 srcv+=vStride;
                 dstPtr+=dstStride;
 
                 for(int x=0;x<w;x++)
                 {
-                    d[0]=*ssrcu++;
-                    d[1]=*ssrcv++;
+                    d[0]=*ssrcv++;
+                    d[1]=*ssrcu++;
                     d+=2;
                 }
         }
@@ -866,7 +1059,7 @@ static void  copyNV12(uint8_t *ptr, VAImage *dest, ADMImage *src)
  * \fn uploadToSurface
  * @param src
  * @param dest
- * @return 
+ * @return
  */
 bool   admLibVA:: admImageToSurface( ADMImage *src,ADM_vaSurface *dest)
 {
@@ -875,7 +1068,7 @@ bool   admLibVA:: admImageToSurface( ADMImage *src,ADM_vaSurface *dest)
     VASurfaceStatus status;
     CHECK_WORKING(false);
     uint8_t *ptr=NULL;
-    
+
     VAImage vaImage;
     CHECK_ERROR(vaDeriveImage (ADM_coreLibVA::display, dest->surface,&vaImage));
     if(xError)
@@ -888,7 +1081,7 @@ bool   admLibVA:: admImageToSurface( ADMImage *src,ADM_vaSurface *dest)
     {
         case VA_FOURCC_YV12:break;
         case VA_FOURCC_NV12:break;
-        default:  
+        default:
             ADM_warning("Unknown format %s\n",fourCC_tostring(vaImage.format.fourcc));
             goto dontTry;
     }
@@ -896,14 +1089,14 @@ bool   admLibVA:: admImageToSurface( ADMImage *src,ADM_vaSurface *dest)
     // Map image...
 
     CHECK_ERROR(vaMapBuffer(ADM_coreLibVA::display, vaImage.buf, (void**)&ptr))
-    if(!xError)        
+    if(!xError)
     {
          r=true;
          // NV12 or YV12
         switch(vaImage.format.fourcc)
         {
-            case VA_FOURCC_YV12: 
-            {
+            case VA_FOURCC_YV12:
+                {
                 ADMImageRefWrittable ref(src->_width,src->_height);
                 for(int i=0;i<3;i++)
                 {
@@ -911,29 +1104,33 @@ bool   admLibVA:: admImageToSurface( ADMImage *src,ADM_vaSurface *dest)
                         ref._planeStride[i]=vaImage.pitches[i];
                 }
                 ref.duplicate(src);
-            }break;
-            case VA_FOURCC_NV12: copyNV12(ptr,&vaImage,src);break;
-            default:  
+                }
+                break;
+            case VA_FOURCC_NV12:
+                copyNV12(ptr,&vaImage,src);
+                break;
+            default:
                 ADM_warning("Unknown format %s\n",fourCC_tostring(vaImage.format.fourcc));
+                break;
         }
         CHECK_ERROR(vaUnmapBuffer(ADM_coreLibVA::display, vaImage.buf))
     }
-dontTry:    
+dontTry:
     CHECK_ERROR(vaDestroyImage (ADM_coreLibVA::display,vaImage.image_id));
-    
+
     return r;
 }
 /**
- * 
+ *
  * @param image
- * @return 
+ * @return
  */
 bool ADM_vaSurface::fromAdmImage (ADMImage *dest)
 {
     switch(ADM_coreLibVA::transferMode)
     {
     case   admLibVA::ADM_LIBVA_NONE: ADM_warning("No transfer supported\n");return false;break;
-    case   admLibVA::ADM_LIBVA_DIRECT:   
+    case   admLibVA::ADM_LIBVA_DIRECT:
                 //printf("Direct\n");
                 return admLibVA::admImageToSurface (dest,this);
     case   admLibVA::ADM_LIBVA_INDIRECT_NV12:
@@ -949,16 +1146,75 @@ bool ADM_vaSurface::fromAdmImage (ADMImage *dest)
     return false;
 }
 /**
- * 
+ * allocateWithSurface
+ * @param w
+ * @param h
+ * @return
+ */
+ADM_vaSurface *ADM_vaSurface::allocateWithSurface(int w,int h)
+{
+    ADM_vaSurface *s=new ADM_vaSurface(w,h);
+    s->surface=admLibVA::allocateSurface(w,h);
+    if(!s->hasValidSurface())
+    {
+        delete s;
+        s=NULL;
+        ADM_warning("Cannot allocate va surface\n");
+        return NULL;
+    }
+    return s;
+}
+
+/**
+ *
+ * @return
+ */
+bool ADM_vaSurface_cleanupCheck(void)
+{
+    int n=listOfAllocatedSurface.size();
+    if(!n) return true;
+
+    ADM_warning("Some allocated va surface are still in use (%d), clearing them\n");
+    return true;
+
+}
+/**
+ *
+ * @return
+ */
+bool ADM_vaImage_cleanupCheck(void)
+{
+    int n=listOfAllocatedVAImage.size();
+    if(!n) return true;
+
+    ADM_warning("Some allocated va images are still in use (%d), clearing them\n");
+    return true;
+
+}
+/**
+ * \fn admLibVa_exitCleanup
+ */
+bool admLibVa_exitCleanup()
+{
+    ADM_info("VA cleanup begin\n");
+    ADM_vaSurface_cleanupCheck();
+    ADM_vaImage_cleanupCheck();
+    admLibVA::cleanup();
+    ADM_info("VA cleanup end\n");
+    return true;
+}
+
+/**
+ *
  * @param image
- * @return 
+ * @return
  */
 bool ADM_vaSurface::toAdmImage(ADMImage *dest)
 {
     switch(ADM_coreLibVA::transferMode)
     {
     case   admLibVA::ADM_LIBVA_NONE: ADM_warning("No transfer supported\n");return false;break;
-    case   admLibVA::ADM_LIBVA_DIRECT:   
+    case   admLibVA::ADM_LIBVA_DIRECT:
                 //printf("Direct\n");
                 return admLibVA::surfaceToAdmImage(dest,this);
     case   admLibVA::ADM_LIBVA_INDIRECT_NV12:
@@ -973,7 +1229,60 @@ bool ADM_vaSurface::toAdmImage(ADMImage *dest)
     }
     return false;
 }
+/**
+ *
+ * @return
+ */
+VAConfigID  admLibVA::createFilterConfig()
+{
+      VAStatus xError;
+      VAConfigID id=VA_INVALID;
+
+      if(!coreLibVAWorking) {ADM_warning("Libva not operationnal\n");return VA_INVALID;}
+
+      CHECK_ERROR(vaCreateConfig(ADM_coreLibVA::display, VAProfileNone, VAEntrypointVideoProc, 0, 0, &id));
+      if(xError!=VA_STATUS_SUCCESS)
+          return VA_INVALID;
+      return id;
+}
+
+/**
+ *
+ * @return
+ */
+VAContextID admLibVA::createFilterContext()
+{
+    return VA_INVALID;
+}
+/**
+ *
+ * @param id
+ * @return
+ */
+bool        admLibVA::destroyFilterContext(VAContextID &id)
+{
+     VAStatus xError;
+     if(!coreLibVAWorking) {ADM_warning("Libva not operationnal\n");return false;}
+
+    CHECK_ERROR( vaDestroyContext(ADM_coreLibVA::display, id));
+    id=VA_INVALID;
+    return true;
+}
+
+/**
+ *
+ * @return
+ */
+bool        admLibVA::destroyFilterConfig(VAConfigID &id)
+{
+    VAStatus xError;
+     if(!coreLibVAWorking) {ADM_warning("Libva not operationnal\n");return false;}
+
+    CHECK_ERROR( vaDestroyConfig(ADM_coreLibVA::display, id));
+    id=VA_INVALID;
+    return true;
+}
+
+
 #include "ADM_coreLibVA_encoder.cpp"
 #endif
-
-
