@@ -18,6 +18,7 @@
 #include "ADM_default.h"
 #include "ADM_ffmp43.h"
 #include "DIA_coreToolkit.h"
+#include "ADM_hwAccel.h"
 
 extern "C"
 {
@@ -61,13 +62,13 @@ uint8_t decoderFF::clonePic (AVFrame * src, ADMImage * out)
 
   ref->_planes[2] = (uint8_t *) src->data[v];
   ref->_planeStride[2] = src->linesize[v];
-
+  
   _lastQ = 0;			//_context->quality;
   out->_Qp = (src->quality * 32) / FF_LAMBDA_MAX;
   out->flags = frameType ();
 
   // Quant ?
-  if (src->qstride && src->qscale_table && codecId != CODEC_ID_H264)
+  if (src->qstride && src->qscale_table && codecId != AV_CODEC_ID_H264)
     {
       out->quant = (uint8_t *) src->qscale_table;
       out->_qStride = src->qstride;
@@ -192,7 +193,7 @@ decoderFF::decoderFF (uint32_t w, uint32_t h,uint32_t fcc, uint32_t extraDataLen
             memset(_extraDataCopy,0,extraDataLen+FF_INPUT_BUFFER_PADDING_SIZE);
             memcpy(_extraDataCopy,extraData,extraDataLen);
     }
-  
+   hwDecoder=NULL;
 
 }
 
@@ -224,60 +225,64 @@ decoderFF::~decoderFF ()
       delete [] _extraDataCopy;
       _extraDataCopy=NULL;
   }
+  delete hwDecoder;
+  hwDecoder=NULL;
+}
+/**
+ * 
+ * @param pic
+ * @return 
+ */
+uint32_t decoderFF::admFrameTypeFromLav (AVFrame *pic)
+{
+    uint32_t outFlags=0;
+#define SET(x)      {outFlags=x;}
+#define SET_ADD(x)  {outFlags|=x;}
+    
+  switch (pic->pict_type)
+    {
+        case AV_PICTURE_TYPE_B:
+                SET (AVI_B_FRAME);
+                break;
+        case AV_PICTURE_TYPE_I:
+                SET (AVI_KEY_FRAME);
+                if (!pic->key_frame)
+                  {
+                    if (codecId == AV_CODEC_ID_H264)
+                        SET (AVI_P_FRAME)
+                    else
+                      ADM_info ("\n But keyframe is not set\n");
+                  }
+                break;
+        case AV_PICTURE_TYPE_S:
+                _gmc = 1;			// No break, just inform that gmc is there
+        case AV_PICTURE_TYPE_P:
+                SET (AVI_P_FRAME);
+                if (pic->key_frame)
+                        aprintf ("\n But keyframe is set\n");
+                break;
+        default:
+                break;
+    }
+    outFlags&=~AVI_STRUCTURE_TYPE_MASK;
+    if(pic->interlaced_frame)
+    {
+        SET_ADD(AVI_FIELD_STRUCTURE)
+        if(pic->top_field_first)
+            SET_ADD(AVI_TOP_FIELD)
+        else
+            SET_ADD(AVI_BOTTOM_FIELD)
+    }
+  return outFlags;
 }
-
 /**
     \fn frameType
     \return frametype of the last decoded frame
 */
 uint32_t decoderFF::frameType (void)
 {
-  uint32_t
-    flag = 0;
+    return admFrameTypeFromLav(_frame);
 
-#define SET(x) {flag=x;aprintf("Frame is %s\n",#x);}
-
-  switch (_frame->pict_type)
-    {
-    case AV_PICTURE_TYPE_B:
-      SET (AVI_B_FRAME);
-      if (_frame->key_frame)
-	aprintf ("\n But keyframe is set\n");
-      break;
-
-    case AV_PICTURE_TYPE_I:
-      SET (AVI_KEY_FRAME);
-      if (!_frame->key_frame)
-	{
-	  if (codecId == CODEC_ID_H264)
-	    {
-	      SET (AVI_P_FRAME);
-	    }
-	  else
-	    printf ("\n But keyframe is not set\n");
-	}
-      break;
-    case AV_PICTURE_TYPE_S:
-      _gmc = 1;			// No break, just inform that gmc is there
-    case AV_PICTURE_TYPE_P:
-      SET (AVI_P_FRAME);
-      if (_frame->key_frame)
-	aprintf ("\n But keyframe is set\n");
-      break;
-    default:
-//                              printf("\n OOops XXX frame ?\n");
-      break;
-    }
-    flag&=~AVI_STRUCTURE_TYPE_MASK;
-    if(_frame->interlaced_frame)
-    {
-        flag|=AVI_FIELD_STRUCTURE;
-        if(_frame->top_field_first)
-            flag|=AVI_TOP_FIELD;
-        else
-            flag|=AVI_BOTTOM_FIELD;
-    }
-  return flag;
 }
 bool decoderFF::decodeHeaderOnly (void)
 {
@@ -316,6 +321,10 @@ bool   decoderFF::uncompress (ADMCompressedImage * in, ADMImage * out)
   uint8_t *oBuff[3];
   int ret = 0;
   out->_noPicture = 0;
+  if(hwDecoder)
+        return hwDecoder->uncompress(in,out);
+ 
+  
   if (decoderFF_params.showMv)
     {
       _context->debug_mv |= FF_SHOW;
@@ -384,7 +393,7 @@ bool   decoderFF::uncompress (ADMCompressedImage * in, ADMImage * out)
       // vop flag set to 0
       // it is meant to mean frame skipped but very dubious
       if (in->dataLength <= 8)
-        if(codecId == CODEC_ID_MPEG4||codecId==CODEC_ID_FRAPS)
+        if(codecId == AV_CODEC_ID_MPEG4||codecId==AV_CODEC_ID_FRAPS)
 	{
 	  printf ("[lavc] Probably pseudo black frame...\n");
 	  out->_Qp = 2;
@@ -430,52 +439,55 @@ bool   decoderFF::uncompress (ADMCompressedImage * in, ADMImage * out)
   // We have an image....
   switch (_context->pix_fmt)
     {
-    case PIX_FMT_YUV411P:
+    case AV_PIX_FMT_YUV411P:
       out->_colorspace = ADM_COLOR_YUV411;
       break;
-    case PIX_FMT_YUYV422:
+    case AV_PIX_FMT_YUYV422:
       out->_colorspace = ADM_COLOR_YUV422;
       break;
-    case PIX_FMT_YUV422P:
-    case PIX_FMT_YUVJ422P:
+    case AV_PIX_FMT_YUV422P:
+    case AV_PIX_FMT_YUVJ422P:
       out->_colorspace = ADM_COLOR_YUV422P;
       break;
-    case PIX_FMT_GRAY8:
+    case AV_PIX_FMT_GRAY8:
        out->_colorspace = ADM_COLOR_Y8;
        break;
-    case PIX_FMT_YUV444P:
-    case PIX_FMT_YUVJ444P:
+    case AV_PIX_FMT_YUV444P:
+    case AV_PIX_FMT_YUVJ444P:
       out->_colorspace = ADM_COLOR_YUV444;
       break;
-    case PIX_FMT_YUV420P:
-    case PIX_FMT_YUVJ420P:
-    case PIX_FMT_YUVA420P:
+    case AV_PIX_FMT_YUV420P:
+    case AV_PIX_FMT_YUVJ420P:
+    case AV_PIX_FMT_YUVA420P:
       // Default is YV12 or I420
       // In that case depending on swap u/v
       // we do it or not
       out->_colorspace = ADM_COLOR_YV12;
       break;
-   case PIX_FMT_BGR24:
-   case PIX_FMT_RGB24:
+   case AV_PIX_FMT_BGR24:
+   case AV_PIX_FMT_RGB24:
 	  out->_colorspace = ADM_COLOR_BGR24;
 	  break;
-    case PIX_FMT_BGRA:
+    case AV_PIX_FMT_BGR0:
+    case AV_PIX_FMT_BGRA:
       out->_colorspace = ADM_COLOR_BGR32A;
       break;
-    case PIX_FMT_RGBA: // ???PIX_FMT_RGBA32:
+    case AV_PIX_FMT_RGBA: // ???PIX_FMT_RGBA32:
       out->_colorspace = ADM_COLOR_RGB32A;
       break;
-    case PIX_FMT_RGB555:
+    case AV_PIX_FMT_RGB555:
       out->_colorspace = ADM_COLOR_RGB555;
       break;
-    case PIX_FMT_VDPAU_MPEG1:
-    case PIX_FMT_VDPAU_MPEG2:
-    case PIX_FMT_VDPAU_WMV3:
-    case PIX_FMT_VDPAU_VC1:
-    case PIX_FMT_VDPAU_H264:
+#if 0
+    case AV_PIX_FMT_VDPAU_MPEG1:
+    case AV_PIX_FMT_VDPAU_MPEG2:
+    case AV_PIX_FMT_VDPAU_WMV3:
+    case AV_PIX_FMT_VDPAU_VC1:
+    case AV_PIX_FMT_VDPAU_H264:
+    case AV_PIX_FMT_VDPAU:
         out->_colorspace=ADM_COLOR_VDPAU;
-        break;
-    case PIX_FMT_VAAPI_VLD:
+        break;        
+    case AV_PIX_FMT_VAAPI:
         out->_colorspace=ADM_COLOR_LIBVA;
         break;
         
@@ -484,11 +496,15 @@ bool   decoderFF::uncompress (ADMCompressedImage * in, ADMImage * out)
         out->_colorspace=ADM_COLOR_XVBA;
         break;
 #endif        
+#endif
+  case AV_PIX_FMT_YUV444P10LE:
+        out->_colorspace=ADM_COLOR_YUV444_10BITS;
+        break;        
   case  AV_PIX_FMT_YUV420P10LE      :  
         out->_colorspace=ADM_COLOR_YV12_10BITS;
         break;
     default:
-      printf ("[lavc] Unhandled colorspace: %d\n", _context->pix_fmt);
+      printf ("[lavc] Unhandled colorspace: %d (AV_PIX_FMT_YUV444P10BE=%d)\n", _context->pix_fmt,AV_PIX_FMT_YUV444P10BE);
       return 0;
     }
     clonePic (_frame, out);
@@ -504,7 +520,7 @@ decoderFFDiv3::decoderFFDiv3 (uint32_t w, uint32_t h,uint32_t fcc, uint32_t extr
 decoderFF (w, h,fcc,extraDataLen,extraData,bpp)
 {
   _refCopy = 1;			// YUV420 only
-  WRAP_Open (CODEC_ID_MSMPEG4V3);
+  WRAP_Open (AV_CODEC_ID_MSMPEG4V3);
 }
 
 decoderFFMpeg4::decoderFFMpeg4 (uint32_t w, uint32_t h,uint32_t fcc, uint32_t extraDataLen, uint8_t *extraData,uint32_t bpp):
@@ -516,7 +532,7 @@ decoderFF (w, h,fcc,extraDataLen,extraData,bpp)
   _refCopy = 1;			// YUV420 only
   _setFcc=true;
   decoderMultiThread ();
-  WRAP_Open (CODEC_ID_MPEG4);
+  WRAP_Open (AV_CODEC_ID_MPEG4);
   
 }
 bool decoderFFMpeg4::uncompress (ADMCompressedImage * in, ADMImage * out)
@@ -535,7 +551,7 @@ decoderFFDV::decoderFFDV (uint32_t w, uint32_t h,uint32_t fcc, uint32_t extraDat
 decoderFF (w, h,fcc,extraDataLen,extraData,bpp)
 {
     
-    WRAP_Open (CODEC_ID_DVVIDEO);
+    WRAP_Open (AV_CODEC_ID_DVVIDEO);
   
 
 }
@@ -544,12 +560,12 @@ decoderFFMpeg12::decoderFFMpeg12 (uint32_t w, uint32_t h,uint32_t fcc, uint32_t
 {
   _refCopy = 1;			// YUV420 only
   decoderMultiThread ();
-  WRAP_Open (CODEC_ID_MPEG2VIDEO);
+  WRAP_Open (AV_CODEC_ID_MPEG2VIDEO);
 }
 
 decoderFFPng::decoderFFPng(uint32_t w, uint32_t h, uint32_t fcc, uint32_t extraDataLen, uint8_t *extraData, uint32_t bpp) : decoderFF(w, h, fcc, extraDataLen, extraData, bpp)
 {
-	WRAP_Open (CODEC_ID_PNG);
+	WRAP_Open (AV_CODEC_ID_PNG);
 }
 
 decoderFF_ffhuff::decoderFF_ffhuff (uint32_t w, uint32_t h,uint32_t fcc, uint32_t extraDataLen, uint8_t *extraData,uint32_t bpp)
@@ -558,7 +574,7 @@ decoderFF_ffhuff::decoderFF_ffhuff (uint32_t w, uint32_t h,uint32_t fcc, uint32_
     
   _setBpp=true;
   ADM_info ("[lavc] FFhuff: We have %d bytes of extra data\n", (int)extraDataLen);
-  WRAP_Open (CODEC_ID_FFVHUFF);  
+  WRAP_Open (AV_CODEC_ID_FFVHUFF);  
 
 }
 decoderFFH264::decoderFFH264 (uint32_t w, uint32_t h,uint32_t fcc, uint32_t extraDataLen, uint8_t *extraData,uint32_t bpp)
@@ -567,7 +583,7 @@ decoderFFH264::decoderFFH264 (uint32_t w, uint32_t h,uint32_t fcc, uint32_t extr
   _refCopy = 1;			// YUV420 only
   decoderMultiThread ();
   ADM_info ("[lavc] Initializing H264 decoder with %d extradata\n", (int)extraDataLen);
-  WRAP_Open(CODEC_ID_H264);
+  WRAP_Open(AV_CODEC_ID_H264);
   
 }
 //*********************
@@ -606,7 +622,7 @@ decoderFFhuff::decoderFFhuff (uint32_t w, uint32_t h,uint32_t fcc, uint32_t extr
 decoderFF (w, h,fcc,extraDataLen,extraData,bpp)
 {
   _setBpp=true;
-  WRAP_Open (CODEC_ID_HUFFYUV);
+  WRAP_Open (AV_CODEC_ID_HUFFYUV);
 }
 
 //***************
