@@ -15,7 +15,6 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#define __STDC_CONSTANT_MACROS
 #include "ADM_default.h"
 #include "ADM_coreVideoEncoderFFmpeg.h"
 #include "prefs.h"
@@ -59,6 +58,8 @@ _hasSettings=false;
     image=new ADMImageDefault(w,h);
     _frame=av_frame_alloc();
     _frame->pts = AV_NOPTS_VALUE;
+    _frame->width=w;
+    _frame->height=h;
     rgbByteBuffer.setSize((w+7)*(h+7)*4);
     colorSpace=NULL;
     pass=0;
@@ -133,15 +134,18 @@ bool             ADM_coreVideoEncoderFFmpeg::prolog(ADMImage *img)
         case ADM_COLOR_YV12:    _frame->linesize[0] = img->GetPitch(PLANAR_Y);
                                 _frame->linesize[1] = img->GetPitch(PLANAR_U);
                                 _frame->linesize[2] = img->GetPitch(PLANAR_V);
-                                _context->pix_fmt =PIX_FMT_YUV420P;break;
+                                _frame->format=AV_PIX_FMT_YUV420P;
+                                _context->pix_fmt =AV_PIX_FMT_YUV420P;break;
         case ADM_COLOR_YUV422P: _frame->linesize[0] = w;
                                 _frame->linesize[1] = w>>1;
                                 _frame->linesize[2] = w>>1;
-                                _context->pix_fmt =PIX_FMT_YUV422P;break;
+                                _frame->format=AV_PIX_FMT_YUV422P;
+                                _context->pix_fmt =AV_PIX_FMT_YUV422P;break;
         case ADM_COLOR_RGB32A : _frame->linesize[0] = w*4;
                                 _frame->linesize[1] = 0;//w >> 1;
                                 _frame->linesize[2] = 0;//w >> 1;
-                                _context->pix_fmt =PIX_FMT_RGB32;break;
+                                _frame->format=AV_PIX_FMT_RGB32;
+                                _context->pix_fmt =AV_PIX_FMT_RGB32;break;
         default: ADM_assert(0);
 
     }
@@ -206,7 +210,7 @@ bool             ADM_coreVideoEncoderFFmpeg::preEncode(void)
 
     uint64_t p=image->Pts;
     queueOfDts.push_back(p);
-    aprintf("Incoming frame PTS=%"PRIu64", delay=%"PRIu64"\n",p,getEncoderDelay());
+    aprintf("Incoming frame PTS=%" PRIu64", delay=%" PRIu64"\n",p,getEncoderDelay());
     p+=getEncoderDelay();
     _frame->pts= timingToLav(p);    //
     if(!_frame->pts) _frame->pts=AV_NOPTS_VALUE;
@@ -216,7 +220,7 @@ bool             ADM_coreVideoEncoderFFmpeg::preEncode(void)
     map.internalTS=_frame->pts;
     mapper.push_back(map);
 
-    aprintf("Codec> incoming pts=%"PRIu64"\n",image->Pts);
+    aprintf("Codec> incoming pts=%" PRIu64"\n",image->Pts);
     //printf("--->>[PTS] :%"PRIu64", raw %"PRIu64" num:%"PRIu32" den:%"PRIu32"\n",_frame->pts,image->Pts,_context->time_base.num,_context->time_base.den);
     //
     switch(targetColorSpace)
@@ -266,6 +270,32 @@ bool             ADM_coreVideoEncoderFFmpeg::configureContext(void)
 {
     return true;
 }
+
+/**
+ * \fn encodeWrapper
+ */
+int              ADM_coreVideoEncoderFFmpeg::encodeWrapper(AVFrame *in,ADMBitstream *out)
+{
+    int r,gotData;
+        AVPacket pkt;
+        av_init_packet(&pkt);
+        pkt.data=out->data;
+        pkt.size=out->bufferSize;
+
+
+        r= avcodec_encode_video2 (_context,&pkt,in, &gotData);
+        if(r<0)
+        {
+            ADM_warning("Error %d encoding video\n",r);
+            return r;
+        }
+        if(!gotData)
+        {
+            ADM_warning("Encoder produced no data\n");
+            pkt.size=0;
+        }
+        return pkt.size;            
+}
 /**
  * 
  * @param codecId
@@ -412,7 +442,7 @@ bool ADM_coreVideoEncoderFFmpeg::postEncode(ADMBitstream *out, uint32_t size)
         ADM_warning("No picture...\n");
         return false;
     }
-    aprintf("[ffMpeg4] Out Quant :%d, pic type %d keyf %d\n",out->out_quantizer,pict_type,keyframe);
+    aprintf("[ffMpeg4] Out Quant :%d, pic type %d keyf %d %p\n",out->out_quantizer,pict_type,keyframe,_context->coded_frame);
     out->len=size;
     out->flags=0;
     if(keyframe)
@@ -423,15 +453,27 @@ bool ADM_coreVideoEncoderFFmpeg::postEncode(ADMBitstream *out, uint32_t size)
     // Update PTS/Dts
     if(!_context->max_b_frames)
     {
-            out->dts=out->pts=queueOfDts[0];
-            mapper.erase(mapper.begin());
-            queueOfDts.erase(queueOfDts.begin());
+            if(mapper.size())
+                mapper.erase(mapper.begin());
+            if(queueOfDts.size())
+            {
+                out->dts=out->pts=queueOfDts[0];
+                queueOfDts.erase(queueOfDts.begin());
+            }else
+            {
+                out->dts=out->pts=lastDts+ source->getInfo()->frameIncrement;
+                return false; // probably empty now
+            }
+
     } else
-    getRealPtsFromInternal(_context->coded_frame->pts,&(out->dts),&(out->pts));
+    {
+        if(!getRealPtsFromInternal(_context->coded_frame->pts,&(out->dts),&(out->pts)))
+                return false;
+    }
     // update lastDts
     lastDts=out->dts;
 
-    aprintf("Codec>Out pts=%"PRIu64" us, out Dts=%"PRIu64"\n",out->pts,out->dts);
+    aprintf("Codec>Out pts=%" PRIu64" us, out Dts=%" PRIu64"\n",out->pts,out->dts);
 
     // Update quant
     if(!_context->coded_frame->quality)
@@ -580,7 +622,7 @@ bool ADM_coreVideoEncoderFFmpeg::setupPass(void)
                 averageBitrate=(uint32_t)avg*1000; // convert from kb/s to b/s
             }
 
-        printf("[ffmpeg4] Average bitrate =%"PRIu32" kb/s\n",averageBitrate/1000);
+        printf("[ffmpeg4] Average bitrate =%" PRIu32" kb/s\n",averageBitrate/1000);
         _context->bit_rate=averageBitrate;
         switch(pass)
         {
