@@ -45,8 +45,8 @@ uint8_t mkvHeader::videoIndexer(ADM_ebml_file *parser)
   const char *ss;
 
    parser->seek(0);
-   DIA_workingBase *work=createWorking("Matroska Images");
-   
+   DIA_workingBase *work=createWorking(QT_TRANSLATE_NOOP("matroskademuxer","Matroska Images"));
+
    readBufferSize=200*1024;
    readBuffer=new uint8_t[readBufferSize];
     //************
@@ -55,7 +55,7 @@ uint8_t mkvHeader::videoIndexer(ADM_ebml_file *parser)
     int nbCluster=_clusters.size();
    for(int clusters=0;clusters<nbCluster;clusters++)
     {
-        printf("[Cluster] %d/%d StartTimecode=%"PRIu64" ms\n",clusters,nbCluster,_clusters[clusters].Dts);
+        printf("[Cluster] %d/%d StartTimecode=%" PRIu64" ms\n",clusters,nbCluster,_clusters[clusters].Dts);
     }
 #endif
     int nbClusters=_clusters.size();
@@ -70,7 +70,7 @@ uint8_t mkvHeader::videoIndexer(ADM_ebml_file *parser)
       cluster.readElemId(&id,&len);
       if(!ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type))
       {
-        printf("[MKV] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+        printf("[MKV] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
         cluster.skip(len);
         continue;
       }
@@ -96,7 +96,7 @@ uint8_t mkvHeader::videoIndexer(ADM_ebml_file *parser)
                                 blockGroup.readElemId(&id,&len);
                                 if(!ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type))
                                 {
-                                  printf("[MKV] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+                                  printf("[MKV] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
                                   blockGroup.skip(len);
                                   continue;
                                 }
@@ -121,7 +121,7 @@ uint8_t mkvHeader::videoIndexer(ADM_ebml_file *parser)
      }
    // printf("[MKV] ending cluster at 0x%llx\n",segment.tell());
   }
-     printf("Found %"PRIu32" images in this cluster\n",(uint32_t)VIDEO.index.size());
+     printf("Found %" PRIu32" images in this cluster\n",(uint32_t)VIDEO.index.size());
      delete work;
      delete [] readBuffer;
      readBuffer=NULL;
@@ -159,8 +159,8 @@ uint8_t mkvHeader::indexBlock(ADM_ebml_file *parser,uint32_t len,uint32_t cluste
       return 1;
 }
 /**
- * 
- * @return 
+ *
+ * @return
  */
 static int mkvFindStartCode(uint8_t *& start, uint8_t *end)
 {
@@ -181,11 +181,11 @@ static int mkvFindStartCode(uint8_t *& start, uint8_t *end)
 
 static bool canRederiveFrameType(uint32_t fcc)
 {
-    if(isMpeg4Compatible(fcc)) return true;
+    if(isMpeg4Compatible(fcc) || isVC1Compatible(fcc)) return true;
     if(isH264Compatible(fcc)) return true;
     if(isMpeg12Compatible(fcc)) return true;
     return false;
-    
+
 }
 
 /**
@@ -204,8 +204,9 @@ uint8_t mkvHeader::addIndexEntry(uint32_t track,ADM_ebml_file *parser,uint64_t w
   ix.flags=0;
   ix.Dts=timecodeMS*_timeBase;
   ix.Pts=timecodeMS*_timeBase;
+  //printf("Track=%d, timecode=%d timeBase=%d, Pts=%d\n",track,(int)timecodeMS,(int)_timeBase,ix.Pts);
    uint32_t rpt=_tracks[0].headerRepeatSize;
-   
+
    // expand buffer if needed
    if(size>readBufferSize)
    {
@@ -220,12 +221,12 @@ uint8_t mkvHeader::addIndexEntry(uint32_t track,ADM_ebml_file *parser,uint64_t w
   // since frame type is unreliable for mkv, we scan each frame
   // For the 2 most common cases : mp4 & h264.
   // Hackish, we already read the 3 bytes header
-  // But they are already taken into account in the size part 
+  // But they are already taken into account in the size part
   if(!track && canRederiveFrameType(_videostream.fccHandler)) // Track 0 is video
   {
     if( isMpeg4Compatible(_videostream.fccHandler))
     {
-        
+
             if(rpt)
                 memcpy(readBuffer,_tracks[0].headerRepeat,rpt);
             parser->readBin(readBuffer+rpt,size-3);
@@ -236,36 +237,36 @@ uint8_t mkvHeader::addIndexEntry(uint32_t track,ADM_ebml_file *parser,uint64_t w
              vops[0].type=AVI_KEY_FRAME;
              ADM_searchVop(readBuffer,readBuffer+rpt+size-3,&nb,vops, &timeinc);
              ix.flags=vops[0].type;
-        
+
     }else
     if(isH264Compatible(_videostream.fccHandler))
     {
-                
+
                 uint32_t flags=AVI_KEY_FRAME;
-                
+
                 if(rpt)
                         memcpy(readBuffer,_tracks[0].headerRepeat,rpt);
                 parser->readBin(readBuffer+rpt,size-3);
                 extractH264FrameType(2,readBuffer,rpt+size-3,&flags); // Nal size is not used in that case
                 if(flags & AVI_KEY_FRAME)
                 {
-                    printf("[MKV/H264] Frame %"PRIu32" is a keyframe\n",(uint32_t)Track->index.size());
+                    printf("[MKV/H264] Frame %" PRIu32" is a keyframe\n",(uint32_t)Track->index.size());
                 }
                 ix.flags=flags;
                 if(Track->index.size()) ix.Dts=ADM_NO_PTS;
 
     }/*else if(isH265Compatible(_videostream.fccHandler))
     {
-                
+
                 uint32_t flags=AVI_KEY_FRAME;
-                
+
                 if(rpt)
                         memcpy(readBuffer,_tracks[0].headerRepeat,rpt);
                 parser->readBin(readBuffer+rpt,size-3);
                 extractH265FrameType(2,readBuffer,rpt+size-3,&flags); // Nal size is not used in that case
                 if(flags & AVI_KEY_FRAME)
                 {
-                    printf("[MKV/H265] Frame %"PRIu32" is a keyframe\n",(uint32_t)Track->index.size());
+                    printf("[MKV/H265] Frame %" PRIu32" is a keyframe\n",(uint32_t)Track->index.size());
                 }
                 ix.flags=flags;
                 if(Track->index.size()) ix.Dts=ADM_NO_PTS;
@@ -282,7 +283,7 @@ uint8_t mkvHeader::addIndexEntry(uint32_t track,ADM_ebml_file *parser,uint64_t w
                 while(begin<end)
                 {
                     int code=mkvFindStartCode(begin,end);
-                    if(code==-1) 
+                    if(code==-1)
                     {
                         ADM_warning("[Mpg2InMkv]No startcode found\n");
                         break;
@@ -303,9 +304,21 @@ uint8_t mkvHeader::addIndexEntry(uint32_t track,ADM_ebml_file *parser,uint64_t w
                         }
                         break;
                     }
-                    
-                }             
-                
+
+                }
+
+    }else if(isVC1Compatible(_videostream.fccHandler))
+    {
+        if(rpt)
+                    memcpy(readBuffer,_tracks[0].headerRepeat,rpt);
+            parser->readBin(readBuffer+rpt,size-3);
+            uint8_t *begin=readBuffer;
+            uint8_t *end=readBuffer+size-3+rpt;
+            int frameType;
+            if(ADM_VC1getFrameType(begin, (int)(end-begin),&frameType))
+            {
+                ix.flags=frameType;
+            }
     }
   }
   Track->index.append(ix);
@@ -339,8 +352,8 @@ bool     mkvHeader::readCue(ADM_ebml_file *parser)
   ADM_MKV_TYPE type;
   const char *ss;
   uint64_t time;
-  
-  
+
+
 
   if(!goBeforeAtomAtPosition(parser, _cuePosition,vlen, MKV_CUES,"MKV_CUES"))
   {
@@ -354,7 +367,7 @@ bool     mkvHeader::readCue(ADM_ebml_file *parser)
            cues.readElemId(&id,&len);
            if(!ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type))
            {
-             printf("[MKV] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+             printf("[MKV] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
              cues.skip(len);
              continue;
            }
@@ -370,7 +383,7 @@ bool     mkvHeader::readCue(ADM_ebml_file *parser)
             if(id!=MKV_CUE_TIME)
             {
                ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type);
-               printf("Found %s(0x%"PRIx64"), expected CUE_TIME  (0x%x)\n", ss,id,MKV_CUE_TIME);
+               printf("Found %s(0x%" PRIx64"), expected CUE_TIME  (0x%x)\n", ss,id,MKV_CUE_TIME);
                cue.skip(cue.remaining());
                continue;
             }
@@ -381,7 +394,7 @@ bool     mkvHeader::readCue(ADM_ebml_file *parser)
             if(id!=MKV_CUE_TRACK_POSITION)
             {
                ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type);
-               printf("Found %s (0x%"PRIx64"), expected MKV_CUE_TRACK_POSITION (0x%x)\n", ss,id,MKV_CUE_TRACK_POSITION);
+               printf("Found %s (0x%" PRIx64"), expected MKV_CUE_TRACK_POSITION (0x%x)\n", ss,id,MKV_CUE_TRACK_POSITION);
                cue.skip(cues.remaining());
                continue;
             }
@@ -399,13 +412,13 @@ bool     mkvHeader::readCue(ADM_ebml_file *parser)
                 case MKV_CUE_RELATIVE_POSITION: cue_position=trackPos.readUnsignedInt(len);break;
                 default:
                       ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type);
-                      printf("[MKV] in cluster position found tag %s (0x%"PRIx64")\n",ss,id);
+                      printf("[MKV] in cluster position found tag %s (0x%" PRIx64")\n",ss,id);
                       trackPos.skip(len);
                       continue;
               }
             }
-            aprintf("Track %"PRIx64" segmentPos=%"PRIx64" Cluster Position 0x%"PRIx64" Cue position 0x%"PRIx64" Absolute=%"PRIx64" time %"PRIu64"\n",
-                  tid,_segmentPosition,cluster_position,cue_position,cue_position+cluster_position+_segmentPosition,time);  
+            aprintf("Track %" PRIx64" segmentPos=%" PRIx64" Cluster Position 0x%" PRIx64" Cue position 0x%" PRIx64" Absolute=%" PRIx64" time %" PRIu64"\n",
+                  tid,_segmentPosition,cluster_position,cue_position,cue_position+cluster_position+_segmentPosition,time);
 
             if(!searchTrackFromTid(tid)) //only keep video i.e. track zero
             {
@@ -423,7 +436,7 @@ bool     mkvHeader::readCue(ADM_ebml_file *parser)
        ADM_info("[MKV] No Cue found\n");
        return false;
    }
-   
+
 }
 /**
         \fn indexClusters
@@ -450,15 +463,15 @@ uint8_t   mkvHeader::indexClusters(ADM_ebml_file *parser)
    }
     // In case the segment is ridiculously small take file size....
    pos=parser->tell();
-   ADM_info("FileSize = %"PRIu64", pos=%"PRIu64" size=%"PRIu64",pos+size=%"PRIu64"\n",fileSize,pos,vlen,pos+vlen);
+   ADM_info("FileSize = %" PRIu64", pos=%" PRIu64" size=%" PRIu64",pos+size=%" PRIu64"\n",fileSize,pos,vlen,pos+vlen);
    if(pos+vlen<fileSize)
     {
         ADM_warning("Segment is way too small, trying to guess the right value\n");
         vlen=fileSize-pos;
     }
    ADM_ebml_file segment(parser,vlen);
-   
-   DIA_workingBase *work=createWorking("Matroska clusters");
+
+   DIA_workingBase *work=createWorking(QT_TRANSLATE_NOOP("matroskademuxer","Matroska clusters"));
    while(segment.simplefind(MKV_CLUSTER,&alen,0))
    {
 
@@ -486,7 +499,7 @@ tryAgain:
        {
           ss=NULL;
           ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type);
-          ADM_warning("[MKV] Cluster : no time code Found %s(0x%"PRIx64"), expected MKV_TIMECODE  (0x%x)\n",
+          ADM_warning("[MKV] Cluster : no time code Found %s(0x%" PRIx64"), expected MKV_TIMECODE  (0x%x)\n",
                   ss,id,MKV_TIMECODE);
        }
        else // timecode
@@ -510,13 +523,13 @@ tryAgain:
  *     length
  *     Actual image <= We point here
  * Typically the difference is ~ 16 bytes, so we accept anything between 0 and32
- * @return 
+ * @return
  */
 bool  mkvHeader::updateFlagsWithCue(void)
 {
     int nbImages=_tracks[0].index.size();
     int nbCues=_cueTime.size();
-    
+
     int lastImage=0;
     ADM_info("Updating Flags with Cue\n");
     for(int curCue=0;curCue<nbCues;curCue++)
@@ -524,7 +537,7 @@ bool  mkvHeader::updateFlagsWithCue(void)
         uint64_t tim=_cueTime[curCue];
         for(int curImage=lastImage;curImage<nbImages;curImage++)
         {
-            uint64_t thisTime=_tracks[0].index[curImage].Pts/_timeBase;            
+            uint64_t thisTime=_tracks[0].index[curImage].Pts/_timeBase;
             if( tim== thisTime)
             {
                 // match!
@@ -536,12 +549,12 @@ bool  mkvHeader::updateFlagsWithCue(void)
         }
     }
     ADM_info("Updating Flags with Cue done\n");
-    return true;   
+    return true;
 }
 /**
- * 
+ *
  * @param mx
- * @return 
+ * @return
  */
 bool mkvHeader::dumpVideoIndex(int mx)
 {
