@@ -219,6 +219,7 @@ bool	MP4Header::processAudio( MP4Track *track,  uint32_t trackScale,
       {
         default:break;
         case WAV_PCM: // wtf ?
+        case WAV_LPCM: // wtf ?
         case WAV_ULAW: // Wtf ?
         case WAV_IMAADPCM:
         case WAV_MSADPCM:
@@ -266,7 +267,7 @@ uint32_t i,j,cur;
         ADM_info("Build Track index\n");
 	*outNbChunk=0;
 	aprintf("+_+_+_+_+_+\n");
-	aprintf("co : %lu sz: %lu sc: %lu co[0] %"PRIu64"\n",info->nbCo,info->nbSz,info->nbSc,info->Co[0]);
+	aprintf("co : %lu sz: %lu sc: %lu co[0] %" PRIu64"\n",info->nbCo,info->nbSz,info->nbSc,info->Co[0]);
 	aprintf("+_+_+_+_+_+\n");
 
 	ADM_assert(info->Sc);
@@ -424,7 +425,7 @@ uint32_t i,j,cur;
 	}
 	else // there is not ssts
 	{
-          //GUI_Error_HIG(QT_TR_NOOP("No stts table"), NULL);
+          //GUI_Error_HIG(QT_TRANSLATE_NOOP("mp4demuxer","No stts table"), NULL);
           return false;
 	}
         printf("Index done\n");
