@@ -80,23 +80,35 @@ bool r;
     delete p;
     printf("[TsIndexer] Audio probed, %d found, doing video\n",(int)audioTrack.size());
     //
-    TsIndexer *dx=new TsIndexer(&audioTrack);
+    TsIndexerBase *dx=NULL;
     switch(tracks[0].trackType)
     {
             case ADM_TS_MPEG2: 
-                            r=dx->runMpeg2(file,&(tracks[0]));
+                            dx=new TsIndexerMpeg2(&audioTrack);
                             break;
             case ADM_TS_VC1: 
-                            r=dx->runVC1(file,&(tracks[0]));
+                            dx=new TsIndexerVC1(&audioTrack);
+                            break;
+            case ADM_TS_H265: 
+                            dx=new TsIndexerH265(&audioTrack);
                             break;
             case ADM_TS_H264: 
-                            r=dx->runH264(file,&(tracks[0]));
+                            dx=new TsIndexerH264(&audioTrack);
                             break;
             default:
                         r=0;
                         break;
     }
-    delete dx;
+    if(!dx)
+    {
+        ADM_warning("Unsupported video codec \n");
+        r=false;
+    }else
+    {
+        r=dx->run( file,&(tracks[0]));
+        delete dx;
+        dx=NULL;
+    }
     delete [] tracks;
     return r;
 }
@@ -104,9 +116,9 @@ bool r;
 /**
     \fn TsIndexer
 */
-TsIndexer::TsIndexer(listOfTsAudioTracks *trk)
+TsIndexerBase::TsIndexerBase(listOfTsAudioTracks *trk)
 {
-    memset(&spsInfo,0,sizeof(spsInfo));
+
     index=NULL;
     pkt=NULL;
     audioTracks=NULL;
@@ -119,7 +131,7 @@ TsIndexer::TsIndexer(listOfTsAudioTracks *trk)
 /**
     \fn ~TsIndexer
 */
-TsIndexer::~TsIndexer()
+TsIndexerBase::~TsIndexerBase()
 {
     if(index) qfclose(index);
     if(pkt) delete pkt;
@@ -130,7 +142,7 @@ TsIndexer::~TsIndexer()
     \fn updateUI
  *  \brief return false if abort is needed
 */
-bool  TsIndexer::updateUI(void)
+bool  TsIndexerBase::updateUI(void)
 {
     int p=++processedThisRound;
         processedThisRound=0;
@@ -141,7 +153,7 @@ bool  TsIndexer::updateUI(void)
     \fn writeVideo
     \brief Write Video section of index file
 */
-bool TsIndexer::writeVideo(TSVideo *video,ADM_TS_TRACK_TYPE trkType)
+bool TsIndexerBase::writeVideo(TSVideo *video,ADM_TS_TRACK_TYPE trkType)
 {
     qfprintf(index,"[Video]\n");
     qfprintf(index,"Width=%d\n",video->w);
@@ -161,6 +173,7 @@ bool TsIndexer::writeVideo(TSVideo *video,ADM_TS_TRACK_TYPE trkType)
     {
         case ADM_TS_MPEG2: qfprintf(index,"VideoCodec=Mpeg2\n");break;;
         case ADM_TS_H264:  qfprintf(index,"VideoCodec=H264\n");break;
+        case ADM_TS_H265:  qfprintf(index,"VideoCodec=H265\n");break;
         case ADM_TS_VC1:   qfprintf(index,"VideoCodec=VC1\n");break;
         default: printf("[TsIndexer] Unsupported video codec\n");return false;
 
@@ -171,7 +184,7 @@ bool TsIndexer::writeVideo(TSVideo *video,ADM_TS_TRACK_TYPE trkType)
     \fn writeSystem
     \brief Write system part of index file
 */
-bool TsIndexer::writeSystem(const char *filename,bool append)
+bool TsIndexerBase::writeSystem(const char *filename,bool append)
 {
     qfprintf(index,"PSD1\n");
     qfprintf(index,"[System]\n");
@@ -185,7 +198,7 @@ bool TsIndexer::writeSystem(const char *filename,bool append)
     \fn     writeAudio
     \brief  Write audio headers
 */
-bool TsIndexer::writeAudio(void)
+bool TsIndexerBase::writeAudio(void)
 {
     if(!audioTracks) return false;
     qfprintf(index,"[Audio]\n");
@@ -218,7 +231,7 @@ bool TsIndexer::writeAudio(void)
 /**
     \fn dumpUnits
 */
-bool TsIndexer::dumpUnits(indexerData &data,uint64_t nextConsumed,const dmxPacketInfo *nextPacket)
+bool TsIndexerBase::dumpUnits(indexerData &data,uint64_t nextConsumed,const dmxPacketInfo *nextPacket)
 {
         // if it contain a SPS or a intra/idr, we start a new line
         bool mustFlush=false;
@@ -253,7 +266,7 @@ bool TsIndexer::dumpUnits(indexerData &data,uint64_t nextConsumed,const dmxPacke
         {
             if(audioTracks)
             {
-                qfprintf(index,"\nAudio bf:%08"PRIx64" ",nextPacket->startAt);
+                qfprintf(index,"\nAudio bf:%08" PRIx64" ",nextPacket->startAt);
                 packetTSStats *s;
                 uint32_t na;
                 pkt->getStats(&na,&s);      
@@ -261,14 +274,14 @@ bool TsIndexer::dumpUnits(indexerData &data,uint64_t nextConsumed,const dmxPacke
                 for(int i=0;i<na;i++)
                 {   
                     packetTSStats *current=s+i;
-                    qfprintf(index,"Pes:%x:%08"PRIx64":%"PRIi32":%"PRId64" ",
+                    qfprintf(index,"Pes:%x:%08" PRIx64":%" PRIi32":%" PRId64" ",
                                 current->pid,current->startAt,current->startSize,current->startDts);
                 }                
             }
             data.beginPts=pic->pts;
             data.beginDts=pic->dts;
             // start a new line
-            qfprintf(index,"\nVideo at:%08"PRIx64":%04"PRIx32" Pts:%08"PRId64":%08"PRId64" ",
+            qfprintf(index,"\nVideo at:%08" PRIx64":%04" PRIx32" Pts:%08" PRId64":%08" PRId64" ",
                         p->startAt,p->offset-unit->overRead,pic->pts,pic->dts);
         }
        
@@ -284,8 +297,11 @@ bool TsIndexer::dumpUnits(indexerData &data,uint64_t nextConsumed,const dmxPacke
 
         qfprintf(index," %c%c",Type[picUnit->imageType],Structure[pictStruct&3]);
         int32_t delta=(int32_t)(nextConsumed-beginConsuming);
-        qfprintf(index,":%06"PRIx32,delta);
-        qfprintf(index,":%"PRId64":%"PRId64,deltaPts,deltaDts);
+        
+    //    printf("%d -- %d = %d\n",nextConsumed, beginConsuming,delta);
+        
+        qfprintf(index,":%06" PRIx32,delta);
+        qfprintf(index,":%" PRId64":%" PRId64,deltaPts,deltaDts);
     
         beginConsuming=nextConsumed;
         listOfUnits.clear();
@@ -294,13 +310,13 @@ bool TsIndexer::dumpUnits(indexerData &data,uint64_t nextConsumed,const dmxPacke
 /**
     \fn addUnit
 */
-bool TsIndexer::addUnit(indexerData &data,int unitType2,const H264Unit &unit,uint32_t overRead)
+bool TsIndexerBase::addUnit(indexerData &data,int unitType2,const H264Unit &unit,uint32_t overRead)
 {
         H264Unit myUnit=unit;
         myUnit.unitType=unitType2;
         myUnit.overRead=overRead;
 #if 0
-        printf("Adding new unit of type %x unitType2 PTS=%"PRId64" DTS=%"PRId64"\n",unitType2,
+        printf("Adding new unit of type %x unitType2 PTS=%" PRId64" DTS=%" PRId64"\n",unitType2,
                     unit.packetInfo.pts,
                     unit.packetInfo.dts
                     );
