@@ -37,7 +37,7 @@ static const uint32_t FPS[16]={
 /**
     \fn runMpeg2
 */  
-bool TsIndexer::runMpeg2(const char *file,ADM_TS_TRACK *videoTrac)
+bool TsIndexerMpeg2::run(const char *file,ADM_TS_TRACK *videoTrac)
 {
 uint32_t temporal_ref,val;
 uint8_t buffer[50*1024];
@@ -79,14 +79,14 @@ bool bAppend=false;
     FP_TYPE append=FP_DONT_APPEND;
     if(true==ADM_probeSequencedFile(file))
     {
-        if(true==GUI_Question("There are several files with sequential file names. Should they be all loaded ?"))
+        if(true==GUI_Question(QT_TRANSLATE_NOOP("tsdemuxer","There are several files with sequential file names. Should they be all loaded ?")))
                bAppend=true;
     }
     if(true==bAppend)
         append=FP_APPEND;
     writeSystem(file,bAppend);
     pkt->open(file,append);
-    gui= createProcessing("Indexing",pkt->getSize());
+    gui= createProcessing(QT_TRANSLATE_NOOP("tsdemuxer","Indexing"),pkt->getSize());
     data.pkt=pkt;
     fullSize=pkt->getSize();
     int startCode;
@@ -136,7 +136,7 @@ bool bAppend=false;
                               keepRunning=false;
                           continue;
                           break;
-#warning FIXME, update pic field info.... It triggers a end-of-pic message as it is
+//#warning FIXME, update pic field info.... It triggers a end-of-pic message as it is
 #if 0
                     case 0xB5: //  extension
                                 { 
@@ -190,7 +190,7 @@ bool bAppend=false;
                           type=7 & (val>>3);
                           if( type<1 ||  type>3)
                           {
-                                  printf("[Indexer]Met illegal pic at %"PRIx64" + %"PRIx32"\n",
+                                  printf("[Indexer]Met illegal pic at %" PRIx64" + %" PRIx32"\n",
                                                   thisUnit.packetInfo.startAt,thisUnit.packetInfo.offset);
                                   continue;
                           }
@@ -211,9 +211,9 @@ bool bAppend=false;
     
         printf("\n");
         qfprintf(index,"\n[End]\n");
-        qfprintf(index,"\n# Found %"PRIu32" images \n",data.nbPics); // Size
-        qfprintf(index,"# Found %"PRIu32" frame pictures\n",video.frameCount); // Size
-        qfprintf(index,"# Found %"PRIu32" field pictures\n",video.fieldCount); // Size
+        qfprintf(index,"\n# Found %" PRIu32" images \n",data.nbPics); // Size
+        qfprintf(index,"# Found %" PRIu32" frame pictures\n",video.frameCount); // Size
+        qfprintf(index,"# Found %" PRIu32" field pictures\n",video.fieldCount); // Size
         qfclose(index);
         index=NULL;
         audioTracks=NULL;
