@@ -23,7 +23,7 @@ static const uint32_t  VC1_ar[16][2] = {  // From VLC
     \fn runVC1
     \brief Index VC1 stream
 */  
-bool TsIndexer::runVC1(const char *file,ADM_TS_TRACK *videoTrac)
+bool TsIndexerVC1::run(const char *file,ADM_TS_TRACK *videoTrac)
 {
 uint32_t temporal_ref,val;
 uint8_t buffer[50*1024];
@@ -63,7 +63,7 @@ dmxPacketInfo info;
     pkt->open(file,append);
     data.pkt=pkt;
     fullSize=pkt->getSize();
-    gui= createProcessing("Indexing",pkt->getSize());
+    gui= createProcessing(QT_TRANSLATE_NOOP("tsdemuxer","Indexing"),pkt->getSize());
     int startCode;
     decodingImage=false;
 #define likely(x) x
@@ -149,9 +149,9 @@ dmxPacketInfo info;
         printf("\n");
 //        Mark(&data,&info,2);
         qfprintf(index,"\n[End]\n");
-        qfprintf(index,"\n# Found %"PRIu32" images \n",data.nbPics); // Size
-        qfprintf(index,"# Found %"PRIu32" frame pictures\n",video.frameCount); // Size
-        qfprintf(index,"# Found %"PRIu32" field pictures\n",video.fieldCount); // Size
+        qfprintf(index,"\n# Found %" PRIu32" images \n",data.nbPics); // Size
+        qfprintf(index,"# Found %" PRIu32" frame pictures\n",video.frameCount); // Size
+        qfprintf(index,"# Found %" PRIu32" field pictures\n",video.fieldCount); // Size
         qfclose(index);
         index=NULL;
         audioTracks=NULL;
@@ -162,11 +162,11 @@ dmxPacketInfo info;
 /**
     \fn decodeVc1Seq
     \brief http://wiki.multimedia.cx/index.php?title=VC-1#Setup_Data_.2F_Sequence_Layer
-#warning we should de-escape it!
+//#warning we should de-escape it!
         Large part of this borrowed from VLC
         Advanced/High profile only
 */
-bool TsIndexer::decodeVC1Seq(tsGetBits &bits,TSVideo &video)
+bool TsIndexerVC1::decodeVC1Seq(tsGetBits &bits,TSVideo &video)
 {
 
 int v;
@@ -323,7 +323,7 @@ int consumed;
     Borrowed a lot from VLC also
 
 */
-bool TsIndexer::decodeVC1Pic(tsGetBits &bits,uint32_t &frameType,uint32_t &frameStructure)
+bool TsIndexerVC1::decodeVC1Pic(tsGetBits &bits,uint32_t &frameType,uint32_t &frameStructure)
 {
     frameStructure=3;
     bool field=false;
