@@ -21,6 +21,7 @@
 #include "fourcc.h"
 #include "muxerAvi.h"
 #include "ADM_vidMisc.h"
+#include "ADM_codecType.h"
 
 
 avi_muxer muxerConfig={AVI_MUXER_AUTO};
@@ -67,6 +68,12 @@ muxerAvi::~muxerAvi()
 
 bool muxerAvi::open(const char *file, ADM_videoStream *s,uint32_t nbAudioTrack,ADM_audioStream **a)
 {
+       uint32_t fcc=s->getFCC();
+       if(isH264Compatible(fcc) || isH265Compatible(fcc))
+       {
+           if(!GUI_YesNo(QT_TRANSLATE_NOOP("avimuxer","Bad Idea"),QT_TRANSLATE_NOOP("avimuxer","Using H264/H265 in AVI is a bad idea, MKV is better for that.\n Do you want to continue anyway ?")))
+               return false;
+       }
         audioDelay=s->getVideoDelay();
         if(!writter.saveBegin (
              file,
@@ -74,7 +81,7 @@ bool muxerAvi::open(const char *file, ADM_videoStream *s,uint32_t nbAudioTrack,A
              nbAudioTrack,
              a))
         {
-            GUI_Error_HIG("Error","Cannot create avi file");
+            GUI_Error_HIG(QT_TRANSLATE_NOOP("avimuxer","Error"),QT_TRANSLATE_NOOP("avimuxer","Cannot create AVI file"));
             return false;
 
         }
@@ -121,14 +128,14 @@ bool muxerAvi::fillAudio(uint64_t targetDts)
                                 aPacket->dts+=audioDelay;
                                 aPacket->dts-=firstPacketOffset;
                             }
-                            aprintf("[Audio] Packet size %"PRIu32" sample:%"PRIu32" dts:%"PRIu64" target :%"PRIu64"\n",
+                            aprintf("[Audio] Packet size %" PRIu32" sample:%" PRIu32" dts:%" PRIu64" target :%" PRIu64"\n",
                                             aPacket->sizeInBytes,aPacket->nbSamples,aPacket->dts,targetDts);
                             if(aPacket->dts!=ADM_NO_PTS)
                                 if( labs((long int)aPacket->dts-(long int)clk->getTimeUs())>32000)
                                 {
                                     ADM_warning("[AviMuxer] Audio skew!\n");
                                     clk->setTimeUs(aPacket->dts);
-#warning FIXME add padding
+//#warning FIXME add padding
                                 }
                             aPacket->present=true;
                     }
