@@ -38,7 +38,7 @@ typedef struct
 }idcToken;
 
 static const idcToken listOfIdc[]={
-        {-1,"Auto"},
+        {(unsigned int)-1,"Auto"},
         {10,"1"},
         {20,"2"},
         {21,"2.1"},
@@ -82,7 +82,8 @@ static const aspectRatio predefinedARs[]={
 static const char* listOfPresets[] = { "ultrafast", "superfast", "veryfast", "faster", "fast", "medium", "slow", "slower", "veryslow", "placebo" };
 #define NB_PRESET sizeof(listOfPresets)/sizeof(char*)
 
-static const char* listOfTunings[] = { "psnr", "ssim", "zerolatency", "fastdecode" };
+// Empty string "" as tuning means no tuning. This is the default.
+static const char* listOfTunings[] = { "", "psnr", "ssim", "grain", "zerolatency", "fastdecode" };
 #define NB_TUNE sizeof(listOfTunings)/sizeof(char*)
 
 static const char* listOfProfiles[] = { "main", "main10", "mainstillpicture" };
@@ -102,16 +103,7 @@ bool x265_ui(x265_settings *settings)
     if (dialog.exec() == QDialog::Accepted)
     {
             dialog.download();
-            if(settings->general.preset) ADM_dealloc(settings->general.preset);
-            settings->general.preset = NULL;
-            if(settings->general.tuning) ADM_dealloc(settings->general.tuning);
-            settings->general.tuning = NULL;
-            if(settings->general.profile) ADM_dealloc(settings->general.profile);
-            settings->general.profile = NULL;
-            memcpy(settings,&myCopy,sizeof(myCopy));
-            if(myCopy.general.preset) settings->general.preset = ADM_strdup(myCopy.general.preset);
-            if(myCopy.general.tuning) settings->general.tuning = ADM_strdup(myCopy.general.tuning);
-            if(myCopy.general.profile) settings->general.profile = ADM_strdup(myCopy.general.profile);
+            *settings=myCopy;
             success = true;
     }
 
@@ -130,6 +122,8 @@ x265Dialog::x265Dialog(QWidget *parent, void *param) : QDialog(parent)
         connect(ui.quantiserSlider, SIGNAL(valueChanged(int)), this, SLOT(quantiserSlider_valueChanged(int)));
         connect(ui.meSlider, SIGNAL(valueChanged(int)), this, SLOT(meSlider_valueChanged(int)));
         connect(ui.quantiserSpinBox, SIGNAL(valueChanged(int)), this, SLOT(quantiserSpinBox_valueChanged(int)));
+        connect(ui.maxBFramesSpinBox, SIGNAL(valueChanged(int)), this, SLOT(maxBFramesSpinBox_valueChanged(int)));
+        connect(ui.bFrameRefComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(bFrameRefComboBox_currentIndexChanged(int)));
         connect(ui.meSpinBox, SIGNAL(valueChanged(int)), this, SLOT(meSpinBox_valueChanged(int)));
         connect(ui.targetRateControlSpinBox, SIGNAL(valueChanged(int)), this, SLOT(targetRateControlSpinBox_valueChanged(int)));
         connect(ui.cuTreeCheckBox, SIGNAL(toggled(bool)), this, SLOT(cuTreeCheckBox_toggled(bool)));
@@ -139,16 +133,7 @@ x265Dialog::x265Dialog(QWidget *parent, void *param) : QDialog(parent)
         connect(ui.maxCrfSpinBox, SIGNAL(valueChanged(int)), this, SLOT(maxCrfSpinBox_valueChanged(int)));
 #endif
        x265_settings* settings = (x265_settings*)param;
-       if(myCopy.general.preset) ADM_dealloc(myCopy.general.preset);
-       myCopy.general.preset = NULL;
-       if(myCopy.general.tuning) ADM_dealloc(myCopy.general.tuning);
-       myCopy.general.tuning = NULL;
-       if(myCopy.general.profile) ADM_dealloc(myCopy.general.profile);
-       myCopy.general.profile = NULL;
-       memcpy(&myCopy,settings,sizeof(myCopy));
-       if(settings->general.preset) myCopy.general.preset = ADM_strdup(settings->general.preset);
-       if(settings->general.tuning) myCopy.general.tuning = ADM_strdup(settings->general.tuning);
-       if(settings->general.profile) myCopy.general.profile = ADM_strdup(settings->general.profile);
+       myCopy=*settings;
 
 #define ENCODING(x)  myCopy.general.params.x       
         lastBitrate =   ENCODING(bitrate);
@@ -195,7 +180,12 @@ x265Dialog::x265Dialog(QWidget *parent, void *param) : QDialog(parent)
         tunings->clear();
         for(int i=0;i<NB_TUNE;i++)
         {
-            tunings->addItem(QString(listOfTunings[i]));
+            // we pass an empty string to the encoder in order to disable tuning,
+            // but want to show a descriptive label to the user
+            const char* _tn=listOfTunings[i];
+            if(_tn=="")
+                _tn=QT_TRANSLATE_NOOP("x265","none");
+            tunings->addItem(QString(_tn));
         }
 
         QComboBox* profiles=ui.profileComboBox;
@@ -227,7 +217,7 @@ bool x265Dialog::updatePresetList(void)
     {
         combo->addItem(list[i].c_str());
     }
-    combo->addItem(QString("Custom"));
+    combo->addItem(QString(QT_TRANSLATE_NOOP("x265","Custom")));
     return true;
 }
 
@@ -259,7 +249,7 @@ bool x265Dialog::toogleAdvancedConfiguration(bool advancedEnabled)
     for(int i=0;i<count;i++) \
     { \
       const char *p=list[i]; \
-      if(myCopy.y && !strcmp(myCopy.y, p)) \
+      if(myCopy.y.size() && !strcmp(myCopy.y.c_str(), p)) \
       { \
         combobox->setCurrentIndex(i); \
       } \
@@ -456,8 +446,7 @@ bool x265Dialog::upload(void)
     QComboBox* combo=ui.x; \
     int idx=combo->currentIndex(); \
     ADM_assert(idx<count); \
-    if(myCopy.y) ADM_dealloc(myCopy.y); \
-    myCopy.y = ADM_strdup(list[idx]); \
+    myCopy.y = std::string(ADM_strdup(list[idx])); \
   }
 
 bool x265Dialog::download(void)
@@ -585,28 +574,28 @@ void x265Dialog::encodingModeComboBox_currentIndexChanged(int index)
 	switch (index)
 	{
 		case 0:
-			ui.targetRateControlLabel1->setText(tr("Target Bitrate:"));
-			ui.targetRateControlLabel2->setText(tr("kbit/s"));
+			ui.targetRateControlLabel1->setText(QT_TRANSLATE_NOOP("x265","Target Bitrate:"));
+			ui.targetRateControlLabel2->setText(QT_TRANSLATE_NOOP("x265","kbit/s"));
 			ui.targetRateControlSpinBox->setValue(lastBitrate);
                         enableStrictCbr = true;
 			break;
 		case 1: // Constant Quality - 1 pass
-			ui.quantiserLabel2->setText(tr("Quantiser:"));
+			ui.quantiserLabel2->setText(QT_TRANSLATE_NOOP("x265","Quantiser:"));
 			enableQp = true;
 			break;
 		case 2: // Average Quantiser - 1 pass
-			ui.quantiserLabel2->setText(tr("Quality:"));
+			ui.quantiserLabel2->setText(QT_TRANSLATE_NOOP("x265","Quality:"));
 			enableQp = true;
 			enableMaxCrf = true;
 			break;
 		case 3: // Video Size - 2 pass
-			ui.targetRateControlLabel1->setText(tr("Target Video Size:"));
-			ui.targetRateControlLabel2->setText(tr("MB"));
+			ui.targetRateControlLabel1->setText(QT_TRANSLATE_NOOP("x265","Target Video Size:"));
+			ui.targetRateControlLabel2->setText(QT_TRANSLATE_NOOP("x265","MB"));
 			ui.targetRateControlSpinBox->setValue(lastVideoSize);
 			break;
 		case 4: // Average Bitrate - 2 pass
-			ui.targetRateControlLabel1->setText(tr("Average Bitrate:"));
-			ui.targetRateControlLabel2->setText(tr("kbit/s"));
+			ui.targetRateControlLabel1->setText(QT_TRANSLATE_NOOP("x265","Average Bitrate:"));
+			ui.targetRateControlLabel2->setText(QT_TRANSLATE_NOOP("x265","kbit/s"));
 			ui.targetRateControlSpinBox->setValue(lastBitrate);
 			break;
 	}
@@ -647,10 +636,48 @@ void x265Dialog::meSlider_valueChanged(int value)
 {
 	ui.meSpinBox->setValue(value);
 }
+
 void x265Dialog::quantiserSpinBox_valueChanged(int value)
 {
 	ui.quantiserSlider->setValue(value);
 }
+
+void x265Dialog::maxBFramesSpinBox_valueChanged(int value)
+{
+    // HEVC specification allows a maximum of 8 total reference frames only if B frames are disabled.
+    // Enforce the limit to ensure compliance.
+    if(!value)
+    {
+        ui.refFramesSpinBox->setMaximum(8);
+    }else // with B frames enabled, the maximum decreases to 7
+    {
+        if(ui.bFrameRefComboBox->currentIndex()>0)
+        { // max ref frames decreases further to 6 if B pyramid is enabled as well
+            ui.refFramesSpinBox->setMaximum(6);
+        }else
+        {
+            ui.refFramesSpinBox->setMaximum(7);
+        }
+    }
+}
+
+void x265Dialog::bFrameRefComboBox_currentIndexChanged(int index)
+{
+     if(ui.maxBFramesSpinBox->value()) // if B frames are enabled
+     {
+         if(index>0) // and B pyramid is enabled too, reduce max ref frames accordingly
+         {
+             ui.refFramesSpinBox->setMaximum(6);
+         }else
+         {
+             ui.refFramesSpinBox->setMaximum(7);
+         }
+     }else
+     {
+         ui.refFramesSpinBox->setMaximum(8);
+     }
+}
+
 void x265Dialog::meSpinBox_valueChanged(int value)
 {
 	ui.meSlider->setValue(value);
@@ -668,7 +695,8 @@ void x265Dialog::cuTreeCheckBox_toggled(bool checked)
 {
 	if (checked && !ui.aqVarianceCheckBox->isChecked())
 	{
-		if (GUI_Question(tr("Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Variance Adaptive Quantisation will automatically be enabled.\n\nDo you wish to continue?").toUtf8().constData()))
+                QString st=QT_TRANSLATE_NOOP("x265","Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Variance Adaptive Quantisation will automatically be enabled.\n\nDo you wish to continue?");
+		if (GUI_Question(st.toUtf8().constData()))
 			ui.aqVarianceCheckBox->setChecked(true);
 		else
 			ui.cuTreeCheckBox->setChecked(false);
@@ -679,7 +707,8 @@ void x265Dialog::aqVarianceCheckBox_toggled(bool checked)
 {
 	if (!checked && ui.cuTreeCheckBox->isChecked())
 	{
-		if (GUI_Question(tr("Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Macroblock-Tree optimisation will automatically be disabled.\n\nDo you wish to continue?").toUtf8().constData()))
+                QString st=QT_TRANSLATE_NOOP("x265","Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Macroblock-Tree optimisation will automatically be disabled.\n\nDo you wish to continue?");
+		if (GUI_Question(st.toUtf8().constData()))
 			ui.cuTreeCheckBox->setChecked(false);
 		else
 			ui.aqVarianceCheckBox->setChecked(true);
@@ -719,7 +748,7 @@ void x265Dialog::configurationComboBox_currentIndexChanged(int index)
     ADM_info("Loading preset %s\n",t);
     if(false==x265_settings_jdeserialize(t,x265_settings_param,&myCopy))
     {
-        GUI_Error_HIG("Error","Cannot load preset");
+        GUI_Error_HIG(QT_TRANSLATE_NOOP("x265","Error"),QT_TRANSLATE_NOOP("x265","Cannot load preset"));
         ADM_error("Cannot read from %s\n",t);
     }else       
     {
@@ -734,7 +763,7 @@ void x265Dialog::configurationComboBox_currentIndexChanged(int index)
 static char *getProfileName(void)
 {
   QDialog dialog;
-  dialog.setWindowTitle(QString::fromUtf8("Save Profile"));
+  dialog.setWindowTitle(QString::fromUtf8(QT_TRANSLATE_NOOP("x265","Save Profile")));
   QDialogButtonBox *buttonBox = new QDialogButtonBox();  
   QVBoxLayout *vboxLayout = new QVBoxLayout();
   buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
@@ -779,7 +808,7 @@ void x265Dialog::saveAsButton_pressed(void)
 
   if(ADM_fileExist(fullpath.c_str()))
   {
-        if(false==GUI_Confirmation_HIG("Overwrite","Replace the following preset ?:",out))
+        if(false==GUI_Confirmation_HIG(QT_TRANSLATE_NOOP("x265","Overwrite"),QT_TRANSLATE_NOOP("x265","Replace the following preset ?:"),out))
         {
             ADM_dealloc(out);
             return;
@@ -788,7 +817,7 @@ void x265Dialog::saveAsButton_pressed(void)
   ADM_dealloc(out);
   if(false==x265_settings_jserialize(fullpath.c_str(),&myCopy))
   {
-        GUI_Error_HIG("Error","Cannot save preset");
+        GUI_Error_HIG(QT_TRANSLATE_NOOP("x265","Error"),QT_TRANSLATE_NOOP("x265","Cannot save preset"));
         ADM_error("Cannot write to %s\n",out);
   }
   updatePresetList();
@@ -802,13 +831,13 @@ void x265Dialog::deleteButton_pressed(void)
     int m=ui.configurationComboBox->count();
     if(n==m-1) // custom
     {
-        GUI_Error_HIG("Error","Cannot delete custom profile");
+        GUI_Error_HIG(QT_TRANSLATE_NOOP("x265","Error"),QT_TRANSLATE_NOOP("x265","Cannot delete custom profile"));
         return;
     }
   QString preset=ui.configurationComboBox->itemText(n);
-  QString msg=QString("Do you really want to delete the ")+preset+
-            QString(" profile ?.\nIf it is a system profile it will be recreated next time.");
-  if(true==GUI_Confirmation_HIG("Delete preset","Delete",msg.toUtf8().constData()))
+  QString msg=QString(QT_TRANSLATE_NOOP("x265","Do you really want to delete the "))+preset+
+            QString(QT_TRANSLATE_NOOP("x265"," profile ?.\nIf it is a system profile it will be recreated next time."));
+  if(true==GUI_Confirmation_HIG(QT_TRANSLATE_NOOP("x265","Delete preset"),QT_TRANSLATE_NOOP("x265","Delete"),msg.toUtf8().constData()))
   {
     std::string rootPath;
     ADM_pluginGetPath("x265",pluginVersion,rootPath);
