@@ -30,7 +30,7 @@ const char *addBorders::getConfiguration(void)
 {
     static char conf[250];
     conf[0]=0;
-    snprintf(conf,80,"Add Border : Left:%"PRIu32" Right:%"PRIu32" Top:%"PRIu32" Bottom:%"PRIu32" => %"PRIu32"x%"PRIu32"\n",
+    snprintf(conf,80,"Add Border : Left:%" PRIu32" Right:%" PRIu32" Top:%" PRIu32" Bottom:%" PRIu32" => %" PRIu32"x%" PRIu32"\n",
                 param.left,param.right,param.top,param.bottom,
                 info.width,info.height);
     return conf;
@@ -76,7 +76,7 @@ void addBorders::setCoupledConf(CONFcouple *couples)
 }
 #define Y_BLACK 16
 #define UV_BLACK 128
-static bool blackenHz(uint32_t w,uint32_t nbLine,uint8_t *ptr[3],uint32_t strides[3])
+static bool blackenHz(int w,int nbLine,uint8_t *ptr[3],int strides[3])
 {
     // y
     uint8_t *p=ptr[0];
@@ -137,7 +137,7 @@ bool addBorders::getNextFrame(uint32_t *fn,ADMImage *image)
 
     // Top...
     uint8_t *ptr[3];
-    uint32_t stride[3];
+    int     stride[3];
     image->GetPitches(stride);
     image->GetWritePlanes(ptr);
     blackenHz(image->_width,param.top,ptr,stride);
@@ -179,17 +179,17 @@ bool addBorders::configure(void)
           width=previousFilter->getInfo()->width;
           height=previousFilter->getInfo()->height;
 
-          diaElemUInteger dleft(&left,QT_TR_NOOP("_Left border:"),       0,width);
-          diaElemUInteger dright(&right,QT_TR_NOOP("_Right border:"),    0,width);
-          diaElemUInteger dtop(&(top),QT_TR_NOOP("_Top border:"),          0,height);
-          diaElemUInteger dbottom(&(bottom),QT_TR_NOOP("_Bottom border:"), 0,height);
+          diaElemUInteger dleft(&left,QT_TRANSLATE_NOOP("addBorder", "_Left border:"),       0,width);
+          diaElemUInteger dright(&right,QT_TRANSLATE_NOOP("addBorder", "_Right border:"),    0,width);
+          diaElemUInteger dtop(&(top),QT_TRANSLATE_NOOP("addBorder", "_Top border:"),          0,height);
+          diaElemUInteger dbottom(&(bottom),QT_TRANSLATE_NOOP("addBorder", "_Bottom border:"), 0,height);
 
           diaElem *elems[4]={&dleft,&dright,&dtop,&dbottom};
-          if(diaFactoryRun(QT_TR_NOOP("Add Borders"),4,elems))
+          if(diaFactoryRun(QT_TRANSLATE_NOOP("addBorder", "Add Borders"),4,elems))
           {
             if((left&1) || (right&1)|| (top&1) || (bottom&1))
             {
-              GUI_Error_HIG(QT_TR_NOOP("Incorrect parameters"),QT_TR_NOOP("All parameters must be even and within range."));
+              GUI_Error_HIG(QT_TRANSLATE_NOOP("addBorder", "Incorrect parameters"),QT_TRANSLATE_NOOP("addBorder", "All parameters must be even and within range."));
               continue;
             }
             else
