@@ -1,13 +1,11 @@
 
-
-#ifndef FLY_ASHARP_H
-#define FLY_ASHARP_H
+#pragma once
 /**
     \class flyASharp
 */
 #include "asharp.h"
 #define uc uint8_t
-class flyASharp : public FLY_DIALOG_TYPE
+class flyASharp : public ADM_flyDialogYuv
 {
   
   public:
@@ -18,9 +16,9 @@ class flyASharp : public FLY_DIALOG_TYPE
    uint8_t    download(void);
    uint8_t    upload(void);
    uint8_t    update(void);
-   flyASharp (uint32_t width,uint32_t height,ADM_coreVideoFilter *in,
-                                    void *canvas, void *slider) : 
-                FLY_DIALOG_TYPE(width, height,in,canvas, slider,1,RESIZE_AUTO) {};
+                flyASharp (QDialog *parent,uint32_t width,uint32_t height,ADM_coreVideoFilter *in,
+                                    ADM_QCanvas *canvas, QSlider *slider) : 
+                    ADM_flyDialogYuv(parent,width, height,in,canvas, slider,RESIZE_AUTO) {};
 };
 
 void asharp_run_c(      uc* planeptr, int pitch,
@@ -28,4 +26,4 @@ void asharp_run_c(      uc* planeptr, int pitch,
                                         int     T,int D, int B, int B2, bool bf,uint8_t *line );
 
 
-#endif
+
