@@ -36,9 +36,10 @@
 
         canvas=new ADM_QCanvas(ui.graphicsView,width,height);
         
-        myCrop=new flyASharp( width, height,in,canvas,ui.horizontalSlider);
+        myCrop=new flyASharp( this,width, height,in,canvas,ui.horizontalSlider);
         memcpy(&(myCrop->param),param,sizeof(asharp));
         myCrop->_cookie=&ui;
+        myCrop->addControl(ui.toolboxLayout);
         myCrop->upload();
         myCrop->sliderChanged();
 
