@@ -41,9 +41,10 @@ Ui_chromaShiftWindow::Ui_chromaShiftWindow(QWidget* parent, chromashift *param,A
         
         canvas=new ADM_QCanvas(ui.graphicsView,width,height);
         
-        myCrop=new flyChromaShift( width, height,in,canvas,ui.horizontalSlider);
+        myCrop=new flyChromaShift( this,width, height,in,canvas,ui.horizontalSlider);
         memcpy(&(myCrop->param),param,sizeof(chromashift));
         myCrop->_cookie=&ui;
+        myCrop->addControl(ui.toolboxLayout);
         myCrop->upload();
         myCrop->sliderChanged();
 
@@ -102,7 +103,7 @@ uint8_t flyChromaShift::download(void)
       \fn     DIA_getChromaShift
       \brief  Handle crop dialog
 */
-uint8_t DIA_getChromaShift( ADM_coreVideoFilter *in,chromashift    *param )
+bool DIA_getChromaShift( ADM_coreVideoFilter *in,chromashift    *param )
 {
         uint8_t ret=0;
 
