@@ -29,7 +29,7 @@ extern "C" {
 #include "vdpauFilterDeint.h"
 #include "vdpauFilterDeint_desc.cpp"
 
-#include "ADM_coreVideoCodec/ADM_hwAccel/ADM_coreVdpau/include/ADM_coreVdpau.h"
+#include "ADM_coreVdpau.h"
 //
 #define ADM_INVALID_FRAME_NUM 0x80000000
 #define ADM_NB_SURFACES 5
@@ -128,8 +128,8 @@ DECLARE_VIDEO_FILTER(   vdpauVideoFilterDeint,   // Class
                         ADM_UI_GTK+ADM_UI_QT4+ADM_FEATURE_VDPAU,     // We need a display for VDPAU; so no cli...
                         VF_INTERLACING,            // Category
                         "vdpauDeint",            // internal name (must be uniq!)
-                        "vdpauDeint",            // Display name
-                        "VDPAU deinterlacer (+resize)." // Description
+                        QT_TRANSLATE_NOOP("vdpaudeint","vdpauDeint"),            // Display name
+                        QT_TRANSLATE_NOOP("vdpaudeint","VDPAU deinterlacer (+resize).") // Description
                     );
 
 //
@@ -226,7 +226,7 @@ bool vdpauVideoFilterDeint::setupVdpau(void)
                                             previousFilter->getInfo()->height);
     
     if(VDP_STATUS_OK!=admVdpau::mixerCreate(previousFilter->getInfo()->width,
-                                            paddedHeight,&mixer,true)) 
+                                            paddedHeight,&mixer,true,configuration.enableIvtc)) 
     {
         ADM_error("Cannot create mixer\n");
         goto badInit;
@@ -290,6 +290,7 @@ vdpauVideoFilterDeint::vdpauVideoFilterDeint(ADM_coreVideoFilter *in, CONFcouple
         configuration.deintMode=ADM_KEEP_TOP;
         configuration.targetWidth=info.width;
         configuration.targetHeight=info.height;
+        configuration.enableIvtc=false;
     }
     
     myName="vdpauDeint";
@@ -313,22 +314,25 @@ bool vdpauVideoFilterDeint::configure( void)
 {
      
      diaMenuEntry tMode[]={
-                             {ADM_KEEP_TOP,      QT_TR_NOOP("Keep Top Field"),NULL},
-                             {ADM_KEEP_BOTTOM,   QT_TR_NOOP("Keep Bottom Field"),NULL},
-                             {ADM_KEEP_BOTH,      QT_TR_NOOP("Double framerate"),NULL}
+                             {ADM_KEEP_TOP,      QT_TRANSLATE_NOOP("vdpaudeint","Keep Top Field"),NULL},
+                             {ADM_KEEP_BOTTOM,   QT_TRANSLATE_NOOP("vdpaudeint","Keep Bottom Field"),NULL},
+                             {ADM_KEEP_BOTH,      QT_TRANSLATE_NOOP("vdpaudeint","Double framerate"),NULL}
                              
           };
      bool doResize=configuration.resizeToggle;
-     diaElemToggle    tResize(&(doResize),   QT_TR_NOOP("_Resize:"));
-     diaElemMenu      mMode(&(configuration.deintMode),   QT_TR_NOOP("_Deint Mode:"), 3,tMode);
-     diaElemUInteger  tWidth(&(configuration.targetWidth),QT_TR_NOOP("Width :"),16,2048);
-     diaElemUInteger  tHeight(&(configuration.targetHeight),QT_TR_NOOP("Height :"),16,2048);
+     bool doIvtc=configuration.enableIvtc;
+     diaElemToggle    tIvtc(&(doIvtc),   QT_TRANSLATE_NOOP("vdpaudeint","_Ivtc:"));
+     diaElemToggle    tResize(&(doResize),   QT_TRANSLATE_NOOP("vdpaudeint","_Resize:"));
+     diaElemMenu      mMode(&(configuration.deintMode),   QT_TRANSLATE_NOOP("vdpaudeint","_Deint Mode:"), 3,tMode);
+     diaElemUInteger  tWidth(&(configuration.targetWidth),QT_TRANSLATE_NOOP("vdpaudeint","Width :"),16,2048);
+     diaElemUInteger  tHeight(&(configuration.targetHeight),QT_TRANSLATE_NOOP("vdpaudeint","Height :"),16,2048);
      
-     diaElem *elems[]={&mMode,&tResize,&tWidth,&tHeight};
+     diaElem *elems[]={&mMode,&tIvtc,&tResize,&tWidth,&tHeight};
      
-     if(diaFactoryRun(QT_TR_NOOP("vdpau"),sizeof(elems)/sizeof(diaElem *),elems))
+     if(diaFactoryRun(QT_TRANSLATE_NOOP("vdpaudeint","vdpau"),sizeof(elems)/sizeof(diaElem *),elems))
      {
                 configuration.resizeToggle=(bool)doResize;
+                configuration.enableIvtc=doIvtc;
                 if(doResize)
                 {
                     info.width=configuration.targetWidth;
@@ -390,10 +394,13 @@ bool vdpauVideoFilterDeint::uploadImage(ADMImage *next,VdpVideoSurface surface)
         return false;
     }
   // Blit our image to surface
+    int      ipitches[3];
     uint32_t pitches[3];
     uint8_t *planes[3];
-    next->GetPitches(pitches);
+    next->GetPitches(ipitches);
     next->GetReadPlanes(planes);
+    
+    for(int i=0;i<3;i++) pitches[i]=(uint32_t)ipitches[i];
 
     aprintf("Putting image in surface %d\n",(int)surface);
     // Put out stuff in input...
@@ -436,7 +443,7 @@ bool vdpauVideoFilterDeint::fillSlot(int slot,ADMImage *image)
         img->duplicateFull(image); // increment ref count
         // get surface
         img->hwDownloadFromRef();
-        vdpau_render_state *render=(vdpau_render_state *)img->refDescriptor.refCookie;
+        vdpau_render_state *render=(vdpau_render_state *)img->refDescriptor.refHwImage;
         ADM_assert(render->refCount);
         tgt=render->surface;
         external=true;
@@ -524,7 +531,7 @@ bool vdpauVideoFilterDeint::sendField(bool topField)
     
        
     // ---------- Top field ------------
-    if(VDP_STATUS_OK!=admVdpau::mixerRenderWithPastAndFuture(topField, 
+    if(VDP_STATUS_OK!=admVdpau::mixerRenderFieldWithPastAndFuture(topField, 
                 mixer,
                 in,
                 outputSurface, 
