@@ -63,8 +63,8 @@ DECLARE_VIDEO_FILTER(   openGlResize,   // Class
                         ADM_UI_QT4+ADM_FEATURE_OPENGL,         // UI
                         VF_OPENGL,            // Category
                         "glResize",            // internal name (must be uniq!)
-                        "OpenGl Resize",            // Display name
-                        "Resize using openGl." // Description
+                        QT_TRANSLATE_NOOP("glResize","OpenGl Resize"),            // Display name
+                        QT_TRANSLATE_NOOP("glResize","Resize using openGl.") // Description
                     );
 
 // Now implements the interesting parts
@@ -88,23 +88,10 @@ UNUSED_ARG(setup);
         _parentQGL->makeCurrent();
         fboY->bind();
         printf("Compiling shader \n");
-        glProgramY = new QGLShaderProgram(_context);
-        ADM_assert(glProgramY);
-        if ( !glProgramY->addShaderFromSourceCode(QGLShader::Fragment, myShaderY))
+        glProgramY =    createShaderFromSource(QGLShader::Fragment,myShaderY);
+        if ( !glProgramY)
         {
-                ADM_error("[GL Render] Fragment log: %s\n", glProgramY->log().toUtf8().constData());
-                ADM_assert(0);
-        }
-        if ( !glProgramY->link())
-        {
-            ADM_error("[GL Render] Link log: %s\n", glProgramY->log().toUtf8().constData());
-            ADM_assert(0);
-        }
-
-        if ( !glProgramY->bind())
-        {
-                ADM_error("[GL Render] Binding FAILED\n");
-                ADM_assert(0);
+            ADM_error("[GL Render] Cannot compile shader\n");            
         }
 
         fboY->release();
@@ -127,6 +114,15 @@ openGlResize::~openGlResize()
 */
 bool openGlResize::getNextFrame(uint32_t *fn,ADMImage *image)
 {
+    if(!glProgramY)
+    {
+        char strxx[80];
+        snprintf(strxx,80,"Shader was not compiled succesfully");
+        image->printString(2,4,strxx); 
+        return true;
+    }    
+    
+    
     // since we do nothing, just get the output of previous filter
     if(false==previousFilter->getNextFrame(fn,original))
     {
@@ -214,12 +210,12 @@ bool openGlResize::configure( void)
 {
     
      
-     diaElemUInteger  tWidth(&(configuration.width),QT_TR_NOOP("Width :"),16,2048);
-     diaElemUInteger  tHeight(&(configuration.height),QT_TR_NOOP("Height :"),16,2048);
+     diaElemUInteger  tWidth(&(configuration.width),QT_TRANSLATE_NOOP("glResize","Width :"),16,2048);
+     diaElemUInteger  tHeight(&(configuration.height),QT_TRANSLATE_NOOP("glResize","Height :"),16,2048);
      
      diaElem *elems[]={&tWidth,&tHeight};
      
-     if(diaFactoryRun(QT_TR_NOOP("glResize"),sizeof(elems)/sizeof(diaElem *),elems))
+     if(diaFactoryRun(QT_TRANSLATE_NOOP("glResize","glResize"),sizeof(elems)/sizeof(diaElem *),elems))
      {
                 info.width=configuration.width;
                 info.height=configuration.height;
