@@ -54,8 +54,8 @@ DECLARE_VIDEO_FILTER(   rotateGl,   // Class
                         ADM_UI_QT4+ADM_FEATURE_OPENGL,         // UI
                         VF_OPENGL,            // Category
                         "glRotate",            // internal name (must be uniq!)
-                        "OpenGl Rotate",            // Display name
-                        "Rotate image by a small amount." // Description
+                        QT_TRANSLATE_NOOP("glRotate","OpenGl Rotate"),            // Display name
+                        QT_TRANSLATE_NOOP("glRotate","Rotate image by a small amount.") // Description
                     );
 
 // Now implements the interesting parts
@@ -75,24 +75,13 @@ UNUSED_ARG(setup);
         _parentQGL->makeCurrent();
         fboY->bind();
         printf("Compiling shader \n");
-        glProgramY = new QGLShaderProgram(_context);
-        ADM_assert(glProgramY);
-        if ( !glProgramY->addShaderFromSourceCode(QGLShader::Fragment, myShaderY))
+        
+        glProgramY =    createShaderFromSource(QGLShader::Fragment,myShaderY);
+        if(!glProgramY)
         {
-                ADM_error("[GL Render] Fragment log: %s\n", glProgramY->log().toUtf8().constData());
-                ADM_assert(0);
-        }
-        if ( !glProgramY->link())
-        {
-            ADM_error("[GL Render] Link log: %s\n", glProgramY->log().toUtf8().constData());
-            ADM_assert(0);
-        }
-
-        if ( !glProgramY->bind())
-        {
-                ADM_error("[GL Render] Binding FAILED\n");
-                ADM_assert(0);
-        }
+            ADM_error("Cannot setup shader\n");
+        }        
+                
         glList=glGenLists(1);
         genQuad();
         fboY->release();
@@ -116,6 +105,15 @@ rotateGl::~rotateGl()
 */
 bool rotateGl::getNextFrame(uint32_t *fn,ADMImage *image)
 {
+    if(!glProgramY)
+    {
+        char strxx[80];
+        snprintf(strxx,80,"Shader was not compiled succesfully");
+        image->printString(2,4,strxx); 
+        return true;
+    }    
+    
+    
     // since we do nothing, just get the output of previous filter
     if(false==previousFilter->getNextFrame(fn,original))
     {
@@ -175,12 +173,12 @@ bool rotateGl::configure( void)
 {
     
      
-     diaElemInteger  tAngle(&(params.angle),QT_TR_NOOP("Angle (°):"),-190,190);
+     diaElemInteger  tAngle(&(params.angle),QT_TRANSLATE_NOOP("glRotate","Angle (°):"),-190,190);
    
      
      diaElem *elems[]={&tAngle};
      
-     if(diaFactoryRun(QT_TR_NOOP("glRotate"),sizeof(elems)/sizeof(diaElem *),elems))
+     if(diaFactoryRun(QT_TRANSLATE_NOOP("glRotate","glRotate"),sizeof(elems)/sizeof(diaElem *),elems))
      {
                 ADM_info("New angle : %d \n",params.angle);
                 _parentQGL->makeCurrent();
