@@ -56,8 +56,8 @@ DECLARE_VIDEO_FILTER(   openGlDistort,   // Class
                         ADM_UI_QT4+ADM_FEATURE_OPENGL,         // UI
                         VF_OPENGL,            // Category
                         "glSampleDistort",            // internal name (must be uniq!)
-                        "OpenGl wave ",            // Display name
-                        "Simple wave filter." // Description
+                        QT_TRANSLATE_NOOP("glWave","OpenGl wave "),            // Display name
+                        QT_TRANSLATE_NOOP("glWave","Simple wave filter.") // Description
                     );
 
 // Now implements the interesting parts
@@ -74,24 +74,12 @@ UNUSED_ARG(setup);
         // vertex shader 
        
         // frag shader
-        glProgramY = new QGLShaderProgram(_context);
-        ADM_assert(glProgramY);
-        if ( !glProgramY->addShaderFromSourceCode(QGLShader::Fragment, myShaderY))
+        glProgramY =    createShaderFromSource(QGLShader::Fragment,myShaderY);
+        if(!glProgramY)
         {
-                ADM_error("[GL Render] Fragment log: %s\n", glProgramY->log().toUtf8().constData());
-                ADM_assert(0);
-        }
-        if ( !glProgramY->link())
-        {
-            ADM_error("[GL Render] Link log: %s\n", glProgramY->log().toUtf8().constData());
-            ADM_assert(0);
-        }
+            ADM_error("Cannot setup shader\n");
+        }        
 
-        if ( !glProgramY->bind())
-        {
-                ADM_error("[GL Render] Binding FAILED\n");
-                ADM_assert(0);
-        }
         glList=glGenLists(1);
         
         fboY->release();
@@ -113,6 +101,13 @@ openGlDistort::~openGlDistort()
 */
 bool openGlDistort::getNextFrame(uint32_t *fn,ADMImage *image)
 {
+    if(!glProgramY)
+    {
+        char strxx[80];
+        snprintf(strxx,80,"Shader was not compiled succesfully");
+        image->printString(2,4,strxx); 
+        return true;
+    }
     // since we do nothing, just get the output of previous filter
     if(false==previousFilter->getNextFrame(fn,image))
     {
